/*     */ package com.scytl.pnyx.client.communication.application;
/*     */ 
/*     */ import com.scytl.common.domain.LoginType;
/*     */ import com.scytl.common.domain.MessageType;
/*     */ import com.scytl.pnyx.client.SecurityException;
/*     */ import com.scytl.pnyx.client.SecurityException.Key;
/*     */ import com.scytl.pnyx.client.communication.connector.ClientData;
/*     */ import com.scytl.pnyx.client.state.LoginData;
/*     */ import com.scytl.pnyx.client.state.RecognizedLoginData;
/*     */ import java.security.GeneralSecurityException;
/*     */ import java.security.KeyStore;
/*     */ import java.security.KeyStoreException;
/*     */ import java.security.PrivateKey;
/*     */ import java.security.PublicKey;
/*     */ import java.security.cert.Certificate;
/*     */ import java.security.cert.X509Certificate;
/*     */ import java.util.Enumeration;
/*     */ import javax.crypto.SecretKey;
/*     */ import org.apache.commons.logging.Log;
/*     */ import org.apache.commons.logging.LogFactory;
/*     */ import org.picocontainer.ComponentMonitor;
/*     */ 
/*     */ public class ClientDataManager
/*     */ {
/*  35 */   private static Log _logger = LogFactory.getLog(ClientDataManager.class);
/*     */   private final ClientData _clientData;
/*     */   private SecretKey _secureMessageSecretKey;
/*     */   private String _encryptedBallotContent;
/*     */   private String _secureMessageSignature;
/*     */   private String _ballotId;
/*  49 */   private final long _timestamp = System.currentTimeMillis();
/*     */   private String _electoralBoardEnvelopedSecretKey;
/*     */ 
/*     */   public ClientDataManager(ClientData clientData)
/*     */   {
/*  57 */     this._clientData = clientData;
/*     */   }
/*     */ 
/*     */   public void setSecureMessageSecretKey(SecretKey secureMessageSecretKey)
/*     */   {
/*  65 */     this._secureMessageSecretKey = secureMessageSecretKey;
/*     */   }
/*     */ 
/*     */   public void setSecureMessageSignature(String secureMessageSignature)
/*     */   {
/*  70 */     this._secureMessageSignature = secureMessageSignature;
/*     */   }
/*     */ 
/*     */   public String getSecureMessageSignature()
/*     */   {
/*  77 */     return this._secureMessageSignature;
/*     */   }
/*     */ 
/*     */   public PublicKey getElectoralBoardPublicKey() {
/*  81 */     String certAlias = "electoral_board_x509";
/*     */     try {
/*  83 */       return getElectionPublicKey(certAlias);
/*     */     }
/*     */     catch (GeneralSecurityException gse)
/*     */     {
/*     */       GeneralSecurityException gse;
/*  85 */       _logger.error("Error retrieving the electoral board public key.", this);
/*     */     }
/*  87 */     return null;
/*     */   }
/*     */ 
/*     */   public PublicKey getAdministrationBoardPublicKey()
/*     */   {
/*  92 */     String certAlias = "administration_board_x509";
/*     */     try {
/*  94 */       return getElectionPublicKey(certAlias);
/*     */     }
/*     */     catch (GeneralSecurityException gse)
/*     */     {
/*     */       GeneralSecurityException gse;
/*  96 */       _logger.error("Error retrieving the administration board public key.", this);
/*     */     }
/*     */ 
/*  99 */     return null;
/*     */   }
/*     */ 
/*     */   public PublicKey getMessageServerPublicKey()
/*     */   {
/* 109 */     String str = "message_server_x509";
/*     */     try {
/* 111 */       str = str; this = this; return this._clientData.getServerKeystore().getCertificate(str).getPublicKey();
/*     */     } catch (GeneralSecurityException this) {
/* 113 */       _logger.error("Error retrieving the message server public key.", this);
/*     */     }
/* 115 */     return null;
/*     */   }
/*     */ 
/*     */   private PublicKey getElectionPublicKey(String certAlias)
/*     */     throws GeneralSecurityException
/*     */   {
/* 127 */     return this._clientData.getElectionKeyStore().getCertificate(certAlias).getPublicKey();
/*     */   }
/*     */ 
/*     */   public PublicKey getUserPublicKey()
/*     */     throws GeneralSecurityException
/*     */   {
/* 144 */     return getUserCertificate().getPublicKey();
/*     */   }
/*     */ 
/*     */   public PrivateKey getUserPrivateKey()
/*     */     throws GeneralSecurityException, SecurityException
/*     */   {
/*     */     KeyStore userKeyStore;
/* 152 */     return (PrivateKey)(
/* 152 */       userKeyStore = this._clientData.getUserKeyStore())
/* 152 */       .getKey(getUserAlias(), this._clientData.getLoginData().getPin());
/*     */   }
/*     */ 
/*     */   public X509Certificate getUserCertificate()
/*     */     throws GeneralSecurityException
/*     */   {
/* 158 */     return (X509Certificate)this._clientData.getUserKeyStore().getCertificate(getUserAlias());
/*     */   }
/*     */ 
/*     */   private String getUserAlias() throws KeyStoreException
/*     */   {
/* 163 */     if ((this._clientData.getLoginData() instanceof RecognizedLoginData))
/*     */     {
/*     */       String alias;
/* 167 */       if ((
/* 167 */         alias = ((RecognizedLoginData)this._clientData.getLoginData()).getAlias()) != null)
/*     */       {
/* 168 */         return alias;
/*     */       }
/*     */     }
/*     */ 
/* 172 */     if (this._clientData.getUserKeyStore().size() != 1) {
/* 173 */       throw new KeyStoreException(SecurityException.Key.MALFORMED_KEYSTORE.getKey());
/*     */     }
/*     */ 
/* 178 */     return (String)this._clientData.getUserKeyStore().aliases().nextElement();
/*     */   }
/*     */ 
/*     */   public void setEncryptedBallotContent(String encryptedBallotContent)
/*     */   {
/* 184 */     this._encryptedBallotContent = encryptedBallotContent;
/*     */   }
/*     */ 
/*     */   public String getEncryptedBallotContent() {
/* 188 */     return this._encryptedBallotContent;
/*     */   }
/*     */ 
/*     */   public void setBallotId(String ballotId)
/*     */   {
/* 195 */     this._ballotId = ballotId;
/*     */   }
/*     */ 
/*     */   public String getBallotId() {
/* 199 */     return this._ballotId;
/*     */   }
/*     */ 
/*     */   public ClientData getClientData() {
/* 203 */     return this._clientData;
/*     */   }
/*     */ 
/*     */   public SecretKey getSecureMessageSecretKey() {
/* 207 */     return this._secureMessageSecretKey;
/*     */   }
/*     */ 
/*     */   public long getTimestamp() {
/* 211 */     return this._timestamp;
/*     */   }
/*     */ 
/*     */   public ComponentMonitor getTokenData$49262418() {
/* 215 */     return this._clientData.getToken$49262418();
/*     */   }
/*     */ 
/*     */   public boolean canDecrypt()
/*     */     throws GeneralSecurityException
/*     */   {
/* 224 */     if (LoginType.ADVANCED.equals(this._clientData.getLoginType())) {
/* 225 */       return true;
/*     */     }
/*     */ 
/* 228 */     (
/* 229 */       this = getUserCertificate())
/* 229 */       .getKeyUsage();
/*     */     try { getExtendedKeyUsage();
/*     */     }
/*     */     catch (java.security.cert.CertificateParsingException this)
/*     */     {
/* 234 */       _logger.warn("The extended key usage extension oculd not be decoded", this);
/*     */     }
/*     */ 
/* 239 */     return false;
/*     */   }
/*     */ 
/*     */   public void setElectoralBoardEncriptedSecretKey(String encryptedSecretKey)
/*     */   {
/* 252 */     this._electoralBoardEnvelopedSecretKey = encryptedSecretKey;
/*     */   }
/*     */ 
/*     */   public String getElectoralBoardEncriptedSecretKey() {
/* 256 */     return this._electoralBoardEnvelopedSecretKey;
/*     */   }
/*     */ 
/*     */   public MessageType getMessageType() {
/* 260 */     return this._clientData.getMessageType();
/*     */   }
/*     */ }

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     com.scytl.pnyx.client.communication.application.ClientDataManager
 * JD-Core Version:    0.6.0
 */