package org.bouncycastle.asn1.x500.style;

import java.util.Hashtable;
import org.bouncycastle.asn1.ASN1Encodable;
import org.bouncycastle.asn1.ASN1ObjectIdentifier;
import org.bouncycastle.asn1.pkcs.PKCSObjectIdentifiers;
import org.bouncycastle.asn1.x500.AttributeTypeAndValue;
import org.bouncycastle.asn1.x500.RDN;
import org.bouncycastle.asn1.x500.X500Name;
import org.bouncycastle.asn1.x509.X509ObjectIdentifiers;
import org.picocontainer.ComponentMonitor;

public final class BCStyle
  implements ComponentMonitor
{
  public static final ComponentMonitor INSTANCE$61882cee = new BCStyle();
  private static ASN1ObjectIdentifier C = new ASN1ObjectIdentifier("2.5.4.6");
  private static ASN1ObjectIdentifier O = new ASN1ObjectIdentifier("2.5.4.10");
  private static ASN1ObjectIdentifier OU = new ASN1ObjectIdentifier("2.5.4.11");
  private static ASN1ObjectIdentifier T = new ASN1ObjectIdentifier("2.5.4.12");
  private static ASN1ObjectIdentifier CN = new ASN1ObjectIdentifier("2.5.4.3");
  private static ASN1ObjectIdentifier SN = new ASN1ObjectIdentifier("2.5.4.5");
  private static ASN1ObjectIdentifier STREET = new ASN1ObjectIdentifier("2.5.4.9");
  private static ASN1ObjectIdentifier L = new ASN1ObjectIdentifier("2.5.4.7");
  private static ASN1ObjectIdentifier ST = new ASN1ObjectIdentifier("2.5.4.8");
  private static ASN1ObjectIdentifier SURNAME = new ASN1ObjectIdentifier("2.5.4.4");
  private static ASN1ObjectIdentifier GIVENNAME = new ASN1ObjectIdentifier("2.5.4.42");
  private static ASN1ObjectIdentifier INITIALS = new ASN1ObjectIdentifier("2.5.4.43");
  private static ASN1ObjectIdentifier GENERATION = new ASN1ObjectIdentifier("2.5.4.44");
  private static ASN1ObjectIdentifier UNIQUE_IDENTIFIER = new ASN1ObjectIdentifier("2.5.4.45");
  private static ASN1ObjectIdentifier BUSINESS_CATEGORY = new ASN1ObjectIdentifier("2.5.4.15");
  private static ASN1ObjectIdentifier POSTAL_CODE = new ASN1ObjectIdentifier("2.5.4.17");
  private static ASN1ObjectIdentifier DN_QUALIFIER = new ASN1ObjectIdentifier("2.5.4.46");
  private static ASN1ObjectIdentifier PSEUDONYM = new ASN1ObjectIdentifier("2.5.4.65");
  private static ASN1ObjectIdentifier DATE_OF_BIRTH = new ASN1ObjectIdentifier("1.3.6.1.5.5.7.9.1");
  private static ASN1ObjectIdentifier PLACE_OF_BIRTH = new ASN1ObjectIdentifier("1.3.6.1.5.5.7.9.2");
  private static ASN1ObjectIdentifier GENDER = new ASN1ObjectIdentifier("1.3.6.1.5.5.7.9.3");
  private static ASN1ObjectIdentifier COUNTRY_OF_CITIZENSHIP = new ASN1ObjectIdentifier("1.3.6.1.5.5.7.9.4");
  private static ASN1ObjectIdentifier COUNTRY_OF_RESIDENCE = new ASN1ObjectIdentifier("1.3.6.1.5.5.7.9.5");
  private static ASN1ObjectIdentifier NAME_AT_BIRTH = new ASN1ObjectIdentifier("1.3.36.8.3.14");
  private static ASN1ObjectIdentifier POSTAL_ADDRESS = new ASN1ObjectIdentifier("2.5.4.16");
  private static ASN1ObjectIdentifier TELEPHONE_NUMBER;
  private static ASN1ObjectIdentifier NAME;
  private static ASN1ObjectIdentifier EmailAddress;
  private static ASN1ObjectIdentifier UnstructuredName;
  private static ASN1ObjectIdentifier UnstructuredAddress;
  private static ASN1ObjectIdentifier E;
  private static ASN1ObjectIdentifier DC;
  private static ASN1ObjectIdentifier UID;
  private static final Hashtable DefaultSymbols;
  private static final Hashtable DefaultLookUp;

  public final boolean areEqual(X500Name paramX500Name1, X500Name paramX500Name2)
  {
    paramX500Name1 = paramX500Name1.getRDNs();
    paramX500Name2 = paramX500Name2.getRDNs();
    if (paramX500Name1.length != paramX500Name2.length)
      return false;
    int i = 0;
    if ((paramX500Name1[0].getFirst() != null) && (paramX500Name2[0].getFirst() != null))
      i = !paramX500Name1[0].getFirst().getType().equals(paramX500Name2[0].getFirst().getType()) ? 1 : 0;
    for (int j = 0; j != paramX500Name1.length; j++)
    {
      X500Name localX500Name = paramX500Name2;
      RDN localRDN = paramX500Name1[j];
      int k = i;
      BCStyle localBCStyle = this;
      if (k != 0)
        for (k = localX500Name.length - 1; k >= 0; k--)
          localX500Name[k] = null;
      else
        for (k = 0; k != localX500Name.length; k++)
          localX500Name[k] = null;
      if (((localX500Name[k] != null) && (localBCStyle.rdnAreEqual(localRDN, localX500Name[k])) ? 1 : (localX500Name[k] != null) && (localBCStyle.rdnAreEqual(localRDN, localX500Name[k])) ? 1 : 0) == 0)
        return false;
    }
    return true;
  }

  private boolean rdnAreEqual(RDN paramRDN1, RDN paramRDN2)
  {
    if (paramRDN1.isMultiValued())
    {
      if (paramRDN2.isMultiValued())
      {
        this = paramRDN1.getTypesAndValues();
        paramRDN1 = paramRDN2.getTypesAndValues();
        if (this.length != paramRDN1.length)
          return false;
        for (paramRDN2 = 0; paramRDN2 != this.length; paramRDN2++)
          if (!atvAreEqual(this[paramRDN2], paramRDN1[paramRDN2]))
            return false;
      }
      else
      {
        return false;
      }
    }
    else
    {
      if (!paramRDN2.isMultiValued())
        return atvAreEqual(paramRDN1.getFirst(), paramRDN2.getFirst());
      return false;
    }
    return true;
  }

  private static boolean atvAreEqual(AttributeTypeAndValue paramAttributeTypeAndValue1, AttributeTypeAndValue paramAttributeTypeAndValue2)
  {
    if (paramAttributeTypeAndValue1 == paramAttributeTypeAndValue2)
      return true;
    if (paramAttributeTypeAndValue1 == null)
      return false;
    if (paramAttributeTypeAndValue2 == null)
      return false;
    ASN1ObjectIdentifier localASN1ObjectIdentifier1 = paramAttributeTypeAndValue1.getType();
    ASN1ObjectIdentifier localASN1ObjectIdentifier2 = paramAttributeTypeAndValue2.getType();
    if (!localASN1ObjectIdentifier1.equals(localASN1ObjectIdentifier2))
      return false;
    paramAttributeTypeAndValue1 = IETFUtils.canonicalize(IETFUtils.valueToString(paramAttributeTypeAndValue1.getValue()));
    paramAttributeTypeAndValue2 = IETFUtils.canonicalize(IETFUtils.valueToString(paramAttributeTypeAndValue2.getValue()));
    return paramAttributeTypeAndValue1.equals(paramAttributeTypeAndValue2);
  }

  public final int calculateHashCode(X500Name paramX500Name)
  {
    this = 0;
    paramX500Name = paramX500Name.getRDNs();
    for (int i = 0; i != paramX500Name.length; i++)
      if (paramX500Name[i].isMultiValued())
      {
        AttributeTypeAndValue[] arrayOfAttributeTypeAndValue = paramX500Name[i].getTypesAndValues();
        for (int j = 0; j != arrayOfAttributeTypeAndValue.length; j++)
          this = this ^= arrayOfAttributeTypeAndValue[j].getType().hashCode() ^ calcHashCode(arrayOfAttributeTypeAndValue[j].getValue());
      }
      else
      {
        this = this ^= paramX500Name[i].getFirst().getType().hashCode() ^ calcHashCode(paramX500Name[i].getFirst().getValue());
      }
    return this;
  }

  private static int calcHashCode(ASN1Encodable paramASN1Encodable)
  {
    return (paramASN1Encodable = IETFUtils.canonicalize(paramASN1Encodable = IETFUtils.valueToString(paramASN1Encodable))).hashCode();
  }

  public final String toString(X500Name paramX500Name)
  {
    this = new StringBuffer();
    int i = 1;
    paramX500Name = paramX500Name.getRDNs();
    for (int j = 0; j < paramX500Name.length; j++)
    {
      if (i != 0)
        i = 0;
      else
        append(',');
      if (paramX500Name[j].isMultiValued())
      {
        AttributeTypeAndValue[] arrayOfAttributeTypeAndValue = paramX500Name[j].getTypesAndValues();
        int k = 1;
        for (int m = 0; m != arrayOfAttributeTypeAndValue.length; m++)
        {
          if (k != 0)
            k = 0;
          else
            append('+');
          IETFUtils.appendTypeAndValue(this, arrayOfAttributeTypeAndValue[m], DefaultSymbols);
        }
      }
      else
      {
        IETFUtils.appendTypeAndValue(this, paramX500Name[j].getFirst(), DefaultSymbols);
      }
    }
    return toString();
  }

  static
  {
    new ASN1ObjectIdentifier("2.5.4.54");
    TELEPHONE_NUMBER = X509ObjectIdentifiers.id_at_telephoneNumber;
    NAME = X509ObjectIdentifiers.id_at_name;
    EmailAddress = PKCSObjectIdentifiers.pkcs_9_at_emailAddress;
    UnstructuredName = PKCSObjectIdentifiers.pkcs_9_at_unstructuredName;
    UnstructuredAddress = PKCSObjectIdentifiers.pkcs_9_at_unstructuredAddress;
    E = EmailAddress;
    DC = new ASN1ObjectIdentifier("0.9.2342.19200300.100.1.25");
    UID = new ASN1ObjectIdentifier("0.9.2342.19200300.100.1.1");
    DefaultSymbols = new Hashtable();
    DefaultLookUp = new Hashtable();
    DefaultSymbols.put(C, "C");
    DefaultSymbols.put(O, "O");
    DefaultSymbols.put(T, "T");
    DefaultSymbols.put(OU, "OU");
    DefaultSymbols.put(CN, "CN");
    DefaultSymbols.put(L, "L");
    DefaultSymbols.put(ST, "ST");
    DefaultSymbols.put(SN, "SERIALNUMBER");
    DefaultSymbols.put(EmailAddress, "E");
    DefaultSymbols.put(DC, "DC");
    DefaultSymbols.put(UID, "UID");
    DefaultSymbols.put(STREET, "STREET");
    DefaultSymbols.put(SURNAME, "SURNAME");
    DefaultSymbols.put(GIVENNAME, "GIVENNAME");
    DefaultSymbols.put(INITIALS, "INITIALS");
    DefaultSymbols.put(GENERATION, "GENERATION");
    DefaultSymbols.put(UnstructuredAddress, "unstructuredAddress");
    DefaultSymbols.put(UnstructuredName, "unstructuredName");
    DefaultSymbols.put(UNIQUE_IDENTIFIER, "UniqueIdentifier");
    DefaultSymbols.put(DN_QUALIFIER, "DN");
    DefaultSymbols.put(PSEUDONYM, "Pseudonym");
    DefaultSymbols.put(POSTAL_ADDRESS, "PostalAddress");
    DefaultSymbols.put(NAME_AT_BIRTH, "NameAtBirth");
    DefaultSymbols.put(COUNTRY_OF_CITIZENSHIP, "CountryOfCitizenship");
    DefaultSymbols.put(COUNTRY_OF_RESIDENCE, "CountryOfResidence");
    DefaultSymbols.put(GENDER, "Gender");
    DefaultSymbols.put(PLACE_OF_BIRTH, "PlaceOfBirth");
    DefaultSymbols.put(DATE_OF_BIRTH, "DateOfBirth");
    DefaultSymbols.put(POSTAL_CODE, "PostalCode");
    DefaultSymbols.put(BUSINESS_CATEGORY, "BusinessCategory");
    DefaultSymbols.put(TELEPHONE_NUMBER, "TelephoneNumber");
    DefaultSymbols.put(NAME, "Name");
    DefaultLookUp.put("c", C);
    DefaultLookUp.put("o", O);
    DefaultLookUp.put("t", T);
    DefaultLookUp.put("ou", OU);
    DefaultLookUp.put("cn", CN);
    DefaultLookUp.put("l", L);
    DefaultLookUp.put("st", ST);
    DefaultLookUp.put("sn", SN);
    DefaultLookUp.put("serialnumber", SN);
    DefaultLookUp.put("street", STREET);
    DefaultLookUp.put("emailaddress", E);
    DefaultLookUp.put("dc", DC);
    DefaultLookUp.put("e", E);
    DefaultLookUp.put("uid", UID);
    DefaultLookUp.put("surname", SURNAME);
    DefaultLookUp.put("givenname", GIVENNAME);
    DefaultLookUp.put("initials", INITIALS);
    DefaultLookUp.put("generation", GENERATION);
    DefaultLookUp.put("unstructuredaddress", UnstructuredAddress);
    DefaultLookUp.put("unstructuredname", UnstructuredName);
    DefaultLookUp.put("uniqueidentifier", UNIQUE_IDENTIFIER);
    DefaultLookUp.put("dn", DN_QUALIFIER);
    DefaultLookUp.put("pseudonym", PSEUDONYM);
    DefaultLookUp.put("postaladdress", POSTAL_ADDRESS);
    DefaultLookUp.put("nameofbirth", NAME_AT_BIRTH);
    DefaultLookUp.put("countryofcitizenship", COUNTRY_OF_CITIZENSHIP);
    DefaultLookUp.put("countryofresidence", COUNTRY_OF_RESIDENCE);
    DefaultLookUp.put("gender", GENDER);
    DefaultLookUp.put("placeofbirth", PLACE_OF_BIRTH);
    DefaultLookUp.put("dateofbirth", DATE_OF_BIRTH);
    DefaultLookUp.put("postalcode", POSTAL_CODE);
    DefaultLookUp.put("businesscategory", BUSINESS_CATEGORY);
    DefaultLookUp.put("telephonenumber", TELEPHONE_NUMBER);
    DefaultLookUp.put("name", NAME);
  }
}

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.bouncycastle.asn1.x500.style.BCStyle
 * JD-Core Version:    0.6.0
 */