package org.bouncycastle.asn1.x509;

import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;
import org.apache.commons.codec.binary.StringUtils;
import org.bouncycastle.asn1.ASN1Encodable;
import org.bouncycastle.asn1.ASN1EncodableVector;
import org.bouncycastle.asn1.ASN1Object;
import org.bouncycastle.asn1.ASN1Sequence;
import org.bouncycastle.asn1.ASN1Set;
import org.bouncycastle.asn1.ASN1StreamParser;
import org.bouncycastle.asn1.DEREncodable;
import org.bouncycastle.asn1.DERObject;
import org.bouncycastle.asn1.DERObjectIdentifier;
import org.bouncycastle.asn1.DERSequence;
import org.bouncycastle.asn1.DERSet;
import org.bouncycastle.asn1.DERString;
import org.bouncycastle.asn1.pkcs.PKCSObjectIdentifiers;
import org.bouncycastle.asn1.x500.X500Name;
import org.bouncycastle.util.encoders.Hex;

/** @deprecated */
public final class X509Name extends ASN1Encodable
{
  public static final DERObjectIdentifier C = new DERObjectIdentifier("2.5.4.6");
  public static final DERObjectIdentifier O = new DERObjectIdentifier("2.5.4.10");
  public static final DERObjectIdentifier OU = new DERObjectIdentifier("2.5.4.11");
  private static DERObjectIdentifier T = new DERObjectIdentifier("2.5.4.12");
  public static final DERObjectIdentifier CN = new DERObjectIdentifier("2.5.4.3");
  public static final DERObjectIdentifier SN = new DERObjectIdentifier("2.5.4.5");
  private static DERObjectIdentifier STREET = new DERObjectIdentifier("2.5.4.9");
  public static final DERObjectIdentifier L = new DERObjectIdentifier("2.5.4.7");
  public static final DERObjectIdentifier ST = new DERObjectIdentifier("2.5.4.8");
  private static DERObjectIdentifier SURNAME = new DERObjectIdentifier("2.5.4.4");
  private static DERObjectIdentifier GIVENNAME = new DERObjectIdentifier("2.5.4.42");
  private static DERObjectIdentifier INITIALS = new DERObjectIdentifier("2.5.4.43");
  private static DERObjectIdentifier GENERATION = new DERObjectIdentifier("2.5.4.44");
  private static DERObjectIdentifier UNIQUE_IDENTIFIER = new DERObjectIdentifier("2.5.4.45");
  private static DERObjectIdentifier BUSINESS_CATEGORY = new DERObjectIdentifier("2.5.4.15");
  private static DERObjectIdentifier POSTAL_CODE = new DERObjectIdentifier("2.5.4.17");
  public static final DERObjectIdentifier DN_QUALIFIER = new DERObjectIdentifier("2.5.4.46");
  private static DERObjectIdentifier PSEUDONYM = new DERObjectIdentifier("2.5.4.65");
  public static final DERObjectIdentifier DATE_OF_BIRTH = new DERObjectIdentifier("1.3.6.1.5.5.7.9.1");
  private static DERObjectIdentifier PLACE_OF_BIRTH = new DERObjectIdentifier("1.3.6.1.5.5.7.9.2");
  private static DERObjectIdentifier GENDER = new DERObjectIdentifier("1.3.6.1.5.5.7.9.3");
  private static DERObjectIdentifier COUNTRY_OF_CITIZENSHIP = new DERObjectIdentifier("1.3.6.1.5.5.7.9.4");
  private static DERObjectIdentifier COUNTRY_OF_RESIDENCE = new DERObjectIdentifier("1.3.6.1.5.5.7.9.5");
  private static DERObjectIdentifier NAME_AT_BIRTH = new DERObjectIdentifier("1.3.36.8.3.14");
  private static DERObjectIdentifier POSTAL_ADDRESS = new DERObjectIdentifier("2.5.4.16");
  public static final DERObjectIdentifier TELEPHONE_NUMBER;
  private static DERObjectIdentifier NAME;
  public static final DERObjectIdentifier EmailAddress;
  private static DERObjectIdentifier UnstructuredName;
  private static DERObjectIdentifier UnstructuredAddress;
  public static final DERObjectIdentifier E;
  public static final DERObjectIdentifier DC;
  private static DERObjectIdentifier UID;
  private static boolean DefaultReverse;
  private static Hashtable DefaultSymbols;
  private static Hashtable RFC2253Symbols;
  private static Hashtable RFC1779Symbols;
  private static Hashtable DefaultLookUp;
  private static final Boolean TRUE;
  private static final Boolean FALSE;
  private X509NameEntryConverter converter = null;
  private Vector ordering = new Vector();
  private Vector values = new Vector();
  private Vector added = new Vector();
  private ASN1Sequence seq;
  private boolean isHashCodeCalculated;
  private int hashCodeValue;

  protected X509Name()
  {
  }

  private X509Name(ASN1Sequence paramASN1Sequence)
  {
    this.seq = paramASN1Sequence;
    paramASN1Sequence = paramASN1Sequence.getObjects();
    if (paramASN1Sequence.hasMoreElements())
    {
      ASN1Set localASN1Set = ASN1Set.getInstance(((DEREncodable)paramASN1Sequence.nextElement()).getDERObject());
      int i = 0;
      if (i < localASN1Set.size())
      {
        ASN1Sequence localASN1Sequence;
        if ((localASN1Sequence = ASN1Sequence.getInstance(localASN1Set.getObjectAt(i))).size() != 2)
          throw new IllegalArgumentException("badly sized pair");
        DEREncodable localDEREncodable;
        throw (((localDEREncodable = localASN1Sequence.getObjectAt(0)) == null) || ((localDEREncodable instanceof DERObjectIdentifier)) ? (DERObjectIdentifier)localDEREncodable : new IllegalArgumentException("illegal object in getInstance: " + localDEREncodable.getClass().getName()));
      }
    }
  }

  public X509Name(String paramString)
  {
    this(false, DefaultLookUp, paramString);
  }

  private X509Name(boolean paramBoolean, Hashtable paramHashtable, String paramString)
  {
    this(paramBoolean, paramHashtable, paramString, new X509DefaultEntryConverter());
  }

  private static DERObjectIdentifier decodeOID(String paramString, Hashtable paramHashtable)
  {
    String str = paramString;
    int i = 0;
    char[] arrayOfChar = str.toCharArray();
    for (int j = 0; j != arrayOfChar.length; j++)
    {
      int k = arrayOfChar[j];
      if ((97 > k) || (122 < k))
        continue;
      i = 1;
      arrayOfChar[j] = (char)(k - 97 + 65);
    }
    if ((i != 0 ? new String(arrayOfChar) : str).startsWith("OID."))
      return new DERObjectIdentifier(paramString.substring(4));
    if ((paramString.charAt(0) >= '0') && (paramString.charAt(0) <= '9'))
      return new DERObjectIdentifier(paramString);
    if ((paramHashtable = (DERObjectIdentifier)paramHashtable.get(ASN1StreamParser.toLowerCase(paramString))) == null)
      throw new IllegalArgumentException("Unknown object id - " + paramString + " - passed to distinguished name");
    return paramHashtable;
  }

  private X509Name(boolean paramBoolean, Hashtable paramHashtable, String paramString, X509NameEntryConverter paramX509NameEntryConverter)
  {
    this.converter = paramX509NameEntryConverter;
    paramString = new StringUtils(paramString);
    Object localObject;
    while (paramString.hasMoreTokens())
    {
      int i;
      if ((i = (paramX509NameEntryConverter = paramString.nextToken()).indexOf('=')) == -1)
        throw new IllegalArgumentException("badly formated directory string");
      String str1 = paramX509NameEntryConverter.substring(0, i);
      String str2 = paramX509NameEntryConverter.substring(i + 1);
      DERObjectIdentifier localDERObjectIdentifier = decodeOID(str1, paramHashtable);
      if (str2.indexOf('+') > 0)
      {
        localObject = (paramX509NameEntryConverter = new StringUtils(str2, '+')).nextToken();
        this.ordering.addElement(localDERObjectIdentifier);
        this.values.addElement(localObject);
        this.added.addElement(FALSE);
        while (paramX509NameEntryConverter.hasMoreTokens())
        {
          int j = (localObject = paramX509NameEntryConverter.nextToken()).indexOf('=');
          str2 = ((String)localObject).substring(0, j);
          localObject = ((String)localObject).substring(j + 1);
          this.ordering.addElement(decodeOID(str2, paramHashtable));
          this.values.addElement(localObject);
          this.added.addElement(TRUE);
        }
        continue;
      }
      this.ordering.addElement(localDERObjectIdentifier);
      this.values.addElement(str2);
      this.added.addElement(FALSE);
    }
    if (paramBoolean)
    {
      paramX509NameEntryConverter = new Vector();
      localObject = new Vector();
      Vector localVector = new Vector();
      int k = 1;
      for (int m = 0; m < this.ordering.size(); m++)
        if (((Boolean)this.added.elementAt(m)).booleanValue())
        {
          paramX509NameEntryConverter.insertElementAt(this.ordering.elementAt(m), k);
          ((Vector)localObject).insertElementAt(this.values.elementAt(m), k);
          localVector.insertElementAt(this.added.elementAt(m), k);
          k++;
        }
        else
        {
          paramX509NameEntryConverter.insertElementAt(this.ordering.elementAt(m), 0);
          ((Vector)localObject).insertElementAt(this.values.elementAt(m), 0);
          localVector.insertElementAt(this.added.elementAt(m), 0);
          k = 1;
        }
      this.ordering = paramX509NameEntryConverter;
      this.values = ((Vector)localObject);
      this.added = localVector;
    }
  }

  public final Vector getOIDs()
  {
    Vector localVector = new Vector();
    for (int i = 0; i != this.ordering.size(); i++)
      localVector.addElement(this.ordering.elementAt(i));
    return localVector;
  }

  public final Vector getValues()
  {
    Vector localVector = new Vector();
    for (int i = 0; i != this.values.size(); i++)
      localVector.addElement(this.values.elementAt(i));
    return localVector;
  }

  public final DERObject toASN1Object()
  {
    if (this.seq == null)
    {
      ASN1EncodableVector localASN1EncodableVector1 = new ASN1EncodableVector();
      ASN1EncodableVector localASN1EncodableVector2 = new ASN1EncodableVector();
      Object localObject = null;
      for (int i = 0; i != this.ordering.size(); i++)
      {
        ASN1EncodableVector localASN1EncodableVector3 = new ASN1EncodableVector();
        DERObjectIdentifier localDERObjectIdentifier = (DERObjectIdentifier)this.ordering.elementAt(i);
        localASN1EncodableVector3.add(localDERObjectIdentifier);
        String str = (String)this.values.elementAt(i);
        localASN1EncodableVector3.add(this.converter.getConvertedValue(localDERObjectIdentifier, str));
        if ((localObject == null) || (((Boolean)this.added.elementAt(i)).booleanValue()))
        {
          localASN1EncodableVector2.add(new DERSequence(localASN1EncodableVector3));
        }
        else
        {
          localASN1EncodableVector1.add(new DERSet(localASN1EncodableVector2));
          (localASN1EncodableVector2 = new ASN1EncodableVector()).add(new DERSequence(localASN1EncodableVector3));
        }
        localObject = localDERObjectIdentifier;
      }
      localASN1EncodableVector1.add(new DERSet(localASN1EncodableVector2));
      this.seq = new DERSequence(localASN1EncodableVector1);
    }
    return this.seq;
  }

  public final int hashCode()
  {
    if (this.isHashCodeCalculated)
      return this.hashCodeValue;
    this.isHashCodeCalculated = true;
    for (int i = 0; i != this.ordering.size(); i++)
    {
      String str = (String)this.values.elementAt(i);
      str = stripInternalSpaces(str = canonicalize(str));
      this.hashCodeValue ^= this.ordering.elementAt(i).hashCode();
      this.hashCodeValue ^= str.hashCode();
    }
    return this.hashCodeValue;
  }

  public final boolean equals(Object paramObject)
  {
    if (paramObject == this)
      return true;
    if ((!(paramObject instanceof X509Name)) && (!(paramObject instanceof ASN1Sequence)))
      return false;
    DERObject localDERObject = ((DEREncodable)paramObject).getDERObject();
    if (getDERObject().equals(localDERObject))
      return true;
    Object localObject1;
    try
    {
      paramObject = localObject1 != null ? new X509Name(ASN1Sequence.getInstance(localObject1)) : (localObject1 instanceof X500Name) ? new X509Name(ASN1Sequence.getInstance(((X500Name)localObject1).getDERObject())) : ((localObject1 = paramObject) == null) || ((localObject1 instanceof X509Name)) ? (X509Name)localObject1 : null;
    }
    catch (IllegalArgumentException localIllegalArgumentException)
    {
      return false;
    }
    int i;
    if ((i = this.ordering.size()) != paramObject.ordering.size())
      return false;
    boolean[] arrayOfBoolean = new boolean[i];
    int k;
    int m;
    if (this.ordering.elementAt(0).equals(paramObject.ordering.elementAt(0)))
    {
      j = 0;
      k = i;
      m = 1;
    }
    else
    {
      j = i - 1;
      k = -1;
      m = -1;
    }
    int j = j;
    while (j != k)
    {
      int n = 0;
      DERObjectIdentifier localDERObjectIdentifier = (DERObjectIdentifier)this.ordering.elementAt(j);
      String str1 = (String)this.values.elementAt(j);
      for (int i1 = 0; i1 < i; i1++)
      {
        if (arrayOfBoolean[i1] != 0)
          continue;
        localObject1 = (DERObjectIdentifier)paramObject.ordering.elementAt(i1);
        if (!localDERObjectIdentifier.equals(localObject1))
          continue;
        localObject1 = (String)paramObject.values.elementAt(i1);
        Object localObject2 = localObject1;
        String str2 = str1;
        localObject1 = this;
        str2 = canonicalize(str2);
        localObject1 = ((X509Name)localObject1).canonicalize(localObject2);
        if (!str2.equals(localObject1))
        {
          str2 = stripInternalSpaces(str2);
          localObject1 = stripInternalSpaces((String)localObject1);
        }
        if ((!str2.equals(localObject1) ? 0 : 1) == 0)
          continue;
        arrayOfBoolean[i1] = true;
        n = 1;
        break;
      }
      if (n == 0)
        return false;
      j += m;
    }
    return true;
  }

  private String canonicalize(String paramString)
  {
    if (((this = ASN1StreamParser.toLowerCase(paramString.trim())).length() > 0) && (charAt(0) == '#') && (((paramString = decodeObject(this)) instanceof DERString)))
      this = ASN1StreamParser.toLowerCase(((DERString)paramString).getString().trim());
    return this;
  }

  private static ASN1Object decodeObject(String paramString)
  {
    try
    {
      return ASN1Object.fromByteArray(Hex.decode(paramString.substring(1)));
    }
    catch (java.io.IOException paramString)
    {
    }
    throw new IllegalStateException("unknown encoding in name: " + paramString);
  }

  private static String stripInternalSpaces(String paramString)
  {
    StringBuffer localStringBuffer = new StringBuffer();
    if (paramString.length() != 0)
    {
      char c1 = paramString.charAt(0);
      localStringBuffer.append(c1);
      for (int i = 1; i < paramString.length(); i++)
      {
        char c2 = paramString.charAt(i);
        if ((c1 != ' ') || (c2 != ' '))
          localStringBuffer.append(c2);
        c1 = c2;
      }
    }
    return localStringBuffer.toString();
  }

  private static void appendValue(StringBuffer paramStringBuffer, Hashtable paramHashtable, DERObjectIdentifier paramDERObjectIdentifier, String paramString)
  {
    if ((paramHashtable = (String)paramHashtable.get(paramDERObjectIdentifier)) != null)
      paramStringBuffer.append(paramHashtable);
    else
      paramStringBuffer.append(paramDERObjectIdentifier.getId());
    paramStringBuffer.append('=');
    paramHashtable = paramStringBuffer.length();
    paramStringBuffer.append(paramString);
    paramDERObjectIdentifier = paramStringBuffer.length();
    if ((paramString.length() >= 2) && (paramString.charAt(0) == '\\') && (paramString.charAt(1) == '#'))
      paramHashtable += 2;
    while (paramHashtable != paramDERObjectIdentifier)
    {
      if ((paramStringBuffer.charAt(paramHashtable) == ',') || (paramStringBuffer.charAt(paramHashtable) == '"') || (paramStringBuffer.charAt(paramHashtable) == '\\') || (paramStringBuffer.charAt(paramHashtable) == '+') || (paramStringBuffer.charAt(paramHashtable) == '=') || (paramStringBuffer.charAt(paramHashtable) == '<') || (paramStringBuffer.charAt(paramHashtable) == '>') || (paramStringBuffer.charAt(paramHashtable) == ';'))
      {
        paramStringBuffer.insert(paramHashtable, "\\");
        paramHashtable++;
        paramDERObjectIdentifier++;
      }
      paramHashtable++;
    }
  }

  private static String bytesToString(byte[] paramArrayOfByte)
  {
    char[] arrayOfChar = new char[paramArrayOfByte.length];
    for (int i = 0; i != arrayOfChar.length; i++)
      arrayOfChar[i] = (char)(paramArrayOfByte[i] & 0xFF);
    return new String(arrayOfChar);
  }

  public final String toString()
  {
    Hashtable localHashtable = DefaultSymbols;
    int i = 0;
    this = this;
    StringBuffer localStringBuffer1 = new StringBuffer();
    Vector localVector = new Vector();
    int j = 1;
    StringBuffer localStringBuffer2 = null;
    for (int k = 0; k < this.ordering.size(); k++)
      if (((Boolean)this.added.elementAt(k)).booleanValue())
      {
        localStringBuffer2.append('+');
        appendValue(localStringBuffer2, localHashtable, (DERObjectIdentifier)this.ordering.elementAt(k), (String)this.values.elementAt(k));
      }
      else
      {
        appendValue(localStringBuffer2 = new StringBuffer(), localHashtable, (DERObjectIdentifier)this.ordering.elementAt(k), (String)this.values.elementAt(k));
        localVector.addElement(localStringBuffer2);
      }
    if (i != 0)
      for (k = localVector.size() - 1; k >= 0; k--)
      {
        if (j != 0)
          j = 0;
        else
          localStringBuffer1.append(',');
        localStringBuffer1.append(localVector.elementAt(k).toString());
      }
    else
      for (k = 0; k < localVector.size(); k++)
      {
        if (j != 0)
          j = 0;
        else
          localStringBuffer1.append(',');
        localStringBuffer1.append(localVector.elementAt(k).toString());
      }
    return localStringBuffer1.toString();
  }

  static
  {
    new DERObjectIdentifier("2.5.4.54");
    TELEPHONE_NUMBER = X509ObjectIdentifiers.id_at_telephoneNumber;
    NAME = X509ObjectIdentifiers.id_at_name;
    EmailAddress = PKCSObjectIdentifiers.pkcs_9_at_emailAddress;
    UnstructuredName = PKCSObjectIdentifiers.pkcs_9_at_unstructuredName;
    UnstructuredAddress = PKCSObjectIdentifiers.pkcs_9_at_unstructuredAddress;
    E = EmailAddress;
    DC = new DERObjectIdentifier("0.9.2342.19200300.100.1.25");
    UID = new DERObjectIdentifier("0.9.2342.19200300.100.1.1");
    DefaultReverse = false;
    DefaultSymbols = new Hashtable();
    RFC2253Symbols = new Hashtable();
    RFC1779Symbols = new Hashtable();
    DefaultLookUp = new Hashtable();
    TRUE = new Boolean(true);
    FALSE = new Boolean(false);
    DefaultSymbols.put(C, "C");
    DefaultSymbols.put(O, "O");
    DefaultSymbols.put(T, "T");
    DefaultSymbols.put(OU, "OU");
    DefaultSymbols.put(CN, "CN");
    DefaultSymbols.put(L, "L");
    DefaultSymbols.put(ST, "ST");
    DefaultSymbols.put(SN, "SERIALNUMBER");
    DefaultSymbols.put(EmailAddress, "E");
    DefaultSymbols.put(DC, "DC");
    DefaultSymbols.put(UID, "UID");
    DefaultSymbols.put(STREET, "STREET");
    DefaultSymbols.put(SURNAME, "SURNAME");
    DefaultSymbols.put(GIVENNAME, "GIVENNAME");
    DefaultSymbols.put(INITIALS, "INITIALS");
    DefaultSymbols.put(GENERATION, "GENERATION");
    DefaultSymbols.put(UnstructuredAddress, "unstructuredAddress");
    DefaultSymbols.put(UnstructuredName, "unstructuredName");
    DefaultSymbols.put(UNIQUE_IDENTIFIER, "UniqueIdentifier");
    DefaultSymbols.put(DN_QUALIFIER, "DN");
    DefaultSymbols.put(PSEUDONYM, "Pseudonym");
    DefaultSymbols.put(POSTAL_ADDRESS, "PostalAddress");
    DefaultSymbols.put(NAME_AT_BIRTH, "NameAtBirth");
    DefaultSymbols.put(COUNTRY_OF_CITIZENSHIP, "CountryOfCitizenship");
    DefaultSymbols.put(COUNTRY_OF_RESIDENCE, "CountryOfResidence");
    DefaultSymbols.put(GENDER, "Gender");
    DefaultSymbols.put(PLACE_OF_BIRTH, "PlaceOfBirth");
    DefaultSymbols.put(DATE_OF_BIRTH, "DateOfBirth");
    DefaultSymbols.put(POSTAL_CODE, "PostalCode");
    DefaultSymbols.put(BUSINESS_CATEGORY, "BusinessCategory");
    DefaultSymbols.put(TELEPHONE_NUMBER, "TelephoneNumber");
    DefaultSymbols.put(NAME, "Name");
    RFC2253Symbols.put(C, "C");
    RFC2253Symbols.put(O, "O");
    RFC2253Symbols.put(OU, "OU");
    RFC2253Symbols.put(CN, "CN");
    RFC2253Symbols.put(L, "L");
    RFC2253Symbols.put(ST, "ST");
    RFC2253Symbols.put(STREET, "STREET");
    RFC2253Symbols.put(DC, "DC");
    RFC2253Symbols.put(UID, "UID");
    RFC1779Symbols.put(C, "C");
    RFC1779Symbols.put(O, "O");
    RFC1779Symbols.put(OU, "OU");
    RFC1779Symbols.put(CN, "CN");
    RFC1779Symbols.put(L, "L");
    RFC1779Symbols.put(ST, "ST");
    RFC1779Symbols.put(STREET, "STREET");
    DefaultLookUp.put("c", C);
    DefaultLookUp.put("o", O);
    DefaultLookUp.put("t", T);
    DefaultLookUp.put("ou", OU);
    DefaultLookUp.put("cn", CN);
    DefaultLookUp.put("l", L);
    DefaultLookUp.put("st", ST);
    DefaultLookUp.put("sn", SN);
    DefaultLookUp.put("serialnumber", SN);
    DefaultLookUp.put("street", STREET);
    DefaultLookUp.put("emailaddress", E);
    DefaultLookUp.put("dc", DC);
    DefaultLookUp.put("e", E);
    DefaultLookUp.put("uid", UID);
    DefaultLookUp.put("surname", SURNAME);
    DefaultLookUp.put("givenname", GIVENNAME);
    DefaultLookUp.put("initials", INITIALS);
    DefaultLookUp.put("generation", GENERATION);
    DefaultLookUp.put("unstructuredaddress", UnstructuredAddress);
    DefaultLookUp.put("unstructuredname", UnstructuredName);
    DefaultLookUp.put("uniqueidentifier", UNIQUE_IDENTIFIER);
    DefaultLookUp.put("dn", DN_QUALIFIER);
    DefaultLookUp.put("pseudonym", PSEUDONYM);
    DefaultLookUp.put("postaladdress", POSTAL_ADDRESS);
    DefaultLookUp.put("nameofbirth", NAME_AT_BIRTH);
    DefaultLookUp.put("countryofcitizenship", COUNTRY_OF_CITIZENSHIP);
    DefaultLookUp.put("countryofresidence", COUNTRY_OF_RESIDENCE);
    DefaultLookUp.put("gender", GENDER);
    DefaultLookUp.put("placeofbirth", PLACE_OF_BIRTH);
    DefaultLookUp.put("dateofbirth", DATE_OF_BIRTH);
    DefaultLookUp.put("postalcode", POSTAL_CODE);
    DefaultLookUp.put("businesscategory", BUSINESS_CATEGORY);
    DefaultLookUp.put("telephonenumber", TELEPHONE_NUMBER);
    DefaultLookUp.put("name", NAME);
  }
}

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.bouncycastle.asn1.x509.X509Name
 * JD-Core Version:    0.6.0
 */