/*     */ package com.scytl.pnyx.client.state.automaton;
/*     */ 
/*     */ import com.scytl.common.domain.MessageType;
/*     */ import com.scytl.common.domain.election.ElectoralScope;
/*     */ import com.scytl.common.domain.election.ballot.QuestionAnswer;
/*     */ import com.scytl.pnyx.client.communication.application.ApplicationProtocolException;
/*     */ import com.scytl.pnyx.client.communication.connector.ProtocolConnector;
/*     */ import com.scytl.pnyx.client.state.LoginData;
/*     */ import com.scytl.pnyx.protocol.PnyxProtocolException;
/*     */ import java.util.Map;
/*     */ import java.util.concurrent.locks.Lock;
/*     */ import java.util.concurrent.locks.ReentrantLock;
/*     */ 
/*     */ public class PnyxClientStateMachine
/*     */   implements LocalActions, RemoteActions
/*     */ {
/*     */   private WizardState UNAUTHENTICATED;
/*     */   private WizardState IDENTIFIED;
/*     */   private WizardState HAS_TOKEN;
/*     */   private WizardState HAS_BALLOT;
/*     */   private WizardState VOTE_VALIDATED;
/*     */   private WizardState VOTE_CAST;
/*     */   private WizardState _currentState;
/* 136 */   private final Lock _lock = new ReentrantLock(true);
/*     */   private ProtocolConnector _connector;
/*     */ 
/*     */   public PnyxClientStateMachine()
/*     */   {
/* 139 */     this.UNAUTHENTICATED = null;
/* 140 */     this.IDENTIFIED = null;
/* 141 */     this.HAS_TOKEN = null;
/* 142 */     this.HAS_BALLOT = null;
/* 143 */     this.VOTE_VALIDATED = null;
/* 144 */     this.VOTE_CAST = null;
/*     */   }
/*     */ 
/*     */   public void init() {
/* 148 */     this.UNAUTHENTICATED = new UnauthenticatedState(this._connector);
/* 149 */     this.IDENTIFIED = new IdentifiedState(this._connector);
/* 150 */     this.HAS_TOKEN = new HasTokenState(this._connector);
/* 151 */     this.HAS_BALLOT = new HasBallotState(this._connector);
/* 152 */     this.VOTE_VALIDATED = new VoteValidatedState(this._connector);
/* 153 */     this.VOTE_CAST = new VoteCastState(this._connector);
/* 154 */     this._currentState = this.UNAUTHENTICATED;
/*     */   }
/*     */ 
/*     */   public void setProtocolConnector(ProtocolConnector connector)
/*     */   {
/* 160 */     this._connector = connector;
/*     */   }
/*     */ 
/*     */   public PnyxClientStateMachine(ProtocolConnector connector) {
/* 164 */     this._connector = connector;
/* 165 */     init();
/*     */   }
/*     */ 
/*     */   private void setState(WizardState state)
/*     */   {
/* 172 */     this._currentState.leave();
/* 173 */     this._currentState = state;
/* 174 */     this._currentState.enter();
/*     */   }
/*     */ 
/*     */   public void login(LoginData paramLoginData, ElectoralScope paramElectoralScope)
/*     */     throws ApplicationProtocolException, PnyxProtocolException
/*     */   {
/* 183 */     this._lock.lock();
/*     */     try { this._currentState.login(paramLoginData, paramElectoralScope);
/* 186 */       setState(this.IDENTIFIED);
/*     */       return; } finally { this._lock.unlock(); } throw paramLoginData;
/*     */   }
/*     */ 
/*     */   public void logout()
/*     */     throws PnyxProtocolException
/*     */   {
/* 196 */     this._lock.lock();
/*     */     try { this._currentState.logout();
/* 199 */       setState(this.UNAUTHENTICATED);
/*     */       return; } finally { this._lock.unlock(); } throw localObject;
/*     */   }
/*     */ 
/*     */   public void discardElection()
/*     */     throws PnyxProtocolException, ApplicationProtocolException
/*     */   {
/* 210 */     this._lock.lock();
/*     */     try { this._currentState.discardElection();
/* 213 */       setState(this.IDENTIFIED);
/*     */       return; } finally { this._lock.unlock(); } throw localObject;
/*     */   }
/*     */ 
/*     */   public void pickElection(ElectoralScope paramElectoralScope)
/*     */     throws ApplicationProtocolException, PnyxProtocolException
/*     */   {
/* 224 */     this._lock.lock();
/*     */     try { this._currentState.pickElection(paramElectoralScope);
/* 227 */       setState(this.HAS_TOKEN);
/*     */       return; } finally { this._lock.unlock(); } throw paramElectoralScope;
/*     */   }
/*     */ 
/*     */   public void produceBallot(MessageType paramMessageType)
/*     */     throws ApplicationProtocolException, PnyxProtocolException
/*     */   {
/* 239 */     this._lock.lock();
/*     */     try { this._currentState.produceBallot(paramMessageType);
/* 242 */       setState(this.HAS_BALLOT);
/*     */       return; } finally { this._lock.unlock(); } throw paramMessageType;
/*     */   }
/*     */ 
/*     */   public void validateVote(Map<String, QuestionAnswer> paramMap)
/*     */     throws PnyxProtocolException
/*     */   {
/* 254 */     this._lock.lock();
/*     */     try { this._currentState.validateVote(paramMap);
/* 257 */       setState(this.VOTE_VALIDATED);
/*     */       return; } finally { this._lock.unlock(); } throw paramMap;
/*     */   }
/*     */ 
/*     */   public void discardVote() throws PnyxProtocolException
/*     */   {
/* 264 */     this._lock.lock();
/*     */     try { this._currentState.discardVote();
/* 267 */       setState(this.HAS_BALLOT);
/*     */       return; } finally { this._lock.unlock(); } throw localObject;
/*     */   }
/*     */ 
/*     */   public void castVote()
/*     */     throws ApplicationProtocolException, PnyxProtocolException
/*     */   {
/* 275 */     this._lock.lock();
/*     */     try { this._currentState.castVote();
/* 278 */       setState(this.VOTE_CAST);
/*     */       return; } finally { this._lock.unlock(); } throw localObject;
/*     */   }
/*     */ 
/*     */   public void nextElection()
/*     */     throws PnyxProtocolException, ApplicationProtocolException
/*     */   {
/* 289 */     this._lock.lock();
/*     */     try { this._currentState.nextElection();
/* 292 */       setState(this.HAS_BALLOT);
/*     */       return; } finally { this._lock.unlock(); } throw localObject;
/*     */   }
/*     */ }

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     com.scytl.pnyx.client.state.automaton.PnyxClientStateMachine
 * JD-Core Version:    0.6.0
 */