/*     */ package org.apache.commons.codec.binary;
/*     */ 
/*     */ public final class Base64 extends BaseNCodec
/*     */ {
/*  71 */   private static byte[] CHUNK_SEPARATOR = { 13, 10 };
/*     */ 
/*  80 */   private static final byte[] STANDARD_ENCODE_TABLE = { 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 43, 47 };
/*     */ 
/*  93 */   private static final byte[] URL_SAFE_ENCODE_TABLE = { 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 45, 95 };
/*     */ 
/* 112 */   private static final byte[] DECODE_TABLE = { -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 62, -1, 62, -1, 63, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, -1, -1, -1, -1, -1, -1, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, -1, -1, -1, -1, 63, -1, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51 };
/*     */   private final byte[] encodeTable;
/* 140 */   private final byte[] decodeTable = DECODE_TABLE;
/*     */   private final byte[] lineSeparator;
/*     */   private final int decodeSize;
/*     */   private final int encodeSize;
/*     */   private int bitWorkArea;
/*     */ 
/*     */   public Base64()
/*     */   {
/* 176 */     this(0);
/*     */   }
/*     */ 
/*     */   private Base64(boolean urlSafe)
/*     */   {
/* 195 */     this(76, CHUNK_SEPARATOR, urlSafe);
/*     */   }
/*     */ 
/*     */   private Base64(int lineLength)
/*     */   {
/* 217 */     this(0, CHUNK_SEPARATOR);
/*     */   }
/*     */ 
/*     */   private Base64(int lineLength, byte[] lineSeparator)
/*     */   {
/* 243 */     this(lineLength, lineSeparator, false);
/*     */   }
/*     */ 
/*     */   private Base64(int paramInt, byte[] paramArrayOfByte, boolean paramBoolean)
/*     */   {
/* 272 */     super(3, 4, paramInt, paramArrayOfByte == null ? 0 : paramArrayOfByte.length);
/*     */ 
/* 277 */     if (paramArrayOfByte != null) {
/* 278 */       if (containsAlphabetOrPad(paramArrayOfByte)) {
/* 279 */         this = StringUtils.newString(this = paramArrayOfByte, "UTF-8");
/* 280 */         throw new IllegalArgumentException("lineSeparator must not contain base64 characters: [" + this + "]");
/*     */       }
/* 282 */       if (paramInt > 0) {
/* 283 */         this.encodeSize = (4 + paramArrayOfByte.length);
/* 284 */         this.lineSeparator = new byte[paramArrayOfByte.length];
/* 285 */         System.arraycopy(paramArrayOfByte, 0, this.lineSeparator, 0, paramArrayOfByte.length);
/*     */       } else {
/* 287 */         this.encodeSize = 4;
/* 288 */         this.lineSeparator = null;
/*     */       }
/*     */     } else {
/* 291 */       this.encodeSize = 4;
/* 292 */       this.lineSeparator = null;
/*     */     }
/* 294 */     this.decodeSize = (this.encodeSize - 1);
/* 295 */     this.encodeTable = (paramBoolean ? URL_SAFE_ENCODE_TABLE : STANDARD_ENCODE_TABLE);
/*     */   }
/*     */ 
/*     */   final void encode(byte[] paramArrayOfByte, int paramInt1, int paramInt2)
/*     */   {
/* 328 */     if (this.eof) {
/* 329 */       return;
/*     */     }
/*     */ 
/* 333 */     if (paramInt2 < 0) {
/* 334 */       this.eof = true;
/* 335 */       if ((this.modulus == 0) && (this.lineLength == 0)) {
/* 336 */         return;
/*     */       }
/* 338 */       ensureBufferSize(this.encodeSize);
/* 339 */       i = this.pos;
/* 340 */       switch (this.modulus) {
/*     */       case 1:
/* 342 */         this.buffer[(this.pos++)] = this.encodeTable[(this.bitWorkArea >> 2 & 0x3F)];
/* 343 */         this.buffer[(this.pos++)] = this.encodeTable[(this.bitWorkArea << 4 & 0x3F)];
/*     */ 
/* 345 */         if (this.encodeTable != STANDARD_ENCODE_TABLE) break;
/* 346 */         this.buffer[(this.pos++)] = 61;
/* 347 */         this.buffer[(this.pos++)] = 61; break;
/*     */       case 2:
/* 352 */         this.buffer[(this.pos++)] = this.encodeTable[(this.bitWorkArea >> 10 & 0x3F)];
/* 353 */         this.buffer[(this.pos++)] = this.encodeTable[(this.bitWorkArea >> 4 & 0x3F)];
/* 354 */         this.buffer[(this.pos++)] = this.encodeTable[(this.bitWorkArea << 2 & 0x3F)];
/*     */ 
/* 356 */         if (this.encodeTable != STANDARD_ENCODE_TABLE) break;
/* 357 */         this.buffer[(this.pos++)] = 61;
/*     */       }
/*     */ 
/* 361 */       this.currentLinePos += this.pos - i;
/*     */ 
/* 363 */       if ((this.lineLength > 0) && (this.currentLinePos > 0)) {
/* 364 */         System.arraycopy(this.lineSeparator, 0, this.buffer, this.pos, this.lineSeparator.length);
/* 365 */         this.pos += this.lineSeparator.length;
/*     */       }
/* 367 */       return;
/* 368 */     }for (int i = 0; i < paramInt2; i++) {
/* 369 */       ensureBufferSize(this.encodeSize);
/* 370 */       this.modulus = ((this.modulus + 1) % 3);
/*     */       int j;
/* 372 */       if ((
/* 372 */         j = paramArrayOfByte[(paramInt1++)]) < 0)
/*     */       {
/* 373 */         j += 256;
/*     */       }
/* 375 */       this.bitWorkArea = ((this.bitWorkArea << 8) + j);
/* 376 */       if (this.modulus == 0) {
/* 377 */         this.buffer[(this.pos++)] = this.encodeTable[(this.bitWorkArea >> 18 & 0x3F)];
/* 378 */         this.buffer[(this.pos++)] = this.encodeTable[(this.bitWorkArea >> 12 & 0x3F)];
/* 379 */         this.buffer[(this.pos++)] = this.encodeTable[(this.bitWorkArea >> 6 & 0x3F)];
/* 380 */         this.buffer[(this.pos++)] = this.encodeTable[(this.bitWorkArea & 0x3F)];
/* 381 */         this.currentLinePos += 4;
/* 382 */         if ((this.lineLength > 0) && (this.lineLength <= this.currentLinePos)) {
/* 383 */           System.arraycopy(this.lineSeparator, 0, this.buffer, this.pos, this.lineSeparator.length);
/* 384 */           this.pos += this.lineSeparator.length;
/* 385 */           this.currentLinePos = 0;
/*     */         }
/*     */       }
/*     */     }
/*     */   }
/*     */ 
/*     */   final void decode(byte[] paramArrayOfByte, int paramInt1, int paramInt2)
/*     */   {
/* 417 */     if (this.eof) {
/* 418 */       return;
/*     */     }
/* 420 */     if (paramInt2 < 0) {
/* 421 */       this.eof = true;
/*     */     }
/* 423 */     for (int i = 0; i < paramInt2; i++) {
/* 424 */       ensureBufferSize(this.decodeSize);
/*     */       int j;
/* 426 */       if ((
/* 426 */         j = paramArrayOfByte[(paramInt1++)]) == 
/* 426 */         61)
/*     */       {
/* 428 */         this.eof = true;
/* 429 */         break;
/*     */       }
/* 431 */       if ((j < 0) || (j >= DECODE_TABLE.length))
/*     */         continue;
/* 433 */       if ((
/* 433 */         j = DECODE_TABLE[j]) >= 0)
/*     */       {
/* 434 */         this.modulus = ((this.modulus + 1) % 4);
/* 435 */         this.bitWorkArea = ((this.bitWorkArea << 6) + j);
/* 436 */         if (this.modulus == 0) {
/* 437 */           this.buffer[(this.pos++)] = (byte)(this.bitWorkArea >> 16);
/* 438 */           this.buffer[(this.pos++)] = (byte)(this.bitWorkArea >> 8);
/* 439 */           this.buffer[(this.pos++)] = (byte)this.bitWorkArea;
/*     */         }
/*     */ 
/*     */       }
/*     */ 
/*     */     }
/*     */ 
/* 449 */     if ((this.eof) && (this.modulus != 0)) {
/* 450 */       ensureBufferSize(this.decodeSize);
/*     */ 
/* 454 */       switch (this.modulus)
/*     */       {
/*     */       case 2:
/* 458 */         this.bitWorkArea >>= 4;
/* 459 */         this.buffer[(this.pos++)] = (byte)this.bitWorkArea;
/* 460 */         return;
/*     */       case 3:
/* 462 */         this.bitWorkArea >>= 2;
/* 463 */         this.buffer[(this.pos++)] = (byte)(this.bitWorkArea >> 8);
/* 464 */         this.buffer[(this.pos++)] = (byte)this.bitWorkArea;
/*     */       }
/*     */     }
/*     */   }
/*     */ 
/*     */   /** @deprecated */
/*     */   public static boolean isArrayByteBase64(byte[] paramArrayOfByte)
/*     */   {
/* 481 */     paramArrayOfByte = paramArrayOfByte; for (int i = 0; i < paramArrayOfByte.length; i++)
/*     */     {
/* 481 */       int j;
/* 481 */       if ((((j = paramArrayOfByte[i]) == 61) || ((j >= 0) && (j < DECODE_TABLE.length) && (DECODE_TABLE[j] != -1)) ? 1 : 0) != 0) continue; switch (j = paramArrayOfByte[i]) { case 9:
/*     */       case 10:
/*     */       case 13:
/*     */       case 32:
/* 481 */         tmpTernaryOp = 1; break; } if (0 == 0) return false; 
/* 481 */     }return true;
/*     */   }
/*     */ 
/*     */   public static byte[] encodeBase64(byte[] binaryData)
/*     */   {
/* 537 */     return encodeBase64(binaryData, false);
/*     */   }
/*     */ 
/*     */   public static byte[] encodeBase64(byte[] paramArrayOfByte, boolean paramBoolean)
/*     */   {
/* 604 */     paramArrayOfByte = 0; paramBoolean = paramBoolean; paramArrayOfByte = paramArrayOfByte; int i = 2147483647; boolean bool = false; paramBoolean = paramBoolean; paramArrayOfByte = paramArrayOfByte; if ((paramArrayOfByte == null) || (paramArrayOfByte.length == 0)) return paramArrayOfByte;
/* 604 */     long l;
/* 604 */     if ((l = (paramBoolean = paramBoolean ? new Base64(bool) : new Base64(0, CHUNK_SEPARATOR, bool)).getEncodedLength(paramArrayOfByte)) > i) throw new IllegalArgumentException("Input array too big, the output array would be bigger (" + l + ") than the specified maximum size of " + i); return paramBoolean.encode(paramArrayOfByte);
/*     */   }
/*     */ 
/*     */   public static byte[] decodeBase64(String base64String)
/*     */   {
/* 669 */     String str = base64String; return (base64String = new Base64()).decode(StringUtils.getBytesUnchecked(base64String = str, "UTF-8"));
/*     */   }
/*     */ 
/*     */   public static byte[] decodeBase64(byte[] base64Data)
/*     */   {
/* 680 */     return new Base64().decode(base64Data);
/*     */   }
/*     */ 
/*     */   protected final boolean isInAlphabet(byte paramByte)
/*     */   {
/* 755 */     return (paramByte >= 0) && (paramByte < this.decodeTable.length) && (this.decodeTable[paramByte] != -1);
/*     */   }
/*     */ }

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.apache.commons.codec.binary.Base64
 * JD-Core Version:    0.6.0
 */