/*      */ package org.apache.commons.collections.map;
/*      */ 
/*      */ import java.util.AbstractCollection;
/*      */ import java.util.AbstractMap;
/*      */ import java.util.AbstractSet;
/*      */ import java.util.Collection;
/*      */ import java.util.ConcurrentModificationException;
/*      */ import java.util.Iterator;
/*      */ import java.util.Map;
/*      */ import java.util.Map.Entry;
/*      */ import java.util.NoSuchElementException;
/*      */ import java.util.Set;
/*      */ import org.apache.commons.collections.IterableMap;
/*      */ import org.apache.commons.collections.MapIterator;
/*      */ import org.apache.commons.collections.iterators.EmptyIterator;
/*      */ import org.apache.commons.collections.iterators.EmptyMapIterator;
/*      */ 
/*      */ public class AbstractHashedMap extends AbstractMap
/*      */   implements IterableMap
/*      */ {
/*   80 */   protected static final Object NULL = new Object();
/*      */   private transient float loadFactor;
/*      */   protected transient int size;
/*      */   protected transient HashEntry[] data;
/*      */   private transient int threshold;
/*      */   protected transient int modCount;
/*      */   private transient EntrySet entrySet;
/*      */   private transient KeySet keySet;
/*      */   private transient Values values;
/*      */ 
/*      */   protected AbstractHashedMap()
/*      */   {
/*      */   }
/*      */ 
/*      */   protected AbstractHashedMap(int initialCapacity, float loadFactor, int threshold)
/*      */   {
/*  115 */     this.loadFactor = loadFactor;
/*  116 */     this.data = new HashEntry[initialCapacity];
/*  117 */     this.threshold = threshold;
/*  118 */     init();
/*      */   }
/*      */ 
/*      */   protected void init()
/*      */   {
/*      */   }
/*      */ 
/*      */   public Object get(Object paramObject)
/*      */   {
/*  182 */     int i = hash(paramObject = convertKey(paramObject));
/*      */ 
/*  183 */     int j = this.data.length; this = this.data[((this = i) & j - 1)];
/*  184 */     while (this != null) {
/*  185 */       if ((this.hashCode == i) && (isEqualKey(paramObject, this.key))) {
/*  186 */         return getValue();
/*      */       }
/*  188 */       this = this.next;
/*      */     }
/*  190 */     return null;
/*      */   }
/*      */ 
/*      */   public int size()
/*      */   {
/*  199 */     return this.size;
/*      */   }
/*      */ 
/*      */   public boolean isEmpty()
/*      */   {
/*  208 */     return this.size == 0;
/*      */   }
/*      */ 
/*      */   public boolean containsKey(Object paramObject)
/*      */   {
/*  220 */     int i = hash(paramObject = convertKey(paramObject));
/*      */ 
/*  221 */     int j = this.data.length; this = this.data[((this = i) & j - 1)];
/*  222 */     while (this != null) {
/*  223 */       if ((this.hashCode == i) && (isEqualKey(paramObject, this.key))) {
/*  224 */         return true;
/*      */       }
/*  226 */       this = this.next;
/*      */     }
/*  228 */     return false;
/*      */   }
/*      */ 
/*      */   public boolean containsValue(Object paramObject)
/*      */   {
/*      */     int i;
/*      */     int j;
/*      */     HashEntry localHashEntry;
/*  238 */     if (paramObject == null) {
/*  239 */       i = 0; for (j = this.data.length; i < j; i++) {
/*  240 */         localHashEntry = this.data[i];
/*  241 */         while (localHashEntry != null) {
/*  242 */           if (localHashEntry.getValue() == null) {
/*  243 */             return true;
/*      */           }
/*  245 */           localHashEntry = localHashEntry.next;
/*      */         }
/*      */       }
/*      */     } else {
/*  249 */       i = 0; for (j = this.data.length; i < j; i++) {
/*  250 */         localHashEntry = this.data[i];
/*  251 */         while (localHashEntry != null) {
/*  252 */           if (isEqualValue(paramObject, localHashEntry.getValue())) {
/*  253 */             return true;
/*      */           }
/*  255 */           localHashEntry = localHashEntry.next;
/*      */         }
/*      */       }
/*      */     }
/*  259 */     return false;
/*      */   }
/*      */ 
/*      */   public Object put(Object paramObject1, Object paramObject2)
/*      */   {
/*      */     AbstractHashedMap localAbstractHashedMap;
/*  273 */     int i = this.data.length; Object localObject2 = (localObject2 = localAbstractHashedMap = hash(paramObject1 = convertKey(paramObject1))) & 
/*  273 */       i - 1;
/*  274 */     HashEntry localHashEntry = this.data[localObject2];
/*  275 */     while (localHashEntry != null) {
/*  276 */       if ((localHashEntry.hashCode == localAbstractHashedMap) && (isEqualKey(paramObject1, localHashEntry.key))) {
/*  277 */         this = localHashEntry.getValue();
/*  278 */         paramObject2 = paramObject2; (paramObject1 = localHashEntry).setValue(paramObject2);
/*  279 */         return this;
/*      */       }
/*  281 */       localHashEntry = localHashEntry.next;
/*      */     }
/*      */ 
/*  284 */     Object localObject3 = paramObject2; Object localObject1 = paramObject1; this = localAbstractHashedMap; paramObject2 = localObject2; paramObject1 = this; this.modCount += 1; this = paramObject1.createEntry(paramObject1.data[paramObject2], this, localObject1, localObject3); paramObject1.addEntry(this, paramObject2); paramObject1.size += 1; if (((this = paramObject1).size >= this.threshold) && ((paramObject1 = this.data.length << 1) <= 1073741824)) ensureCapacity(paramObject1);
/*  285 */     return null;
/*      */   }
/*      */ 
/*      */   public void putAll(Map paramMap)
/*      */   {
/*  299 */     if ((
/*  299 */       i = paramMap.size()) == 0)
/*      */     {
/*  300 */       return;
/*      */     }
/*  302 */     int i = (int)((this.size + i) / this.loadFactor + 1.0F);
/*  303 */     i = i; j = 1; for (j = 1073741824; j < i; j <<= 1);
/*  303 */     if (j > 1073741824) j = i > 1073741824 ? this : 1073741824;
/*      */   }
/*      */ 
/*      */   public Object remove(Object paramObject)
/*      */   {
/*      */     int i;
/*  319 */     int k = this.data.length; int j = (j = i = hash(paramObject = convertKey(paramObject))) & 
/*  319 */       k - 1;
/*  320 */     Object localObject2 = this.data[j];
/*  321 */     Object localObject3 = null;
/*  322 */     while (localObject2 != null) {
/*  323 */       if ((((HashEntry)localObject2).hashCode == i) && (isEqualKey(paramObject, ((HashEntry)localObject2).key))) {
/*  324 */         paramObject = ((HashEntry)localObject2).getValue();
/*  325 */         localObject2 = localObject3; j = j; Object localObject1 = localObject2; this = this; this.modCount += 1; removeEntry(localObject1, j, (HashEntry)localObject2); this.size -= 1; (this = localObject1).next = null; this.key = null; this.value = null;
/*  326 */         return paramObject;
/*      */       }
/*  328 */       localObject3 = localObject2;
/*  329 */       localObject2 = ((HashEntry)localObject2).next;
/*      */     }
/*  331 */     return null;
/*      */   }
/*      */ 
/*      */   public void clear()
/*      */   {
/*  339 */     this.modCount += 1;
/*      */     HashEntry[] data;
/*  341 */     for (int i = (
/*  341 */       data = this.data).length - 
/*  341 */       1; i >= 0; i--) {
/*  342 */       data[i] = null;
/*      */     }
/*  344 */     this.size = 0;
/*      */   }
/*      */ 
/*      */   private static Object convertKey(Object paramObject)
/*      */   {
/*  360 */     if (paramObject == null) return NULL; return paramObject;
/*      */   }
/*      */ 
/*      */   private static int hash(Object key)
/*      */   {
/*      */     int h;
/*  378 */     return key = (
/*  377 */       key = (
/*  376 */       key = (
/*  375 */       key = (
/*  374 */       h = key.hashCode()) + (
/*  374 */       key << 9 ^ 0xFFFFFFFF)) ^ 
/*  375 */       key >>> 14) + (
/*  376 */       key << 4)) ^ 
/*  377 */       key >>> 10;
/*      */   }
/*      */ 
/*      */   private static boolean isEqualKey(Object paramObject1, Object paramObject2)
/*      */   {
/*  391 */     return (paramObject1 == paramObject2) || (paramObject1.equals(paramObject2));
/*      */   }
/*      */ 
/*      */   protected static boolean isEqualValue(Object paramObject1, Object paramObject2)
/*      */   {
/*  404 */     return (paramObject1 == paramObject2) || (paramObject1.equals(paramObject2));
/*      */   }
/*      */ 
/*      */   protected final HashEntry getEntry(Object paramObject)
/*      */   {
/*  433 */     int i = hash(paramObject = convertKey(paramObject));
/*      */ 
/*  434 */     int j = this.data.length; this = this.data[((this = i) & j - 1)];
/*  435 */     while (this != null) {
/*  436 */       if ((this.hashCode == i) && (isEqualKey(paramObject, this.key))) {
/*  437 */         return this;
/*      */       }
/*  439 */       this = this.next;
/*      */     }
/*  441 */     return null;
/*      */   }
/*      */ 
/*      */   protected HashEntry createEntry(HashEntry next, int hashCode, Object key, Object value)
/*      */   {
/*  513 */     return new HashEntry(next, hashCode, key, value);
/*      */   }
/*      */ 
/*      */   protected void addEntry(HashEntry entry, int hashIndex)
/*      */   {
/*  526 */     this.data[hashIndex] = entry;
/*      */   }
/*      */ 
/*      */   protected void removeEntry(HashEntry paramHashEntry1, int paramInt, HashEntry paramHashEntry2)
/*      */   {
/*  560 */     if (paramHashEntry2 == null) {
/*  561 */       this.data[paramInt] = paramHashEntry1.next;
/*  562 */       return;
/*  563 */     }paramHashEntry2.next = paramHashEntry1.next;
/*      */   }
/*      */ 
/*      */   private void ensureCapacity(int paramInt)
/*      */   {
/*  602 */     int i = this.data.length;
/*  603 */     if (paramInt <= i)
/*  604 */       return;
/*      */     int j;
/*  606 */     if (this.size == 0) {
/*  607 */       float f1 = this.loadFactor; this.threshold = (int)((j = paramInt) * f1);
/*  608 */       this.data = new HashEntry[paramInt];
/*  609 */       return;
/*  610 */     }HashEntry[] arrayOfHashEntry1 = this.data;
/*  611 */     HashEntry[] arrayOfHashEntry2 = new HashEntry[paramInt];
/*      */ 
/*  613 */     this.modCount += 1;
/*  614 */     for (i -= 1; i >= 0; i--)
/*      */     {
/*  617 */       Object localObject;
/*  616 */       if ((
/*  616 */         localObject = arrayOfHashEntry1[i]) != null) { arrayOfHashEntry1[i] = null;
/*      */         HashEntry localHashEntry;
/*      */         do { localHashEntry = ((HashEntry)localObject).next;
/*  620 */           int k = paramInt; j = (j = ((HashEntry)localObject).hashCode) & k - 1;
/*  621 */           ((HashEntry)localObject).next = arrayOfHashEntry2[j];
/*  622 */           arrayOfHashEntry2[j] = localObject;
/*      */         }
/*  624 */         while ((
/*  624 */           localObject = localHashEntry) != null);
/*      */       }
/*      */     }
/*      */ 
/*  627 */     float f2 = this.loadFactor; this.threshold = (int)((j = paramInt) * f2);
/*  628 */     this.data = arrayOfHashEntry2;
/*      */   }
/*      */ 
/*      */   public MapIterator mapIterator()
/*      */   {
/*  732 */     if (this.size == 0) {
/*  733 */       return EmptyMapIterator.INSTANCE;
/*      */     }
/*  735 */     return new HashMapIterator(this);
/*      */   }
/*      */ 
/*      */   public Set entrySet()
/*      */   {
/*  785 */     if (this.entrySet == null) {
/*  786 */       this.entrySet = new EntrySet(this);
/*      */     }
/*  788 */     return this.entrySet;
/*      */   }
/*      */ 
/*      */   protected Iterator createEntrySetIterator()
/*      */   {
/*  798 */     if (size() == 0) {
/*  799 */       return EmptyIterator.INSTANCE;
/*      */     }
/*  801 */     return new EntrySetIterator(this);
/*      */   }
/*      */ 
/*      */   public Set keySet()
/*      */   {
/*  874 */     if (this.keySet == null) {
/*  875 */       this.keySet = new KeySet(this);
/*      */     }
/*  877 */     return this.keySet;
/*      */   }
/*      */ 
/*      */   protected Iterator createKeySetIterator()
/*      */   {
/*  887 */     if (size() == 0) {
/*  888 */       return EmptyIterator.INSTANCE;
/*      */     }
/*  890 */     return new KeySetIterator(this);
/*      */   }
/*      */ 
/*      */   public Collection values()
/*      */   {
/*  951 */     if (this.values == null) {
/*  952 */       this.values = new Values(this);
/*      */     }
/*  954 */     return this.values;
/*      */   }
/*      */ 
/*      */   protected Iterator createValuesIterator()
/*      */   {
/*  964 */     if (size() == 0) {
/*  965 */       return EmptyIterator.INSTANCE;
/*      */     }
/*  967 */     return new ValuesIterator(this);
/*      */   }
/*      */ 
/*      */   protected Object clone()
/*      */   {
/*      */     try
/*      */     {
/*      */       AbstractHashedMap cloned;
/* 1229 */       (
/* 1230 */         cloned = (AbstractHashedMap)super.clone()).data = 
/* 1230 */         new HashEntry[this.data.length];
/* 1231 */       cloned.entrySet = null;
/* 1232 */       cloned.keySet = null;
/* 1233 */       cloned.values = null;
/* 1234 */       cloned.modCount = 0;
/* 1235 */       cloned.size = 0;
/* 1236 */       cloned.init();
/* 1237 */       cloned.putAll(this);
/* 1238 */       return cloned;
/*      */     }
/*      */     catch (CloneNotSupportedException localCloneNotSupportedException1)
/*      */     {
/*      */     }
/*      */     CloneNotSupportedException ex;
/* 1241 */     return null;
/*      */   }
/*      */ 
/*      */   public boolean equals(Object paramObject)
/*      */   {
/* 1252 */     if (paramObject == this) {
/* 1253 */       return true;
/*      */     }
/* 1255 */     if (!(paramObject instanceof Map)) {
/* 1256 */       return false;
/*      */     }
/*      */ 
/* 1259 */     if ((
/* 1259 */       paramObject = (Map)paramObject)
/* 1259 */       .size() != size()) {
/* 1260 */       return false;
/*      */     }
/* 1262 */     this = mapIterator();
/*      */     try {
/* 1264 */       while (hasNext()) {
/* 1265 */         Object localObject1 = next();
/*      */         Object localObject2;
/* 1267 */         if ((
/* 1267 */           localObject2 = getValue()) == null)
/*      */         {
/* 1268 */           if ((paramObject.get(localObject1) != null) || (!paramObject.containsKey(localObject1))) {
/* 1269 */             return false;
/*      */           }
/*      */         }
/* 1272 */         else if (!localObject2.equals(paramObject.get(localObject1)))
/* 1273 */           return false;
/*      */       }
/*      */     }
/*      */     catch (ClassCastException localClassCastException)
/*      */     {
/* 1278 */       return false;
/*      */     } catch (NullPointerException localNullPointerException) {
/* 1280 */       return false;
/*      */     }
/* 1282 */     return true;
/*      */   }
/*      */ 
/*      */   public int hashCode()
/*      */   {
/* 1291 */     int total = 0;
/* 1292 */     this = createEntrySetIterator();
/*      */     Iterator it;
/* 1293 */     while (it.hasNext()) {
/* 1294 */       total += next().hashCode();
/*      */     }
/* 1296 */     return total;
/*      */   }
/*      */ 
/*      */   public String toString()
/*      */   {
/* 1305 */     if (size() == 0)
/* 1306 */       return "{}";
/*      */     StringBuffer localStringBuffer;
/* 1308 */     (
/* 1309 */       localStringBuffer = new StringBuffer(32 * size()))
/* 1309 */       .append('{');
/*      */     MapIterator localMapIterator;
/* 1312 */     boolean bool1 = (
/* 1312 */       localMapIterator = mapIterator())
/* 1312 */       .hasNext();
/* 1313 */     while (bool1) {
/* 1314 */       Object localObject1 = localMapIterator.next();
/* 1315 */       Object localObject2 = localMapIterator.getValue();
/* 1316 */       localStringBuffer.append(localObject1 == this ? "(this Map)" : localObject1).append('=').append(localObject2 == this ? "(this Map)" : localObject2);
/*      */       boolean bool2;
/* 1321 */       if ((
/* 1321 */         bool2 = localMapIterator.hasNext()))
/*      */       {
/* 1322 */         localStringBuffer.append(',').append(' ');
/*      */       }
/*      */     }
/*      */ 
/* 1326 */     localStringBuffer.append('}');
/* 1327 */     return localStringBuffer.toString();
/*      */   }
/*      */ 
/*      */   protected static abstract class HashIterator
/*      */     implements Iterator
/*      */   {
/*      */     private AbstractHashedMap parent;
/*      */     private int hashIndex;
/*      */     private AbstractHashedMap.HashEntry last;
/*      */     private AbstractHashedMap.HashEntry next;
/*      */     private int expectedModCount;
/*      */ 
/*      */     protected HashIterator(AbstractHashedMap parent)
/*      */     {
/* 1095 */       this.parent = parent;
/*      */       AbstractHashedMap.HashEntry[] data;
/* 1097 */       int i = (
/* 1097 */         data = parent.data).length;
/*      */ 
/* 1098 */       AbstractHashedMap.HashEntry next = null;
/* 1099 */       while ((i > 0) && (next == null)) {
/* 1100 */         i--; next = data[i];
/*      */       }
/* 1102 */       this.next = next;
/* 1103 */       this.hashIndex = i;
/* 1104 */       this.expectedModCount = parent.modCount;
/*      */     }
/*      */ 
/*      */     public boolean hasNext() {
/* 1108 */       return this.next != null;
/*      */     }
/*      */ 
/*      */     protected final AbstractHashedMap.HashEntry nextEntry() {
/* 1112 */       if (this.parent.modCount != this.expectedModCount)
/* 1113 */         throw new ConcurrentModificationException();
/*      */       AbstractHashedMap.HashEntry newCurrent;
/* 1116 */       if ((
/* 1116 */         newCurrent = this.next) == null)
/*      */       {
/* 1117 */         throw new NoSuchElementException("No next() entry in the iteration");
/*      */       }
/* 1119 */       AbstractHashedMap.HashEntry[] data = this.parent.data;
/* 1120 */       int i = this.hashIndex;
/* 1121 */       AbstractHashedMap.HashEntry n = newCurrent.next;
/* 1122 */       while ((n == null) && (i > 0)) {
/* 1123 */         i--; n = data[i];
/*      */       }
/* 1125 */       this.next = n;
/* 1126 */       this.hashIndex = i;
/* 1127 */       this.last = newCurrent;
/* 1128 */       return newCurrent;
/*      */     }
/*      */ 
/*      */     protected final AbstractHashedMap.HashEntry currentEntry() {
/* 1132 */       return this.last;
/*      */     }
/*      */ 
/*      */     public void remove() {
/* 1136 */       if (this.last == null) {
/* 1137 */         throw new IllegalStateException("remove() can only be called once after next()");
/*      */       }
/* 1139 */       if (this.parent.modCount != this.expectedModCount) {
/* 1140 */         throw new ConcurrentModificationException();
/*      */       }
/* 1142 */       this.parent.remove(this.last.getKey());
/* 1143 */       this.last = null;
/* 1144 */       this.expectedModCount = this.parent.modCount;
/*      */     }
/*      */ 
/*      */     public String toString() {
/* 1148 */       if (this.last != null) {
/* 1149 */         return "Iterator[" + this.last.getKey() + "=" + this.last.getValue() + "]";
/*      */       }
/* 1151 */       return "Iterator[]";
/*      */     }
/*      */   }
/*      */ 
/*      */   protected static class HashEntry
/*      */     implements Map.Entry
/*      */   {
/*      */     protected HashEntry next;
/*      */     protected int hashCode;
/*      */     protected Object key;
/*      */     protected Object value;
/*      */ 
/*      */     protected HashEntry(HashEntry next, int hashCode, Object key, Object value)
/*      */     {
/* 1034 */       this.next = next;
/* 1035 */       this.hashCode = hashCode;
/* 1036 */       this.key = key;
/* 1037 */       this.value = value;
/*      */     }
/*      */ 
/*      */     public Object getKey() {
/* 1041 */       if (this.key == AbstractHashedMap.NULL) return null; return this.key;
/*      */     }
/*      */ 
/*      */     public Object getValue() {
/* 1045 */       return this.value;
/*      */     }
/*      */ 
/*      */     public Object setValue(Object value) {
/* 1049 */       Object old = this.value;
/* 1050 */       this.value = value;
/* 1051 */       return old;
/*      */     }
/*      */ 
/*      */     public boolean equals(Object paramObject) {
/* 1055 */       if (paramObject == this) {
/* 1056 */         return true;
/*      */       }
/* 1058 */       if (!(paramObject instanceof Map.Entry)) {
/* 1059 */         return false;
/*      */       }
/* 1061 */       paramObject = (Map.Entry)paramObject;
/* 1062 */       return (getKey() == null ? paramObject.getKey() == null : getKey().equals(paramObject.getKey())) && (getValue() == null ? paramObject.getValue() == null : getValue().equals(paramObject.getValue()));
/*      */     }
/*      */ 
/*      */     public int hashCode()
/*      */     {
/* 1068 */       return (getKey() == null ? 0 : getKey().hashCode()) ^ (getValue() == null ? 0 : getValue().hashCode());
/*      */     }
/*      */ 
/*      */     public String toString()
/*      */     {
/* 1073 */       return getKey() + '=' + getValue();
/*      */     }
/*      */   }
/*      */ 
/*      */   protected static class ValuesIterator extends AbstractHashedMap.HashIterator
/*      */   {
/*      */     protected ValuesIterator(AbstractHashedMap parent)
/*      */     {
/* 1005 */       super();
/*      */     }
/*      */ 
/*      */     public final Object next() {
/* 1009 */       return super.nextEntry().getValue();
/*      */     }
/*      */   }
/*      */ 
/*      */   protected static class Values extends AbstractCollection
/*      */   {
/*      */     private AbstractHashedMap parent;
/*      */ 
/*      */     protected Values(AbstractHashedMap parent)
/*      */     {
/*  979 */       this.parent = parent;
/*      */     }
/*      */ 
/*      */     public final int size() {
/*  983 */       return this.parent.size();
/*      */     }
/*      */ 
/*      */     public final void clear() {
/*  987 */       this.parent.clear();
/*      */     }
/*      */ 
/*      */     public final boolean contains(Object value) {
/*  991 */       return this.parent.containsValue(value);
/*      */     }
/*      */ 
/*      */     public final Iterator iterator() {
/*  995 */       return this.parent.createValuesIterator();
/*      */     }
/*      */   }
/*      */ 
/*      */   protected static class KeySetIterator extends AbstractHashedMap.EntrySetIterator
/*      */   {
/*      */     protected KeySetIterator(AbstractHashedMap parent)
/*      */     {
/*  934 */       super();
/*      */     }
/*      */ 
/*      */     public final Object next() {
/*  938 */       return super.nextEntry().getKey();
/*      */     }
/*      */   }
/*      */ 
/*      */   protected static class KeySet extends AbstractSet
/*      */   {
/*      */     private AbstractHashedMap parent;
/*      */ 
/*      */     protected KeySet(AbstractHashedMap parent)
/*      */     {
/*  902 */       this.parent = parent;
/*      */     }
/*      */ 
/*      */     public final int size() {
/*  906 */       return this.parent.size();
/*      */     }
/*      */ 
/*      */     public final void clear() {
/*  910 */       this.parent.clear();
/*      */     }
/*      */ 
/*      */     public final boolean contains(Object key) {
/*  914 */       return this.parent.containsKey(key);
/*      */     }
/*      */ 
/*      */     public final boolean remove(Object paramObject) {
/*  918 */       boolean bool = this.parent.containsKey(paramObject);
/*  919 */       this.parent.remove(paramObject);
/*  920 */       return bool;
/*      */     }
/*      */ 
/*      */     public final Iterator iterator() {
/*  924 */       return this.parent.createKeySetIterator();
/*      */     }
/*      */   }
/*      */ 
/*      */   protected static class EntrySetIterator extends AbstractHashedMap.HashIterator
/*      */   {
/*      */     protected EntrySetIterator(AbstractHashedMap parent)
/*      */     {
/*  857 */       super();
/*      */     }
/*      */ 
/*      */     public Object next() {
/*  861 */       return super.nextEntry();
/*      */     }
/*      */   }
/*      */ 
/*      */   protected static class EntrySet extends AbstractSet
/*      */   {
/*      */     private AbstractHashedMap parent;
/*      */ 
/*      */     protected EntrySet(AbstractHashedMap parent)
/*      */     {
/*  813 */       this.parent = parent;
/*      */     }
/*      */ 
/*      */     public final int size() {
/*  817 */       return this.parent.size();
/*      */     }
/*      */ 
/*      */     public final void clear() {
/*  821 */       this.parent.clear();
/*      */     }
/*      */ 
/*      */     public final boolean contains(Object paramObject) {
/*  825 */       if ((paramObject instanceof Map.Entry)) {
/*  826 */         paramObject = (Map.Entry)paramObject;
/*      */ 
/*  828 */         return ((
/*  828 */           this = this.parent.getEntry(paramObject.getKey())) != null) && 
/*  828 */           (equals(paramObject));
/*      */       }
/*  830 */       return false;
/*      */     }
/*      */ 
/*      */     public final boolean remove(Object paramObject) {
/*  834 */       if (!(paramObject instanceof Map.Entry)) {
/*  835 */         return false;
/*      */       }
/*  837 */       if (!contains(paramObject)) {
/*  838 */         return false;
/*      */       }
/*      */ 
/*  841 */       paramObject = (
/*  841 */         paramObject = (Map.Entry)paramObject)
/*  841 */         .getKey();
/*  842 */       this.parent.remove(paramObject);
/*  843 */       return true;
/*      */     }
/*      */ 
/*      */     public final Iterator iterator() {
/*  847 */       return this.parent.createEntrySetIterator();
/*      */     }
/*      */   }
/*      */ 
/*      */   protected static class HashMapIterator extends AbstractHashedMap.HashIterator
/*      */     implements MapIterator
/*      */   {
/*      */     protected HashMapIterator(AbstractHashedMap parent)
/*      */     {
/*  744 */       super();
/*      */     }
/*      */ 
/*      */     public final Object next() {
/*  748 */       return super.nextEntry().getKey();
/*      */     }
/*      */ 
/*      */     public final Object getValue()
/*      */     {
/*      */       AbstractHashedMap.HashEntry current;
/*  761 */       if ((
/*  761 */         current = currentEntry()) == null)
/*      */       {
/*  762 */         throw new IllegalStateException("getValue() can only be called after next() and before remove()");
/*      */       }
/*  764 */       return getValue();
/*      */     }
/*      */   }
/*      */ }

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.apache.commons.collections.map.AbstractHashedMap
 * JD-Core Version:    0.6.0
 */