/*     */ package org.apache.commons.collections.map;
/*     */ 
/*     */ import java.util.ConcurrentModificationException;
/*     */ import java.util.Iterator;
/*     */ import java.util.NoSuchElementException;
/*     */ import org.apache.commons.collections.IterableMap;
/*     */ import org.apache.commons.collections.MapIterator;
/*     */ import org.apache.commons.collections.iterators.EmptyOrderedIterator;
/*     */ import org.apache.commons.collections.iterators.EmptyOrderedMapIterator;
/*     */ 
/*     */ public class AbstractLinkedMap extends AbstractHashedMap
/*     */   implements IterableMap
/*     */ {
/*     */   protected transient LinkEntry header;
/*     */ 
/*     */   protected AbstractLinkedMap()
/*     */   {
/*     */   }
/*     */ 
/*     */   protected AbstractLinkedMap(int paramInt1, float paramFloat, int paramInt2)
/*     */   {
/*  86 */     super(16, paramFloat, 12);
/*     */   }
/*     */ 
/*     */   protected final void init()
/*     */   {
/* 130 */     this.header = ((LinkEntry)createEntry(null, -1, null, null));
/* 131 */     this.header.before = (this.header.after = this.header);
/*     */   }
/*     */ 
/*     */   public boolean containsValue(Object paramObject)
/*     */   {
/*     */     LinkEntry localLinkEntry;
/* 143 */     if (paramObject == null) {
/* 144 */       for (localLinkEntry = this.header.after; localLinkEntry != this.header; localLinkEntry = localLinkEntry.after) {
/* 145 */         if (localLinkEntry.getValue() == null)
/* 146 */           return true;
/*     */       }
/*     */     }
/*     */     else {
/* 150 */       for (localLinkEntry = this.header.after; localLinkEntry != this.header; localLinkEntry = localLinkEntry.after) {
/* 151 */         if (isEqualValue(paramObject, localLinkEntry.getValue())) {
/* 152 */           return true;
/*     */         }
/*     */       }
/*     */     }
/* 156 */     return false;
/*     */   }
/*     */ 
/*     */   public void clear()
/*     */   {
/* 165 */     super.clear();
/* 166 */     this.header.before = (this.header.after = this.header);
/*     */   }
/*     */ 
/*     */   protected final void addEntry(AbstractHashedMap.HashEntry entry, int hashIndex)
/*     */   {
/*     */     LinkEntry link;
/* 258 */     (
/* 259 */       link = (LinkEntry)entry).after = 
/* 259 */       this.header;
/* 260 */     link.before = this.header.before;
/* 261 */     this.header.before.after = link;
/* 262 */     this.header.before = link;
/* 263 */     this.data[hashIndex] = entry;
/*     */   }
/*     */ 
/*     */   protected final AbstractHashedMap.HashEntry createEntry(AbstractHashedMap.HashEntry next, int hashCode, Object key, Object value)
/*     */   {
/* 278 */     return new LinkEntry(next, hashCode, key, value);
/*     */   }
/*     */ 
/*     */   protected final void removeEntry(AbstractHashedMap.HashEntry paramHashEntry1, int paramInt, AbstractHashedMap.HashEntry paramHashEntry2)
/*     */   {
/*     */     LinkEntry localLinkEntry;
/* 292 */     (
/* 293 */       localLinkEntry = (LinkEntry)paramHashEntry1).before
/* 293 */       .after = localLinkEntry.after;
/* 294 */     localLinkEntry.after.before = localLinkEntry.before;
/* 295 */     localLinkEntry.after = null;
/* 296 */     localLinkEntry.before = null;
/* 297 */     super.removeEntry(paramHashEntry1, paramInt, paramHashEntry2);
/*     */   }
/*     */ 
/*     */   public final MapIterator mapIterator()
/*     */   {
/* 339 */     if (this.size == 0) {
/* 340 */       return EmptyOrderedMapIterator.INSTANCE$1c9e92f3;
/*     */     }
/* 342 */     return new LinkMapIterator(this);
/*     */   }
/*     */ 
/*     */   protected final Iterator createEntrySetIterator()
/*     */   {
/* 412 */     if (size() == 0) {
/* 413 */       return EmptyOrderedIterator.INSTANCE$439d3a95;
/*     */     }
/* 415 */     return new EntrySetIterator(this);
/*     */   }
/*     */ 
/*     */   protected final Iterator createKeySetIterator()
/*     */   {
/* 444 */     if (size() == 0) {
/* 445 */       return EmptyOrderedIterator.INSTANCE$439d3a95;
/*     */     }
/* 447 */     return new KeySetIterator(this);
/*     */   }
/*     */ 
/*     */   protected final Iterator createValuesIterator()
/*     */   {
/* 476 */     if (size() == 0) {
/* 477 */       return EmptyOrderedIterator.INSTANCE$439d3a95;
/*     */     }
/* 479 */     return new ValuesIterator(this);
/*     */   }
/*     */ 
/*     */   protected static abstract class LinkIterator
/*     */     implements MapIterator
/*     */   {
/*     */     private AbstractLinkedMap parent;
/*     */     private AbstractLinkedMap.LinkEntry last;
/*     */     private AbstractLinkedMap.LinkEntry next;
/*     */     private int expectedModCount;
/*     */ 
/*     */     protected LinkIterator(AbstractLinkedMap parent)
/*     */     {
/* 545 */       this.parent = parent;
/* 546 */       this.next = parent.header.after;
/* 547 */       this.expectedModCount = parent.modCount;
/*     */     }
/*     */ 
/*     */     public boolean hasNext() {
/* 551 */       return this.next != this.parent.header;
/*     */     }
/*     */ 
/*     */     protected final AbstractLinkedMap.LinkEntry nextEntry()
/*     */     {
/* 559 */       if (this.parent.modCount != this.expectedModCount) {
/* 560 */         throw new ConcurrentModificationException();
/*     */       }
/* 562 */       if (this.next == this.parent.header) {
/* 563 */         throw new NoSuchElementException("No next() entry in the iteration");
/*     */       }
/* 565 */       this.last = this.next;
/* 566 */       this.next = this.next.after;
/* 567 */       return this.last;
/*     */     }
/*     */ 
/*     */     protected final AbstractLinkedMap.LinkEntry currentEntry()
/*     */     {
/* 584 */       return this.last;
/*     */     }
/*     */ 
/*     */     public void remove() {
/* 588 */       if (this.last == null) {
/* 589 */         throw new IllegalStateException("remove() can only be called once after next()");
/*     */       }
/* 591 */       if (this.parent.modCount != this.expectedModCount) {
/* 592 */         throw new ConcurrentModificationException();
/*     */       }
/* 594 */       this.parent.remove(this.last.getKey());
/* 595 */       this.last = null;
/* 596 */       this.expectedModCount = this.parent.modCount;
/*     */     }
/*     */ 
/*     */     public String toString()
/*     */     {
/* 605 */       if (this.last != null) {
/* 606 */         return "Iterator[" + this.last.getKey() + "=" + this.last.getValue() + "]";
/*     */       }
/* 608 */       return "Iterator[]";
/*     */     }
/*     */   }
/*     */ 
/*     */   protected static class LinkEntry extends AbstractHashedMap.HashEntry
/*     */   {
/*     */     protected LinkEntry before;
/*     */     protected LinkEntry after;
/*     */ 
/*     */     protected LinkEntry(AbstractHashedMap.HashEntry next, int hashCode, Object key, Object value)
/*     */     {
/* 524 */       super(hashCode, key, value);
/*     */     }
/*     */   }
/*     */ 
/*     */   protected static class ValuesIterator extends AbstractLinkedMap.LinkIterator
/*     */   {
/*     */     protected ValuesIterator(AbstractLinkedMap parent)
/*     */     {
/* 488 */       super();
/*     */     }
/*     */ 
/*     */     public final Object next() {
/* 492 */       return super.nextEntry().getValue();
/*     */     }
/*     */   }
/*     */ 
/*     */   protected static class KeySetIterator extends AbstractLinkedMap.EntrySetIterator
/*     */   {
/*     */     protected KeySetIterator(AbstractLinkedMap parent)
/*     */     {
/* 456 */       super();
/*     */     }
/*     */ 
/*     */     public final Object next() {
/* 460 */       return super.nextEntry().getKey();
/*     */     }
/*     */   }
/*     */ 
/*     */   protected static class EntrySetIterator extends AbstractLinkedMap.LinkIterator
/*     */   {
/*     */     protected EntrySetIterator(AbstractLinkedMap parent)
/*     */     {
/* 424 */       super();
/*     */     }
/*     */ 
/*     */     public Object next() {
/* 428 */       return super.nextEntry();
/*     */     }
/*     */   }
/*     */ 
/*     */   protected static class LinkMapIterator extends AbstractLinkedMap.LinkIterator
/*     */     implements MapIterator
/*     */   {
/*     */     protected LinkMapIterator(AbstractLinkedMap parent)
/*     */     {
/* 368 */       super();
/*     */     }
/*     */ 
/*     */     public final Object next() {
/* 372 */       return super.nextEntry().getKey();
/*     */     }
/*     */ 
/*     */     public final Object getValue()
/*     */     {
/*     */       AbstractHashedMap.HashEntry current;
/* 389 */       if ((
/* 389 */         current = currentEntry()) == null)
/*     */       {
/* 390 */         throw new IllegalStateException("getValue() can only be called after next() and before remove()");
/*     */       }
/* 392 */       return getValue();
/*     */     }
/*     */   }
/*     */ }

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.apache.commons.collections.map.AbstractLinkedMap
 * JD-Core Version:    0.6.0
 */