/*     */ package org.apache.commons.collections.map;
/*     */ 
/*     */ import java.io.Serializable;
/*     */ import java.util.AbstractList;
/*     */ import java.util.AbstractSet;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collection;
/*     */ import java.util.HashMap;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import java.util.Map.Entry;
/*     */ import java.util.Set;
/*     */ import org.apache.commons.collections.IterableMap;
/*     */ import org.apache.commons.collections.iterators.AbstractIteratorDecorator;
/*     */ import org.apache.commons.collections.keyvalue.AbstractMapEntry;
/*     */ 
/*     */ public final class ListOrderedMap extends AbstractMapDecorator
/*     */   implements Serializable, IterableMap
/*     */ {
/*  79 */   private List insertOrder = new ArrayList();
/*     */ 
/*     */   public static IterableMap decorate$71871a5b(Map map)
/*     */   {
/*  90 */     return new ListOrderedMap(map);
/*     */   }
/*     */ 
/*     */   public ListOrderedMap()
/*     */   {
/* 101 */     this(new HashMap());
/*     */   }
/*     */ 
/*     */   private ListOrderedMap(Map paramMap)
/*     */   {
/* 111 */     super(paramMap);
/* 112 */     this.insertOrder.addAll(getMap().keySet());
/*     */   }
/*     */ 
/*     */   public final Object put(Object paramObject1, Object paramObject2)
/*     */   {
/* 209 */     if (getMap().containsKey(paramObject1))
/*     */     {
/* 211 */       return getMap().put(paramObject1, paramObject2);
/*     */     }
/*     */ 
/* 214 */     paramObject2 = getMap().put(paramObject1, paramObject2);
/* 215 */     this.insertOrder.add(paramObject1);
/* 216 */     return paramObject2;
/*     */   }
/*     */ 
/*     */   public final void putAll(Map paramMap)
/*     */   {
/* 221 */     for (paramMap = paramMap.entrySet().iterator(); paramMap.hasNext(); ) {
/* 222 */       Map.Entry localEntry = (Map.Entry)paramMap.next();
/* 223 */       put(localEntry.getKey(), localEntry.getValue());
/*     */     }
/*     */   }
/*     */ 
/*     */   public final Object remove(Object paramObject) {
/* 228 */     Object localObject = getMap().remove(paramObject);
/* 229 */     this.insertOrder.remove(paramObject);
/* 230 */     return localObject;
/*     */   }
/*     */ 
/*     */   public final void clear() {
/* 234 */     getMap().clear();
/* 235 */     this.insertOrder.clear();
/*     */   }
/*     */ 
/*     */   public final Set keySet()
/*     */   {
/* 248 */     return new KeySetView(this);
/*     */   }
/*     */ 
/*     */   public final Collection values()
/*     */   {
/* 277 */     return new ValuesView(this);
/*     */   }
/*     */ 
/*     */   public final Set entrySet()
/*     */   {
/* 302 */     return new EntrySetView(this, this.insertOrder);
/*     */   }
/*     */ 
/*     */   public final String toString()
/*     */   {
/* 312 */     if (isEmpty())
/* 313 */       return "{}";
/*     */     StringBuffer localStringBuffer;
/* 315 */     (
/* 316 */       localStringBuffer = new StringBuffer())
/* 316 */       .append('{');
/* 317 */     int i = 1;
/* 318 */     Iterator localIterator = entrySet().iterator();
/* 319 */     while (localIterator.hasNext())
/*     */     {
/* 321 */       Object localObject2 = (
/* 321 */         localObject1 = (Map.Entry)localIterator.next())
/* 321 */         .getKey();
/* 322 */       Object localObject1 = ((Map.Entry)localObject1).getValue();
/* 323 */       if (i != 0)
/* 324 */         i = 0;
/*     */       else {
/* 326 */         localStringBuffer.append(", ");
/*     */       }
/* 328 */       localStringBuffer.append(localObject2 == this ? "(this Map)" : localObject2);
/* 329 */       localStringBuffer.append('=');
/* 330 */       localStringBuffer.append(localObject1 == this ? "(this Map)" : localObject1);
/*     */     }
/* 332 */     localStringBuffer.append('}');
/* 333 */     return (String)localStringBuffer.toString();
/*     */   }
/*     */ 
/*     */   public final Object get(int index)
/*     */   {
/* 345 */     return this.insertOrder.get(index);
/*     */   }
/*     */ 
/*     */   public final Object getValue(int index)
/*     */   {
/* 356 */     return get(this.insertOrder.get(index));
/*     */   }
/*     */ 
/*     */   public final Object setValue(int index, Object value)
/*     */   {
/*     */     Object value;
/* 378 */     index = this.insertOrder.get(index);
/* 379 */     return put(key, value);
/*     */   }
/*     */ 
/*     */   static class ListOrderedMapEntry extends AbstractMapEntry
/*     */   {
/*     */     private final ListOrderedMap parent;
/*     */ 
/*     */     ListOrderedMapEntry(ListOrderedMap parent, Object key)
/*     */     {
/* 620 */       super(null);
/* 621 */       this.parent = parent;
/*     */     }
/*     */ 
/*     */     public final Object getValue() {
/* 625 */       return this.parent.get(this.key);
/*     */     }
/*     */ 
/*     */     public final Object setValue(Object value) {
/* 629 */       return this.parent.getMap().put(this.key, value);
/*     */     }
/*     */   }
/*     */ 
/*     */   static class ListOrderedIterator extends AbstractIteratorDecorator
/*     */   {
/*     */     private final ListOrderedMap parent;
/* 597 */     private Object last = null;
/*     */ 
/*     */     ListOrderedIterator(ListOrderedMap parent, List insertOrder) {
/* 600 */       super();
/* 601 */       this.parent = parent;
/*     */     }
/*     */ 
/*     */     public final Object next() {
/* 605 */       this.last = super.next();
/* 606 */       return new ListOrderedMap.ListOrderedMapEntry(this.parent, this.last);
/*     */     }
/*     */ 
/*     */     public final void remove() {
/* 610 */       super.remove();
/* 611 */       this.parent.getMap().remove(this.last);
/*     */     }
/*     */   }
/*     */ 
/*     */   static class EntrySetView extends AbstractSet
/*     */   {
/*     */     private final ListOrderedMap parent;
/*     */     private final List insertOrder;
/*     */     private Set entrySet;
/*     */ 
/*     */     public EntrySetView(ListOrderedMap parent, List insertOrder)
/*     */     {
/* 532 */       this.parent = parent;
/* 533 */       this.insertOrder = insertOrder;
/*     */     }
/*     */ 
/*     */     private Set getEntrySet() {
/* 537 */       if (this.entrySet == null) {
/* 538 */         this.entrySet = this.parent.getMap().entrySet();
/*     */       }
/* 540 */       return this.entrySet;
/*     */     }
/*     */ 
/*     */     public final int size() {
/* 544 */       return this.parent.size();
/*     */     }
/*     */     public final boolean isEmpty() {
/* 547 */       return this.parent.isEmpty();
/*     */     }
/*     */ 
/*     */     public final boolean contains(Object obj) {
/* 551 */       return getEntrySet().contains(obj);
/*     */     }
/*     */ 
/*     */     public final boolean containsAll(Collection coll) {
/* 555 */       return getEntrySet().containsAll(coll);
/*     */     }
/*     */ 
/*     */     public final boolean remove(Object paramObject) {
/* 559 */       if (!(paramObject instanceof Map.Entry)) {
/* 560 */         return false;
/*     */       }
/* 562 */       if (getEntrySet().contains(paramObject)) {
/* 563 */         paramObject = ((Map.Entry)paramObject).getKey();
/* 564 */         this.parent.remove(paramObject);
/* 565 */         return true;
/*     */       }
/* 567 */       return false;
/*     */     }
/*     */ 
/*     */     public final void clear() {
/* 571 */       this.parent.clear();
/*     */     }
/*     */ 
/*     */     public final boolean equals(Object obj) {
/* 575 */       if (obj == this) {
/* 576 */         return true;
/*     */       }
/* 578 */       return getEntrySet().equals(obj);
/*     */     }
/*     */ 
/*     */     public final int hashCode() {
/* 582 */       return getEntrySet().hashCode();
/*     */     }
/*     */ 
/*     */     public final String toString() {
/* 586 */       return getEntrySet().toString();
/*     */     }
/*     */ 
/*     */     public final Iterator iterator() {
/* 590 */       return new ListOrderedMap.ListOrderedIterator(this.parent, this.insertOrder);
/*     */     }
/*     */   }
/*     */ 
/*     */   static class KeySetView extends AbstractSet
/*     */   {
/*     */     private final ListOrderedMap parent;
/*     */ 
/*     */     KeySetView(ListOrderedMap parent)
/*     */     {
/* 500 */       this.parent = parent;
/*     */     }
/*     */ 
/*     */     public final int size() {
/* 504 */       return this.parent.size();
/*     */     }
/*     */ 
/*     */     public final boolean contains(Object value) {
/* 508 */       return this.parent.containsKey(value);
/*     */     }
/*     */ 
/*     */     public final void clear() {
/* 512 */       this.parent.clear();
/*     */     }
/*     */ 
/*     */     public final Iterator iterator() {
/* 516 */       return new AbstractIteratorDecorator(this.parent.entrySet().iterator()) {
/*     */         public final Object next() {
/* 518 */           return ((Map.Entry)super.next()).getKey();
/*     */         }
/*     */       };
/*     */     }
/*     */   }
/*     */ 
/*     */   static class ValuesView extends AbstractList
/*     */   {
/*     */     private final ListOrderedMap parent;
/*     */ 
/*     */     ValuesView(ListOrderedMap parent)
/*     */     {
/* 458 */       this.parent = parent;
/*     */     }
/*     */ 
/*     */     public final int size() {
/* 462 */       return this.parent.size();
/*     */     }
/*     */ 
/*     */     public final boolean contains(Object value) {
/* 466 */       return this.parent.containsValue(value);
/*     */     }
/*     */ 
/*     */     public final void clear() {
/* 470 */       this.parent.clear();
/*     */     }
/*     */ 
/*     */     public final Iterator iterator() {
/* 474 */       return new AbstractIteratorDecorator(this.parent.entrySet().iterator()) {
/*     */         public final Object next() {
/* 476 */           return ((Map.Entry)this.iterator.next()).getValue();
/*     */         } } ;
/*     */     }
/*     */ 
/*     */     public final Object get(int index) {
/* 482 */       return this.parent.getValue(index);
/*     */     }
/*     */ 
/*     */     public final Object set(int index, Object value) {
/* 486 */       return this.parent.setValue(index, value);
/*     */     }
/*     */ 
/*     */     public final Object remove(int index) {
/* 490 */       index = index; return (this = this.parent).remove(get(index));
/*     */     }
/*     */   }
/*     */ }

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.apache.commons.collections.map.ListOrderedMap
 * JD-Core Version:    0.6.0
 */