/*     */ package org.apache.commons.io.output;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.OutputStream;
/*     */ import java.util.ArrayList;
/*     */ import java.util.List;
/*     */ 
/*     */ public final class ByteArrayOutputStream extends OutputStream
/*     */ {
/*  53 */   private static final byte[] EMPTY_BYTE_ARRAY = new byte[0];
/*     */ 
/*  56 */   private List buffers = new ArrayList();
/*     */   private int currentBufferIndex;
/*     */   private int filledBufferSum;
/*     */   private byte[] currentBuffer;
/*     */   private int count;
/*     */ 
/*     */   public ByteArrayOutputStream()
/*     */   {
/*  71 */     this(1024);
/*     */   }
/*     */ 
/*     */   private ByteArrayOutputStream(int paramInt)
/*     */   {
/*  82 */     needNewBuffer(1024);
/*     */   }
/*     */ 
/*     */   private byte[] getBuffer(int index)
/*     */   {
/*  97 */     return (byte[])this.buffers.get(index);
/*     */   }
/*     */ 
/*     */   private void needNewBuffer(int paramInt)
/*     */   {
/* 107 */     if (this.currentBufferIndex < this.buffers.size() - 1)
/*     */     {
/* 109 */       this.filledBufferSum += this.currentBuffer.length;
/*     */ 
/* 111 */       this.currentBufferIndex += 1;
/* 112 */       this.currentBuffer = getBuffer(this.currentBufferIndex); return;
/*     */     }
/*     */ 
/* 116 */     if (this.currentBuffer == null) {
/* 117 */       paramInt = paramInt;
/* 118 */       this.filledBufferSum = 0;
/*     */     } else {
/* 120 */       paramInt = Math.max(this.currentBuffer.length << 1, paramInt - this.filledBufferSum);
/*     */ 
/* 123 */       this.filledBufferSum += this.currentBuffer.length;
/*     */     }
/*     */ 
/* 126 */     this.currentBufferIndex += 1;
/* 127 */     this.currentBuffer = new byte[paramInt];
/* 128 */     this.buffers.add(this.currentBuffer);
/*     */   }
/*     */ 
/*     */   public final void write(byte[] paramArrayOfByte, int paramInt1, int paramInt2)
/*     */   {
/* 136 */     if ((paramInt1 < 0) || (paramInt1 > paramArrayOfByte.length) || (paramInt2 < 0) || (paramInt1 + paramInt2 > paramArrayOfByte.length) || (paramInt1 + paramInt2 < 0))
/*     */     {
/* 141 */       throw new IndexOutOfBoundsException();
/* 142 */     }if (paramInt2 == 0) {
/* 143 */       return;
/*     */     }
/* 145 */     synchronized (this) {
/* 146 */       int i = this.count + paramInt2;
/* 147 */       int j = paramInt2;
/* 148 */       int k = this.count - this.filledBufferSum;
/* 149 */       while (j > 0) {
/* 150 */         int m = Math.min(j, this.currentBuffer.length - k);
/* 151 */         System.arraycopy(paramArrayOfByte, paramInt1 + paramInt2 - j, this.currentBuffer, k, m);
/*     */ 
/* 153 */         if ((
/* 153 */           j = j - m) > 0)
/*     */         {
/* 154 */           needNewBuffer(i);
/* 155 */           k = 0;
/*     */         }
/*     */       }
/* 158 */       this.count = i;
/* 159 */       return;
/*     */     }
/*     */   }
/*     */ 
/*     */   public final synchronized void write(int b)
/*     */   {
/*     */     int inBufferPos;
/* 167 */     if ((
/* 167 */       inBufferPos = this.count - this.filledBufferSum) == 
/* 167 */       this.currentBuffer.length) {
/* 168 */       needNewBuffer(this.count + 1);
/* 169 */       inBufferPos = 0;
/*     */     }
/* 171 */     this.currentBuffer[inBufferPos] = (byte)b;
/* 172 */     this.count += 1;
/*     */   }
/*     */ 
/*     */   public final void close()
/*     */     throws IOException
/*     */   {
/*     */   }
/*     */ 
/*     */   public final synchronized byte[] toByteArray()
/*     */   {
/*     */     int i;
/* 234 */     if ((
/* 234 */       i = this.count) == 0)
/*     */     {
/* 235 */       return EMPTY_BYTE_ARRAY;
/*     */     }
/* 237 */     byte[] arrayOfByte1 = new byte[i];
/* 238 */     int j = 0;
/* 239 */     int k = 0;
/*     */ 
/* 246 */     for (; k < this.buffers.size(); k++)
/*     */     {
/*     */       byte[] arrayOfByte2;
/* 241 */       int m = Math.min((
/* 241 */         arrayOfByte2 = getBuffer(k)).length, 
/* 241 */         i);
/* 242 */       System.arraycopy(arrayOfByte2, 0, arrayOfByte1, j, m);
/* 243 */       j += m;
/*     */ 
/* 245 */       if ((
/* 245 */         i = i - m) == 0)
/*     */       {
/*     */         break;
/*     */       }
/*     */     }
/* 249 */     return arrayOfByte1;
/*     */   }
/*     */ 
/*     */   public final String toString()
/*     */   {
/* 258 */     return new String(toByteArray());
/*     */   }
/*     */ }

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.apache.commons.io.output.ByteArrayOutputStream
 * JD-Core Version:    0.6.0
 */