/*     */ package org.apache.commons.lang.builder;
/*     */ 
/*     */ import java.util.HashSet;
/*     */ 
/*     */ public final class HashCodeBuilder
/*     */ {
/*     */   private final int iConstant;
/* 548 */   private int iTotal = 0;
/*     */ 
/*     */   public HashCodeBuilder()
/*     */   {
/* 556 */     this.iConstant = 37;
/* 557 */     this.iTotal = 17;
/*     */   }
/*     */ 
/*     */   public HashCodeBuilder(int initialNonZeroOddNumber, int multiplierNonZeroOddNumber)
/*     */   {
/* 578 */     if (initialNonZeroOddNumber == 0) {
/* 579 */       throw new IllegalArgumentException("HashCodeBuilder requires a non zero initial value");
/*     */     }
/* 581 */     if (initialNonZeroOddNumber % 2 == 0) {
/* 582 */       throw new IllegalArgumentException("HashCodeBuilder requires an odd initial value");
/*     */     }
/* 584 */     if (multiplierNonZeroOddNumber == 0) {
/* 585 */       throw new IllegalArgumentException("HashCodeBuilder requires a non zero multiplier");
/*     */     }
/* 587 */     if (multiplierNonZeroOddNumber % 2 == 0) {
/* 588 */       throw new IllegalArgumentException("HashCodeBuilder requires an odd multiplier");
/*     */     }
/* 590 */     this.iConstant = multiplierNonZeroOddNumber;
/* 591 */     this.iTotal = initialNonZeroOddNumber;
/*     */   }
/*     */ 
/*     */   public final HashCodeBuilder append(byte[] paramArrayOfByte)
/*     */   {
/* 661 */     if (paramArrayOfByte == null) {
/* 662 */       this.iTotal *= this.iConstant;
/*     */     }
/*     */     else
/*     */     {
/*     */       HashCodeBuilder localHashCodeBuilder;
/* 664 */       for (int i = 0; i < paramArrayOfByte.length; i++) {
/* 665 */         int j = paramArrayOfByte[i]; localHashCodeBuilder = this; this.iTotal = (localHashCodeBuilder.iTotal * localHashCodeBuilder.iConstant + j);
/*     */       }
/*     */     }
/* 668 */     return this;
/*     */   }
/*     */ 
/*     */   private HashCodeBuilder append(long value)
/*     */   {
/* 821 */     this.iTotal = (this.iTotal * this.iConstant + (int)(value ^ value >> 32));
/* 822 */     return this;
/*     */   }
/*     */ 
/*     */   public final HashCodeBuilder append(Object paramObject)
/*     */   {
/* 855 */     if (paramObject == null) {
/* 856 */       this.iTotal *= this.iConstant;
/*     */     }
/*     */     else
/*     */     {
/*     */       Object localObject1;
/*     */       int i;
/* 861 */       if ((paramObject instanceof long[])) {
/* 862 */         localObject1 = (long[])paramObject; paramObject = this; if (localObject1 == null) paramObject.iTotal *= paramObject.iConstant; else for (i = 0; i < localObject1.length; i++) paramObject.append(localObject1[i]);
/*     */       }
/*     */       else
/*     */       {
/*     */         int j;
/*     */         Object localObject2;
/* 863 */         if ((paramObject instanceof int[])) {
/* 864 */           localObject1 = (int[])paramObject; paramObject = this; if (localObject1 == null) paramObject.iTotal *= paramObject.iConstant; else for (i = 0; i < localObject1.length; i++) { j = localObject1[i]; (localObject2 = paramObject).iTotal = (localObject2.iTotal * localObject2.iConstant + j); } 
/*     */         }
/* 865 */         else if ((paramObject instanceof short[])) {
/* 866 */           localObject1 = (short[])paramObject; paramObject = this; if (localObject1 == null) paramObject.iTotal *= paramObject.iConstant; else for (i = 0; i < localObject1.length; i++) { j = localObject1[i]; (localObject2 = paramObject).iTotal = (localObject2.iTotal * localObject2.iConstant + j); } 
/*     */         }
/* 867 */         else if ((paramObject instanceof char[])) {
/* 868 */           localObject1 = (char[])paramObject; paramObject = this; if (localObject1 == null) paramObject.iTotal *= paramObject.iConstant; else for (i = 0; i < localObject1.length; i++) { j = localObject1[i]; (localObject2 = paramObject).iTotal = (localObject2.iTotal * localObject2.iConstant + j); } 
/*     */         }
/* 869 */         else if ((paramObject instanceof byte[])) {
/* 870 */           append((byte[])paramObject);
/* 871 */         } else if ((paramObject instanceof double[])) {
/* 872 */           localObject1 = (double[])paramObject; paramObject = this; if (localObject1 == null) paramObject.iTotal *= paramObject.iConstant; else for (i = 0; i < localObject1.length; i++) { double d = localObject1[i]; (localObject2 = paramObject).append(Double.doubleToLongBits(d)); } 
/*     */         }
/* 873 */         else if ((paramObject instanceof float[])) {
/* 874 */           localObject1 = (float[])paramObject; paramObject = this; if (localObject1 == null) paramObject.iTotal *= paramObject.iConstant; else for (i = 0; i < localObject1.length; i++) { float f = localObject1[i]; (localObject2 = paramObject).iTotal = (localObject2.iTotal * localObject2.iConstant + Float.floatToIntBits(f)); } 
/*     */         }
/* 875 */         else if ((paramObject instanceof boolean[])) {
/* 876 */           localObject1 = (boolean[])paramObject; paramObject = this; if (localObject1 == null) paramObject.iTotal *= paramObject.iConstant; else for (i = 0; i < localObject1.length; i++) { int k = localObject1[i]; (localObject2 = paramObject).iTotal = (localObject2.iTotal * localObject2.iConstant + (k != 0 ? 0 : 1)); } 
/*     */         }
/* 877 */         else if ((paramObject instanceof Object[]))
/*     */         {
/* 879 */           localObject1 = (Object[])paramObject; paramObject = this; if (localObject1 == null) paramObject.iTotal *= paramObject.iConstant; else for (i = 0; i < localObject1.length; i++) paramObject.append(localObject1[i]);  
/*     */         }
/*     */         else
/*     */         {
/* 881 */           this.iTotal = (this.iTotal * this.iConstant + paramObject.hashCode());
/*     */         }
/*     */       }
/*     */     }
/* 884 */     return (HashCodeBuilder)this;
/*     */   }
/*     */ 
/*     */   public final HashCodeBuilder appendSuper(int superHashCode)
/*     */   {
/* 952 */     this.iTotal = (this.iTotal * this.iConstant + superHashCode);
/* 953 */     return this;
/*     */   }
/*     */ 
/*     */   public final int toHashCode()
/*     */   {
/* 964 */     return this.iTotal;
/*     */   }
/*     */ 
/*     */   static
/*     */   {
/* 105 */     new ThreadLocal()
/*     */     {
/*     */       protected final Object initialValue()
/*     */       {
/* 109 */         return new HashSet();
/*     */       }
/*     */     };
/*     */   }
/*     */ }

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.apache.commons.lang.builder.HashCodeBuilder
 * JD-Core Version:    0.6.0
 */