/*      */ package org.apache.commons.lang.builder;
/*      */ 
/*      */ import java.io.Serializable;
/*      */ import java.util.Collection;
/*      */ import java.util.HashSet;
/*      */ import java.util.Map;
/*      */ import java.util.Set;
/*      */ import org.apache.commons.lang.ClassUtils;
/*      */ import org.apache.commons.lang.ObjectUtils;
/*      */ import org.apache.commons.lang.SystemUtils;
/*      */ 
/*      */ public abstract class ToStringStyle
/*      */   implements Serializable
/*      */ {
/*   81 */   public static final ToStringStyle DEFAULT_STYLE = new DefaultToStringStyle();
/*      */   private static ThreadLocal registry;
/*  205 */   private boolean useFieldNames = true;
/*      */ 
/*  210 */   private boolean useClassName = true;
/*      */ 
/*  215 */   private boolean useShortClassName = false;
/*      */ 
/*  220 */   private boolean useIdentityHashCode = true;
/*      */ 
/*  225 */   private String contentStart = "[";
/*      */ 
/*  230 */   private String contentEnd = "]";
/*      */ 
/*  235 */   private String fieldNameValueSeparator = "=";
/*      */ 
/*  240 */   private boolean fieldSeparatorAtStart = false;
/*      */ 
/*  245 */   private boolean fieldSeparatorAtEnd = false;
/*      */ 
/*  250 */   private String fieldSeparator = ",";
/*      */ 
/*  255 */   private String arrayStart = "{";
/*      */ 
/*  260 */   private String arraySeparator = ",";
/*      */ 
/*  265 */   private boolean arrayContentDetail = true;
/*      */ 
/*  270 */   private String arrayEnd = "}";
/*      */ 
/*  276 */   private boolean defaultFullDetail = true;
/*      */ 
/*  281 */   private String nullText = "<null>";
/*      */ 
/*  286 */   private String sizeStartText = "<size=";
/*      */ 
/*  291 */   private String sizeEndText = ">";
/*      */ 
/*  296 */   private String summaryObjectStartText = "<";
/*      */ 
/*  301 */   private String summaryObjectEndText = ">";
/*      */ 
/*      */   private static Set getRegistry()
/*      */   {
/*  153 */     return (Set)registry.get();
/*      */   }
/*      */ 
/*      */   private static void register(Object paramObject)
/*      */   {
/*  181 */     if (paramObject != null)
/*  182 */       getRegistry().add(paramObject);
/*      */   }
/*      */ 
/*      */   private static void unregister(Object paramObject)
/*      */   {
/*  199 */     getRegistry().remove(paramObject);
/*      */   }
/*      */ 
/*      */   public final void appendStart(StringBuffer paramStringBuffer, Object paramObject)
/*      */   {
/*  360 */     if (paramObject != null) {
/*  361 */       Object localObject2 = paramObject; StringBuffer localStringBuffer = paramStringBuffer; Object localObject1 = this; if ((this.useClassName) && (localObject2 != null)) { register(localObject2); if (((ToStringStyle)localObject1).useShortClassName) localStringBuffer.append(ClassUtils.getShortClassName(localObject1 = localObject2.getClass())); else localStringBuffer.append(localObject2.getClass().getName()); 
/*      */       }
/*  362 */       localObject2 = paramObject; localStringBuffer = paramStringBuffer; localObject1 = this; paramObject = this; if ((this.useIdentityHashCode) && (localObject2 != null)) { register(localObject2); localStringBuffer.append('@'); localStringBuffer.append(Integer.toHexString(System.identityHashCode(localObject2))); }
/*  363 */       localStringBuffer = paramStringBuffer; localObject1 = this; localStringBuffer.append(((ToStringStyle)localObject1).contentStart);
/*  364 */       if (this.fieldSeparatorAtStart)
/*  365 */         appendFieldSeparator(paramStringBuffer);
/*      */     }
/*      */   }
/*      */ 
/*      */   public final void appendEnd(StringBuffer paramStringBuffer, Object paramObject)
/*      */   {
/*  378 */     StringBuffer localStringBuffer = paramStringBuffer; ToStringStyle localToStringStyle = this; int i = localStringBuffer.length(); int j = localToStringStyle.fieldSeparator.length(); if ((i > 0) && (j > 0) && (i >= j)) { int k = 1; for (int m = 0; m < j; m++) { if (localStringBuffer.charAt(i - 1 - m) == localToStringStyle.fieldSeparator.charAt(j - 1 - m)) continue; k = 0; break; } if (k != 0) localStringBuffer.setLength(i - j);
/*      */     }
/*      */ 
/*  381 */     localStringBuffer = paramStringBuffer; localToStringStyle = this; localStringBuffer.append(localToStringStyle.contentEnd);
/*  382 */     unregister(paramObject);
/*      */   }
/*      */ 
/*      */   public final void append(StringBuffer paramStringBuffer, String paramString, Object paramObject, Boolean paramBoolean)
/*      */   {
/*  422 */     String str = paramString; StringBuffer localStringBuffer = paramStringBuffer; paramBoolean = this; if ((this.useFieldNames) && (str != null)) { localStringBuffer.append(str); localStringBuffer.append(paramBoolean.fieldNameValueSeparator);
/*      */     }
/*  424 */     if (paramObject == null) {
/*  425 */       appendNullText$3c263f97(paramStringBuffer);
/*      */     }
/*      */     else {
/*  428 */       localStringBuffer = null; paramBoolean = this; appendInternal(paramStringBuffer, paramString, paramObject, localStringBuffer == null ? paramBoolean.defaultFullDetail : localStringBuffer.booleanValue());
/*      */     }
/*      */ 
/*  431 */     localStringBuffer = paramStringBuffer; paramBoolean = this; appendFieldSeparator(localStringBuffer);
/*      */   }
/*      */ 
/*      */   private void appendInternal(StringBuffer paramStringBuffer, String paramString, Object paramObject, boolean paramBoolean)
/*      */   {
/*  454 */     Object localObject = paramObject; if ((getRegistry().contains(localObject)) && (!(paramObject instanceof Number)) && (!(paramObject instanceof Boolean)) && (!(paramObject instanceof Character)))
/*      */     {
/*  456 */       this = paramObject; ObjectUtils.appendIdentityToString(localObject = paramStringBuffer, this);
/*  457 */       return;
/*      */     }
/*      */ 
/*  460 */     register(paramObject);
/*      */     try
/*      */     {
/*  463 */       if ((paramObject instanceof Collection)) {
/*  464 */         if (paramBoolean) {
/*  465 */           this = (Collection)paramObject; (localObject = paramStringBuffer).append(this);
/*      */         } else {
/*  467 */           appendSummarySize$48a14046(paramStringBuffer, ((Collection)paramObject).size());
/*      */         }
/*      */       }
/*  470 */       else if ((paramObject instanceof Map)) {
/*  471 */         if (paramBoolean) {
/*  472 */           this = (Map)paramObject; (localObject = paramStringBuffer).append(this);
/*      */         } else {
/*  474 */           appendSummarySize$48a14046(paramStringBuffer, ((Map)paramObject).size());
/*      */         }
/*      */       }
/*      */       else
/*      */       {
/*      */         ToStringStyle localToStringStyle;
/*  477 */         if ((paramObject instanceof long[])) {
/*  478 */           if (paramBoolean) {
/*  479 */             paramString = (long[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; append(((ToStringStyle)localObject).arrayStart); for (paramBoolean = false; paramBoolean < paramString.length; paramBoolean++) { if (paramBoolean) append(((ToStringStyle)localObject).arraySeparator); long l = paramString[paramBoolean]; localToStringStyle = this; append(l); } append(((ToStringStyle)localObject).arrayEnd);
/*      */           } else {
/*  481 */             paramString = (long[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; appendSummarySize$48a14046(this, paramString.length);
/*      */           }
/*      */         }
/*      */         else
/*      */         {
/*      */           int i;
/*  484 */           if ((paramObject instanceof int[])) {
/*  485 */             if (paramBoolean) {
/*  486 */               paramString = (int[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; append(((ToStringStyle)localObject).arrayStart); for (paramBoolean = false; paramBoolean < paramString.length; paramBoolean++) { if (paramBoolean) append(((ToStringStyle)localObject).arraySeparator); i = paramString[paramBoolean]; localToStringStyle = this; append(i); } append(((ToStringStyle)localObject).arrayEnd);
/*      */             } else {
/*  488 */               paramString = (int[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; appendSummarySize$48a14046(this, paramString.length);
/*      */             }
/*      */           }
/*  491 */           else if ((paramObject instanceof short[])) {
/*  492 */             if (paramBoolean) {
/*  493 */               paramString = (short[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; append(((ToStringStyle)localObject).arrayStart); for (paramBoolean = false; paramBoolean < paramString.length; paramBoolean++) { if (paramBoolean) append(((ToStringStyle)localObject).arraySeparator); i = paramString[paramBoolean]; localToStringStyle = this; append(i); } append(((ToStringStyle)localObject).arrayEnd);
/*      */             } else {
/*  495 */               paramString = (short[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; appendSummarySize$48a14046(this, paramString.length);
/*      */             }
/*      */           }
/*  498 */           else if ((paramObject instanceof byte[])) {
/*  499 */             if (paramBoolean) {
/*  500 */               paramString = (byte[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; append(((ToStringStyle)localObject).arrayStart); for (paramBoolean = false; paramBoolean < paramString.length; paramBoolean++) { if (paramBoolean) append(((ToStringStyle)localObject).arraySeparator); i = paramString[paramBoolean]; localToStringStyle = this; append(i); } append(((ToStringStyle)localObject).arrayEnd);
/*      */             } else {
/*  502 */               paramString = (byte[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; appendSummarySize$48a14046(this, paramString.length);
/*      */             }
/*      */           }
/*  505 */           else if ((paramObject instanceof char[])) {
/*  506 */             if (paramBoolean) {
/*  507 */               paramString = (char[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; append(((ToStringStyle)localObject).arrayStart); for (paramBoolean = false; paramBoolean < paramString.length; paramBoolean++) { if (paramBoolean) append(((ToStringStyle)localObject).arraySeparator); i = paramString[paramBoolean]; localToStringStyle = this; append(i); } append(((ToStringStyle)localObject).arrayEnd);
/*      */             } else {
/*  509 */               paramString = (char[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; appendSummarySize$48a14046(this, paramString.length);
/*      */             }
/*      */           }
/*  512 */           else if ((paramObject instanceof double[])) {
/*  513 */             if (paramBoolean) {
/*  514 */               paramString = (double[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; append(((ToStringStyle)localObject).arrayStart); for (paramBoolean = false; paramBoolean < paramString.length; paramBoolean++) { if (paramBoolean) append(((ToStringStyle)localObject).arraySeparator); double d = paramString[paramBoolean]; localToStringStyle = this; append(d); } append(((ToStringStyle)localObject).arrayEnd);
/*      */             } else {
/*  516 */               paramString = (double[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; appendSummarySize$48a14046(this, paramString.length);
/*      */             }
/*      */           }
/*  519 */           else if ((paramObject instanceof float[])) {
/*  520 */             if (paramBoolean) {
/*  521 */               paramString = (float[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; append(((ToStringStyle)localObject).arrayStart); for (paramBoolean = false; paramBoolean < paramString.length; paramBoolean++) { if (paramBoolean) append(((ToStringStyle)localObject).arraySeparator); float f = paramString[paramBoolean]; localToStringStyle = this; append(f); } append(((ToStringStyle)localObject).arrayEnd);
/*      */             } else {
/*  523 */               paramString = (float[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; appendSummarySize$48a14046(this, paramString.length);
/*      */             }
/*      */           }
/*  526 */           else if ((paramObject instanceof boolean[])) {
/*  527 */             if (paramBoolean) {
/*  528 */               paramString = (boolean[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; append(((ToStringStyle)localObject).arrayStart); for (paramBoolean = false; paramBoolean < paramString.length; paramBoolean++) { if (paramBoolean) append(((ToStringStyle)localObject).arraySeparator); int j = paramString[paramBoolean]; localToStringStyle = this; append(j); } append(((ToStringStyle)localObject).arrayEnd);
/*      */             } else {
/*  530 */               paramString = (boolean[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; appendSummarySize$48a14046(this, paramString.length);
/*      */             }
/*      */           }
/*  533 */           else if (paramObject.getClass().isArray()) {
/*  534 */             if (paramBoolean) {
/*  535 */               paramString = (Object[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; append(((ToStringStyle)localObject).arrayStart); for (paramBoolean = false; paramBoolean < paramString.length; paramBoolean++) { localToStringStyle = paramString[paramBoolean]; if (paramBoolean) append(((ToStringStyle)localObject).arraySeparator); if (localToStringStyle == null) ((ToStringStyle)localObject).appendNullText$3c263f97(this); else ((ToStringStyle)localObject).appendInternal(this, paramStringBuffer, localToStringStyle, ((ToStringStyle)localObject).arrayContentDetail);  }
/*  535 */               append(((ToStringStyle)localObject).arrayEnd);
/*      */             } else {
/*  537 */               paramString = (Object[])paramObject; paramStringBuffer = paramString; this = paramStringBuffer; localObject = this; appendSummarySize$48a14046(this, paramString.length);
/*      */             }
/*      */ 
/*      */           }
/*  541 */           else if (paramBoolean) {
/*  542 */             this = paramObject; (localObject = paramStringBuffer).append(this);
/*      */           } else {
/*  544 */             paramStringBuffer = paramObject; this = paramStringBuffer; localObject = this; append(((ToStringStyle)localObject).summaryObjectStartText); append(ClassUtils.getShortClassName(paramStringBuffer = paramStringBuffer.getClass())); append(((ToStringStyle)localObject).summaryObjectEndText);
/*      */           }
/*      */         }
/*      */       }return;
/*      */     } finally {
/*  548 */       unregister(paramObject); } throw this;
/*      */   }
/*      */ 
/*      */   private void appendNullText$3c263f97(StringBuffer paramStringBuffer)
/*      */   {
/* 1486 */     paramStringBuffer.append(this.nullText);
/*      */   }
/*      */ 
/*      */   private void appendFieldSeparator(StringBuffer paramStringBuffer)
/*      */   {
/* 1495 */     paramStringBuffer.append(this.fieldSeparator);
/*      */   }
/*      */ 
/*      */   private void appendSummarySize$48a14046(StringBuffer paramStringBuffer, int paramInt)
/*      */   {
/* 1537 */     paramStringBuffer.append(this.sizeStartText);
/* 1538 */     paramStringBuffer.append(paramInt);
/* 1539 */     paramStringBuffer.append(this.sizeEndText);
/*      */   }
/*      */ 
/*      */   protected final void setUseClassName(boolean useClassName)
/*      */   {
/* 1596 */     this.useClassName = false;
/*      */   }
/*      */ 
/*      */   protected final void setUseShortClassName(boolean useShortClassName)
/*      */   {
/* 1629 */     this.useShortClassName = true;
/*      */   }
/*      */ 
/*      */   protected final void setUseIdentityHashCode(boolean useIdentityHashCode)
/*      */   {
/* 1660 */     this.useIdentityHashCode = false;
/*      */   }
/*      */ 
/*      */   protected final void setUseFieldNames(boolean useFieldNames)
/*      */   {
/* 1680 */     this.useFieldNames = false;
/*      */   }
/*      */ 
/*      */   protected final void setContentStart(String contentStart)
/*      */   {
/* 1823 */     if (contentStart == null) {
/* 1824 */       contentStart = "";
/*      */     }
/* 1826 */     this.contentStart = contentStart;
/*      */   }
/*      */ 
/*      */   protected final void setContentEnd(String contentEnd)
/*      */   {
/* 1849 */     if (contentEnd == null) {
/* 1850 */       contentEnd = "";
/*      */     }
/* 1852 */     this.contentEnd = contentEnd;
/*      */   }
/*      */ 
/*      */   protected final void setFieldSeparator(String fieldSeparator)
/*      */   {
/* 1901 */     if (fieldSeparator == null) {
/* 1902 */       fieldSeparator = "";
/*      */     }
/* 1904 */     this.fieldSeparator = fieldSeparator;
/*      */   }
/*      */ 
/*      */   protected final void setFieldSeparatorAtStart(boolean fieldSeparatorAtStart)
/*      */   {
/* 1928 */     this.fieldSeparatorAtStart = true;
/*      */   }
/*      */ 
/*      */   protected final String getNullText()
/*      */   {
/* 1963 */     return this.nullText;
/*      */   }
/*      */ 
/*      */   static
/*      */   {
/*   95 */     new MultiLineToStringStyle();
/*      */ 
/*  106 */     new NoFieldNameToStringStyle();
/*      */ 
/*  118 */     new ShortPrefixToStringStyle();
/*      */ 
/*  128 */     new SimpleToStringStyle();
/*      */ 
/*  136 */     registry = new ThreadLocal()
/*      */     {
/*      */       protected final Object initialValue()
/*      */       {
/*  140 */         return new HashSet();
/*      */       }
/*      */     };
/*      */   }
/*      */ 
/*      */   private static final class MultiLineToStringStyle extends ToStringStyle
/*      */   {
/*      */     MultiLineToStringStyle()
/*      */     {
/* 2268 */       setContentStart("[");
/* 2269 */       setFieldSeparator(SystemUtils.LINE_SEPARATOR + "  ");
/* 2270 */       setFieldSeparatorAtStart(true);
/* 2271 */       setContentEnd(SystemUtils.LINE_SEPARATOR + "]");
/*      */     }
/*      */   }
/*      */ 
/*      */   private static final class SimpleToStringStyle extends ToStringStyle
/*      */   {
/*      */     SimpleToStringStyle()
/*      */     {
/* 2232 */       setUseClassName(false);
/* 2233 */       setUseIdentityHashCode(false);
/* 2234 */       setUseFieldNames(false);
/* 2235 */       setContentStart("");
/* 2236 */       setContentEnd("");
/*      */     }
/*      */   }
/*      */ 
/*      */   private static final class ShortPrefixToStringStyle extends ToStringStyle
/*      */   {
/*      */     ShortPrefixToStringStyle()
/*      */     {
/* 2200 */       setUseShortClassName(true);
/* 2201 */       setUseIdentityHashCode(false);
/*      */     }
/*      */   }
/*      */ 
/*      */   private static final class NoFieldNameToStringStyle extends ToStringStyle
/*      */   {
/*      */     NoFieldNameToStringStyle()
/*      */     {
/* 2166 */       setUseFieldNames(false);
/*      */     }
/*      */   }
/*      */ 
/*      */   private static final class DefaultToStringStyle extends ToStringStyle
/*      */   {
/*      */   }
/*      */ }

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.apache.commons.lang.builder.ToStringStyle
 * JD-Core Version:    0.6.0
 */