/*     */ package org.apache.commons.logging.impl;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.io.PrintStream;
/*     */ import java.io.PrintWriter;
/*     */ import java.io.Serializable;
/*     */ import java.io.StringWriter;
/*     */ import java.lang.reflect.InvocationTargetException;
/*     */ import java.lang.reflect.Method;
/*     */ import java.security.AccessController;
/*     */ import java.security.PrivilegedAction;
/*     */ import java.text.DateFormat;
/*     */ import java.text.SimpleDateFormat;
/*     */ import java.util.Date;
/*     */ import java.util.Properties;
/*     */ import org.apache.commons.logging.Log;
/*     */ import org.apache.commons.logging.LogConfigurationException;
/*     */ 
/*     */ public class SimpleLog
/*     */   implements Serializable, Log
/*     */ {
/*  88 */   private static Properties simpleLogProps = new Properties();
/*     */ 
/*  94 */   private static boolean showLogName = false;
/*     */ 
/* 100 */   private static boolean showShortName = true;
/*     */ 
/* 102 */   private static boolean showDateTime = false;
/*     */ 
/* 104 */   private static String dateTimeFormat = "yyyy/MM/dd HH:mm:ss:SSS zzz";
/*     */ 
/* 106 */   private static DateFormat dateFormatter = null;
/*     */   public static final int LOG_LEVEL_TRACE = 1;
/*     */   public static final int LOG_LEVEL_DEBUG = 2;
/*     */   public static final int LOG_LEVEL_INFO = 3;
/*     */   public static final int LOG_LEVEL_WARN = 4;
/*     */   public static final int LOG_LEVEL_ERROR = 5;
/*     */   public static final int LOG_LEVEL_FATAL = 6;
/*     */   public static final int LOG_LEVEL_ALL = 0;
/*     */   public static final int LOG_LEVEL_OFF = 7;
/* 188 */   private String logName = null;
/*     */   private int currentLogLevel;
/* 192 */   private String shortLogName = null;
/*     */ 
/*     */   private static String getStringProperty(String paramString)
/*     */   {
/* 132 */     String str = null;
/*     */     try {
/* 134 */       str = System.getProperty(paramString);
/*     */     }
/*     */     catch (SecurityException localSecurityException) {
/*     */     }
/* 138 */     if (str == null) return simpleLogProps.getProperty(paramString); return str;
/*     */   }
/*     */ 
/*     */   private static boolean getBooleanProperty(String paramString, boolean paramBoolean)
/*     */   {
/* 148 */     if ((
/* 148 */       paramString = getStringProperty(paramString)) == null)
/* 148 */       return paramBoolean; return "true".equalsIgnoreCase(paramString);
/*     */   }
/*     */ 
/*     */   public SimpleLog(String paramString)
/*     */   {
/* 204 */     this.logName = paramString;
/*     */ 
/* 209 */     setLevel(3);
/*     */ 
/* 212 */     String str = getStringProperty("org.apache.commons.logging.simplelog.log." + this.logName);
/* 213 */     int i = String.valueOf(paramString).lastIndexOf(".");
/* 214 */     while ((str == null) && (i > -1)) {
/* 215 */       paramString = paramString.substring(0, i);
/* 216 */       str = getStringProperty("org.apache.commons.logging.simplelog.log." + paramString);
/* 217 */       i = String.valueOf(paramString).lastIndexOf(".");
/*     */     }
/*     */ 
/* 220 */     if (str == null) {
/* 221 */       str = getStringProperty("org.apache.commons.logging.simplelog.defaultlog");
/*     */     }
/*     */ 
/* 224 */     if ("all".equalsIgnoreCase(str)) {
/* 225 */       setLevel(0); return;
/* 226 */     }if ("trace".equalsIgnoreCase(str)) {
/* 227 */       setLevel(1); return;
/* 228 */     }if ("debug".equalsIgnoreCase(str)) {
/* 229 */       setLevel(2); return;
/* 230 */     }if ("info".equalsIgnoreCase(str)) {
/* 231 */       setLevel(3); return;
/* 232 */     }if ("warn".equalsIgnoreCase(str)) {
/* 233 */       setLevel(4); return;
/* 234 */     }if ("error".equalsIgnoreCase(str)) {
/* 235 */       setLevel(5); return;
/* 236 */     }if ("fatal".equalsIgnoreCase(str)) {
/* 237 */       setLevel(6); return;
/* 238 */     }if ("off".equalsIgnoreCase(str))
/* 239 */       setLevel(7);
/*     */   }
/*     */ 
/*     */   public void setLevel(int currentLogLevel)
/*     */   {
/* 256 */     this.currentLogLevel = currentLogLevel;
/*     */   }
/*     */ 
/*     */   public int getLevel()
/*     */   {
/* 267 */     return this.currentLogLevel;
/*     */   }
/*     */ 
/*     */   private void log(int paramInt, Object paramObject, Throwable paramThrowable)
/*     */   {
/* 287 */     StringBuffer localStringBuffer = new StringBuffer();
/*     */ 
/* 290 */     if (showDateTime) {
/* 291 */       localStringBuffer.append(dateFormatter.format(new Date()));
/* 292 */       localStringBuffer.append(" ");
/*     */     }
/*     */ 
/* 296 */     switch (paramInt) {
/*     */     case 1:
/* 298 */       localStringBuffer.append("[TRACE] ");
/* 299 */       break;
/*     */     case 2:
/* 301 */       localStringBuffer.append("[DEBUG] ");
/* 302 */       break;
/*     */     case 3:
/* 304 */       localStringBuffer.append("[INFO] ");
/* 305 */       break;
/*     */     case 4:
/* 307 */       localStringBuffer.append("[WARN] ");
/* 308 */       break;
/*     */     case 5:
/* 310 */       localStringBuffer.append("[ERROR] ");
/* 311 */       break;
/*     */     case 6:
/* 313 */       localStringBuffer.append("[FATAL] ");
/*     */     }
/*     */ 
/* 318 */     if (showShortName) {
/* 319 */       if (this.shortLogName == null)
/*     */       {
/* 321 */         this.shortLogName = this.logName.substring(this.logName.lastIndexOf(".") + 1);
/* 322 */         this.shortLogName = this.shortLogName.substring(this.shortLogName.lastIndexOf("/") + 1);
/*     */       }
/*     */ 
/* 325 */       localStringBuffer.append(String.valueOf(this.shortLogName)).append(" - ");
/* 326 */     } else if (showLogName) {
/* 327 */       localStringBuffer.append(String.valueOf(this.logName)).append(" - ");
/*     */     }
/*     */ 
/* 331 */     localStringBuffer.append(String.valueOf(paramObject));
/*     */ 
/* 334 */     if (paramThrowable != null) {
/* 335 */       localStringBuffer.append(" <");
/* 336 */       localStringBuffer.append(paramThrowable.toString());
/* 337 */       localStringBuffer.append(">");
/*     */ 
/* 339 */       this = new StringWriter(1024);
/* 340 */       paramInt = new PrintWriter(this);
/* 341 */       paramThrowable.printStackTrace(paramInt);
/* 342 */       paramInt.close();
/* 343 */       localStringBuffer.append(toString());
/*     */     }
/*     */ 
/* 347 */     this = localStringBuffer; System.err.println(toString());
/*     */   }
/*     */ 
/*     */   private boolean isLevelEnabled(int paramInt)
/*     */   {
/* 377 */     return paramInt >= this.currentLogLevel;
/*     */   }
/*     */ 
/*     */   public final void debug(Object message)
/*     */   {
/* 389 */     if (isLevelEnabled(2))
/* 390 */       log(2, message, null);
/*     */   }
/*     */ 
/*     */   public final void debug(Object message, Throwable t)
/*     */   {
/* 401 */     if (isLevelEnabled(2))
/* 402 */       log(2, message, t);
/*     */   }
/*     */ 
/*     */   public final void trace(Object message)
/*     */   {
/* 413 */     if (isLevelEnabled(1))
/* 414 */       log(1, message, null);
/*     */   }
/*     */ 
/*     */   public final void trace(Object message, Throwable t)
/*     */   {
/* 425 */     if (isLevelEnabled(1))
/* 426 */       log(1, message, t);
/*     */   }
/*     */ 
/*     */   public final void info(Object message)
/*     */   {
/* 437 */     if (isLevelEnabled(3))
/* 438 */       log(3, message, null);
/*     */   }
/*     */ 
/*     */   public final void info(Object message, Throwable t)
/*     */   {
/* 449 */     if (isLevelEnabled(3))
/* 450 */       log(3, message, t);
/*     */   }
/*     */ 
/*     */   public final void warn(Object message)
/*     */   {
/* 461 */     if (isLevelEnabled(4))
/* 462 */       log(4, message, null);
/*     */   }
/*     */ 
/*     */   public final void warn(Object message, Throwable t)
/*     */   {
/* 473 */     if (isLevelEnabled(4))
/* 474 */       log(4, message, t);
/*     */   }
/*     */ 
/*     */   public final void error(Object message)
/*     */   {
/* 485 */     if (isLevelEnabled(5))
/* 486 */       log(5, message, null);
/*     */   }
/*     */ 
/*     */   public final void error(Object message, Throwable t)
/*     */   {
/* 497 */     if (isLevelEnabled(5))
/* 498 */       log(5, message, t);
/*     */   }
/*     */ 
/*     */   public final void fatal(Object message)
/*     */   {
/* 509 */     if (isLevelEnabled(6))
/* 510 */       log(6, message, null);
/*     */   }
/*     */ 
/*     */   public final void fatal(Object message, Throwable t)
/*     */   {
/* 521 */     if (isLevelEnabled(6))
/* 522 */       log(6, message, t);
/*     */   }
/*     */ 
/*     */   public final boolean isDebugEnabled()
/*     */   {
/* 538 */     return isLevelEnabled(2);
/*     */   }
/*     */ 
/*     */   public final boolean isErrorEnabled()
/*     */   {
/* 553 */     return isLevelEnabled(5);
/*     */   }
/*     */ 
/*     */   public final boolean isFatalEnabled()
/*     */   {
/* 568 */     return isLevelEnabled(6);
/*     */   }
/*     */ 
/*     */   public final boolean isInfoEnabled()
/*     */   {
/* 583 */     return isLevelEnabled(3);
/*     */   }
/*     */ 
/*     */   public final boolean isTraceEnabled()
/*     */   {
/* 598 */     return isLevelEnabled(1);
/*     */   }
/*     */ 
/*     */   public final boolean isWarnEnabled()
/*     */   {
/* 613 */     return isLevelEnabled(4);
/*     */   }
/*     */ 
/*     */   private static ClassLoader getContextClassLoader()
/*     */   {
/* 626 */     ClassLoader localClassLoader = null;
/*     */     try {
/* 628 */       Object localObject = Thread.class.getMethod("getContextClassLoader", null);
/*     */       try
/*     */       {
/* 635 */         localClassLoader = (ClassLoader)((Method)localObject).invoke(Thread.currentThread(), null);
/*     */       }
/*     */       catch (IllegalAccessException localIllegalAccessException)
/*     */       {
/*     */       }
/*     */       catch (InvocationTargetException localInvocationTargetException)
/*     */       {
/* 653 */         if (!((
/* 653 */           localObject = 
/* 661 */           localInvocationTargetException).getTargetException() instanceof SecurityException))
/*     */         {
/* 658 */           throw new LogConfigurationException("Unexpected InvocationTargetException", ((InvocationTargetException)localObject).getTargetException());
/*     */         }
/*     */ 
/*     */       }
/*     */ 
/*     */     }
/*     */     catch (NoSuchMethodException localNoSuchMethodException)
/*     */     {
/*     */     }
/*     */ 
/* 668 */     if (localClassLoader == null) {
/* 669 */       localClassLoader = SimpleLog.class.getClassLoader();
/*     */     }
/*     */ 
/* 673 */     return (ClassLoader)localClassLoader;
/*     */   }
/*     */ 
/*     */   static
/*     */   {
/* 156 */     Object localObject = "simplelog.properties"; localObject = (InputStream)AccessController.doPrivileged(new PrivilegedAction((String)localObject)
/*     */     {
/*     */       private final String val$name;
/*     */ 
/*     */       public final Object run()
/*     */       {
/*     */         ClassLoader threadCL;
/* 681 */         if ((
/* 681 */           threadCL = SimpleLog.access$000()) != null)
/*     */         {
/* 682 */           return threadCL.getResourceAsStream(this.val$name);
/*     */         }
/* 684 */         return ClassLoader.getSystemResourceAsStream(this.val$name);
/*     */       }
/*     */     });
/* 157 */     if (localObject != null) {
/*     */       try {
/* 159 */         simpleLogProps.load((InputStream)localObject);
/* 160 */         ((InputStream)localObject).close();
/*     */       }
/*     */       catch (IOException localIOException)
/*     */       {
/*     */       }
/*     */     }
/* 166 */     showLogName = getBooleanProperty("org.apache.commons.logging.simplelog.showlogname", showLogName);
/* 167 */     showShortName = getBooleanProperty("org.apache.commons.logging.simplelog.showShortLogname", showShortName);
/*     */ 
/* 172 */     if ((
/* 172 */       SimpleLog.showDateTime = getBooleanProperty("org.apache.commons.logging.simplelog.showdatetime", showDateTime)))
/*     */     {
/* 173 */       String str = dateTimeFormat; dateTimeFormat = (localObject = getStringProperty(localObject = "org.apache.commons.logging.simplelog.dateTimeFormat")) == null ? str : (String)localObject;
/*     */       try
/*     */       {
/* 176 */         dateFormatter = new SimpleDateFormat(dateTimeFormat);
/*     */ 
/* 181 */         return;
/*     */       }
/*     */       catch (IllegalArgumentException localIllegalArgumentException)
/*     */       {
/* 179 */         dateTimeFormat = "yyyy/MM/dd HH:mm:ss:SSS zzz";
/* 180 */         dateFormatter = new SimpleDateFormat(dateTimeFormat);
/*     */       }
/*     */     }
/*     */   }
/*     */ }

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.apache.commons.logging.impl.SimpleLog
 * JD-Core Version:    0.6.0
 */