package org.bouncycastle.asn1;

import java.io.ByteArrayInputStream;
import java.io.EOFException;
import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;

public final class ASN1InputStream extends FilterInputStream
{
  private final int limit;
  private final boolean lazyEvaluate;

  static int findLimit(InputStream paramInputStream)
  {
    if ((paramInputStream instanceof LimitedInputStream))
      return ((LimitedInputStream)paramInputStream).getRemaining();
    if ((paramInputStream instanceof ByteArrayInputStream))
      return ((ByteArrayInputStream)paramInputStream).available();
    return 2147483647;
  }

  private ASN1InputStream(InputStream paramInputStream)
  {
    this(paramInputStream, findLimit(paramInputStream));
  }

  public ASN1InputStream(byte[] paramArrayOfByte)
  {
    this(new ByteArrayInputStream(paramArrayOfByte), paramArrayOfByte.length);
  }

  public ASN1InputStream(byte[] paramArrayOfByte, boolean paramBoolean)
  {
    this(new ByteArrayInputStream(paramArrayOfByte), paramArrayOfByte.length, true);
  }

  private ASN1InputStream(InputStream paramInputStream, int paramInt)
  {
    this(paramInputStream, paramInt, false);
  }

  private ASN1InputStream(InputStream paramInputStream, int paramInt, boolean paramBoolean)
  {
    super(paramInputStream);
    this.limit = paramInt;
    this.lazyEvaluate = paramBoolean;
  }

  private static ASN1EncodableVector buildDEREncodableVector(DefiniteLengthInputStream paramDefiniteLengthInputStream)
    throws IOException
  {
    paramDefiniteLengthInputStream = new ASN1InputStream(paramDefiniteLengthInputStream);
    ASN1EncodableVector localASN1EncodableVector = new ASN1EncodableVector();
    DERObject localDERObject;
    while ((localDERObject = paramDefiniteLengthInputStream.readObject()) != null)
      localASN1EncodableVector.add(localDERObject);
    return localASN1EncodableVector;
  }

  public final DERObject readObject()
    throws IOException
  {
    ASN1InputStream localASN1InputStream1;
    if ((localASN1InputStream1 = read()) <= 0)
    {
      if (localASN1InputStream1 == 0)
        throw new IOException("unexpected end-of-contents marker");
      return null;
    }
    ASN1InputStream localASN1InputStream2 = readTagNumber(this, localASN1InputStream1);
    int i = (localASN1InputStream1 & 0x20) != 0 ? 1 : 0;
    ASN1InputStream localASN1InputStream3 = this;
    ASN1InputStream localASN1InputStream4;
    if ((localASN1InputStream4 = readLength(this, localASN1InputStream3.limit)) < 0)
    {
      if (i == 0)
        throw new IOException("indefinite length primitive encoding encountered");
      IndefiniteLengthInputStream localIndefiniteLengthInputStream = new IndefiniteLengthInputStream(this, this.limit);
      this = new ASN1StreamParser(localIndefiniteLengthInputStream, this.limit);
      if ((localASN1InputStream1 & 0x40) != 0)
        return new ASN1ApplicationSpecificParser(localASN1InputStream2, this).getLoadedObject();
      if ((localASN1InputStream1 & 0x80) != 0)
        return new BERTaggedObjectParser(true, localASN1InputStream2, this).getLoadedObject();
      switch (localASN1InputStream2)
      {
      case 4:
        return new BEROctetStringParser(this).getLoadedObject();
      case 16:
        return new BERSequenceParser(this).getLoadedObject();
      case 17:
        return new BERSetParser(this).getLoadedObject();
      case 8:
        return new DERExternalParser(this).getLoadedObject();
      }
      throw new IOException("unknown BER object encountered");
    }
    try
    {
      localASN1InputStream2 = localASN1InputStream4;
      localASN1InputStream1 = localASN1InputStream2;
      this = localASN1InputStream1;
      ASN1InputStream localASN1InputStream5 = this;
      boolean bool = (this & 0x20) != 0;
      DefiniteLengthInputStream localDefiniteLengthInputStream = new DefiniteLengthInputStream(localASN1InputStream5, localASN1InputStream2);
      if ((this & 0x40) != 0)
        return new DERApplicationSpecific(bool, localASN1InputStream1, localDefiniteLengthInputStream.toByteArray());
      if ((this & 0x80) != 0)
        return new ASN1StreamParser(localDefiniteLengthInputStream).readTaggedObject(bool, localASN1InputStream1);
      if (bool)
      {
        switch (localASN1InputStream1)
        {
        case 4:
          return new BERConstructedOctetString(buildDEREncodableVector(localDefiniteLengthInputStream).v);
        case 16:
          if (localASN1InputStream5.lazyEvaluate)
            return new LazyDERSequence(localDefiniteLengthInputStream.toByteArray());
          return DERFactory.createSequence(buildDEREncodableVector(localDefiniteLengthInputStream));
        case 17:
          return DERFactory.createSet(buildDEREncodableVector(localDefiniteLengthInputStream), false);
        case 8:
          return new DERExternal(buildDEREncodableVector(localDefiniteLengthInputStream));
        }
        return new DERUnknownTag(true, localASN1InputStream1, localDefiniteLengthInputStream.toByteArray());
      }
      return createPrimitiveDERObject(localASN1InputStream1, localDefiniteLengthInputStream.toByteArray());
    }
    catch (IllegalArgumentException localIllegalArgumentException)
    {
    }
    throw new ASN1Exception("corrupted stream detected", localIllegalArgumentException);
  }

  static int readTagNumber(InputStream paramInputStream, int paramInt)
    throws IOException
  {
    if ((paramInt &= 31) == 31)
    {
      paramInt = 0;
      int i;
      if (((i = paramInputStream.read()) & 0x7F) == 0)
        throw new IOException("corrupted stream - invalid high tag number found");
      while ((i >= 0) && ((i & 0x80) != 0))
      {
        paramInt = (paramInt |= i & 0x7F) << 7;
        i = paramInputStream.read();
      }
      if (i < 0)
        throw new EOFException("EOF found inside tag value.");
      paramInt |= i & 0x7F;
    }
    return paramInt;
  }

  static int readLength(InputStream paramInputStream, int paramInt)
    throws IOException
  {
    int i;
    if ((i = paramInputStream.read()) < 0)
      throw new EOFException("EOF found when length expected");
    if (i == 128)
      return -1;
    if (i > 127)
    {
      int j;
      if ((j = i & 0x7F) > 4)
        throw new IOException("DER length more than 4 bytes: " + j);
      i = 0;
      for (int k = 0; k < j; k++)
      {
        int m;
        if ((m = paramInputStream.read()) < 0)
          throw new EOFException("EOF found reading length");
        i = (i << 8) + m;
      }
      if (i < 0)
        throw new IOException("corrupted stream - negative length found");
      if (i >= paramInt)
        throw new IOException("corrupted stream - out of bounds length found");
    }
    return i;
  }

  static DERObject createPrimitiveDERObject(int paramInt, byte[] paramArrayOfByte)
  {
    switch (paramInt)
    {
    case 3:
      return DERBitString.fromOctetString(paramArrayOfByte);
    case 30:
      return new DERBMPString(paramArrayOfByte);
    case 1:
      return new ASN1Boolean(paramArrayOfByte);
    case 10:
      return new ASN1Enumerated(paramArrayOfByte);
    case 24:
      return new ASN1GeneralizedTime(paramArrayOfByte);
    case 27:
      return new DERGeneralString(paramArrayOfByte);
    case 22:
      return new DERIA5String(paramArrayOfByte);
    case 2:
      return new ASN1Integer(paramArrayOfByte);
    case 5:
      return DERNull.INSTANCE;
    case 18:
      return new DERNumericString(paramArrayOfByte);
    case 6:
      return new ASN1ObjectIdentifier(paramArrayOfByte);
    case 4:
      return new DEROctetString(paramArrayOfByte);
    case 19:
      return new DERPrintableString(paramArrayOfByte);
    case 20:
      return new DERT61String(paramArrayOfByte);
    case 28:
      return new DERUniversalString(paramArrayOfByte);
    case 23:
      return new ASN1UTCTime(paramArrayOfByte);
    case 12:
      return new DERUTF8String(paramArrayOfByte);
    case 26:
      return new DERVisibleString(paramArrayOfByte);
    case 7:
    case 8:
    case 9:
    case 11:
    case 13:
    case 14:
    case 15:
    case 16:
    case 17:
    case 21:
    case 25:
    case 29:
    }
    return new DERUnknownTag(false, paramInt, paramArrayOfByte);
  }
}

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.bouncycastle.asn1.ASN1InputStream
 * JD-Core Version:    0.6.0
 */