package org.bouncycastle.asn1;

import java.io.IOException;
import java.io.InputStream;
import java.util.Vector;

public class ASN1StreamParser
{
  private final InputStream _in;
  private final int _limit;

  public ASN1StreamParser(InputStream paramInputStream)
  {
    this(paramInputStream, ASN1InputStream.findLimit(paramInputStream));
  }

  public ASN1StreamParser(InputStream paramInputStream, int paramInt)
  {
    this._in = paramInputStream;
    this._limit = paramInt;
  }

  final DERObject readTaggedObject(boolean paramBoolean, int paramInt)
    throws IOException
  {
    if (!paramBoolean)
    {
      paramBoolean = (DefiniteLengthInputStream)this._in;
      return new DERTaggedObject(false, paramInt, new DEROctetString(paramBoolean.toByteArray()));
    }
    paramBoolean = readVector();
    if ((this._in instanceof IndefiniteLengthInputStream))
    {
      if ((this = paramBoolean).v.size() == 1)
        return new BERTaggedObject(true, paramInt, paramBoolean.get(0));
      return new BERTaggedObject(false, paramInt, BERFactory.createSequence(paramBoolean));
    }
    if ((this = paramBoolean).v.size() == 1)
      return new DERTaggedObject(true, paramInt, paramBoolean.get(0));
    return new DERTaggedObject(false, paramInt, DERFactory.createSequence(paramBoolean));
  }

  public final DEREncodable readObject()
    throws IOException
  {
    int i;
    if ((i = this._in.read()) == -1)
      return null;
    int k = 0;
    ASN1StreamParser localASN1StreamParser1 = this;
    if ((this._in instanceof IndefiniteLengthInputStream))
      ((IndefiniteLengthInputStream)localASN1StreamParser1._in).setEofOn00(false);
    int j = ASN1InputStream.readTagNumber(this._in, i);
    k = (i & 0x20) != 0 ? 1 : 0;
    int m;
    ASN1StreamParser localASN1StreamParser2;
    if ((m = ASN1InputStream.readLength(this._in, this._limit)) < 0)
    {
      if (k == 0)
        throw new IOException("indefinite length primitive encoding encountered");
      localObject = new IndefiniteLengthInputStream(this._in, this._limit);
      this = new ASN1StreamParser((InputStream)localObject, this._limit);
      if ((i & 0x40) != 0)
        return new ASN1ApplicationSpecificParser(j, this);
      if ((i & 0x80) != 0)
        return new BERTaggedObjectParser(true, j, this);
      k = j;
      localASN1StreamParser2 = this;
      switch (k)
      {
      case 8:
        return new DERExternalParser(localASN1StreamParser2);
      case 4:
        return new BEROctetStringParser(localASN1StreamParser2);
      case 16:
        return new BERSequenceParser(localASN1StreamParser2);
      case 17:
        return new BERSetParser(localASN1StreamParser2);
      }
      throw new ASN1Exception("unknown BER object encountered: 0x" + Integer.toHexString(k));
    }
    Object localObject = new DefiniteLengthInputStream(this._in, localObject);
    if ((i & 0x40) != 0)
      return new DERApplicationSpecific(k, localASN1StreamParser2, ((DefiniteLengthInputStream)localObject).toByteArray());
    if ((i & 0x80) != 0)
      return new BERTaggedObjectParser(k, localASN1StreamParser2, new ASN1StreamParser((InputStream)localObject));
    if (k != 0)
    {
      switch (localASN1StreamParser2)
      {
      case 4:
        return new BEROctetStringParser(new ASN1StreamParser((InputStream)localObject));
      case 16:
        return new DERSequenceParser(new ASN1StreamParser((InputStream)localObject));
      case 17:
        return new DERSetParser(new ASN1StreamParser((InputStream)localObject));
      case 8:
        return new DERExternalParser(new ASN1StreamParser((InputStream)localObject));
      }
      return new DERUnknownTag(true, localASN1StreamParser2, ((DefiniteLengthInputStream)localObject).toByteArray());
    }
    switch (localASN1StreamParser2)
    {
    case 4:
      return new DEROctetStringParser((DefiniteLengthInputStream)localObject);
    }
    try
    {
      return ASN1InputStream.createPrimitiveDERObject(localASN1StreamParser2, ((DefiniteLengthInputStream)localObject).toByteArray());
    }
    catch (java.lang.IllegalArgumentException this)
    {
    }
    throw new ASN1Exception("corrupted stream detected", this);
  }

  final ASN1EncodableVector readVector()
    throws IOException
  {
    ASN1EncodableVector localASN1EncodableVector = new ASN1EncodableVector();
    DEREncodable localDEREncodable;
    while ((localDEREncodable = readObject()) != null)
    {
      if ((localDEREncodable instanceof InMemoryRepresentable))
      {
        localASN1EncodableVector.add(((InMemoryRepresentable)localDEREncodable).getLoadedObject());
        continue;
      }
      localASN1EncodableVector.add(localDEREncodable.getDERObject());
    }
    return localASN1EncodableVector;
  }

  public ASN1StreamParser()
  {
  }

  public static String toLowerCase(String paramString)
  {
    int i = 0;
    char[] arrayOfChar = paramString.toCharArray();
    for (int j = 0; j != arrayOfChar.length; j++)
    {
      int k = arrayOfChar[j];
      if ((65 > k) || (90 < k))
        continue;
      i = 1;
      arrayOfChar[j] = (char)(k - 65 + 97);
    }
    if (i != 0)
      return new String(arrayOfChar);
    return paramString;
  }
}

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.bouncycastle.asn1.ASN1StreamParser
 * JD-Core Version:    0.6.0
 */