package org.bouncycastle.asn1;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.Vector;

public final class DERExternal extends ASN1Object
{
  private DERObjectIdentifier directReference;
  private DERInteger indirectReference;
  private ASN1Object dataValueDescriptor;
  private int encoding;
  private DERObject externalContent;

  public DERExternal(ASN1EncodableVector paramASN1EncodableVector)
  {
    int i = 0;
    DERObject localDERObject;
    if (((localDERObject = getObjFromVector(paramASN1EncodableVector, 0)) instanceof DERObjectIdentifier))
    {
      this.directReference = ((DERObjectIdentifier)localDERObject);
      i++;
      localDERObject = getObjFromVector(paramASN1EncodableVector, 1);
    }
    if ((localDERObject instanceof DERInteger))
    {
      this.indirectReference = ((DERInteger)localDERObject);
      i++;
      localDERObject = getObjFromVector(paramASN1EncodableVector, i);
    }
    if (!(localDERObject instanceof DERTaggedObject))
    {
      this.dataValueDescriptor = ((ASN1Object)localDERObject);
      i++;
      localDERObject = getObjFromVector(paramASN1EncodableVector, i);
    }
    ASN1EncodableVector localASN1EncodableVector;
    if ((localASN1EncodableVector = paramASN1EncodableVector).v.size() != i + 1)
      throw new IllegalArgumentException("input vector too large");
    if (!(localDERObject instanceof DERTaggedObject))
      throw new IllegalArgumentException("No tagged object found in vector. Structure doesn't seem to be of type External");
    paramASN1EncodableVector = (DERTaggedObject)localDERObject;
    int j = (localASN1EncodableVector = paramASN1EncodableVector).tagNo;
    DERExternal localDERExternal = this;
    if ((j < 0) || (j > 2))
      throw new IllegalArgumentException("invalid encoding value: " + j);
    localDERExternal.encoding = j;
    this.externalContent = paramASN1EncodableVector.getObject();
  }

  private static DERObject getObjFromVector(ASN1EncodableVector paramASN1EncodableVector, int paramInt)
  {
    ASN1EncodableVector localASN1EncodableVector = paramASN1EncodableVector;
    if (paramASN1EncodableVector.v.size() <= paramInt)
      throw new IllegalArgumentException("too few objects in input vector");
    return paramASN1EncodableVector.get(paramInt).getDERObject();
  }

  public final int hashCode()
  {
    int i = 0;
    if (this.directReference != null)
      i = this.directReference.hashCode();
    if (this.indirectReference != null)
      i ^= this.indirectReference.hashCode();
    if (this.dataValueDescriptor != null)
      i ^= this.dataValueDescriptor.hashCode();
    return i ^= this.externalContent.hashCode();
  }

  final void encode(DEROutputStream paramDEROutputStream)
    throws IOException
  {
    ByteArrayOutputStream localByteArrayOutputStream = new ByteArrayOutputStream();
    if (this.directReference != null)
      localByteArrayOutputStream.write(this.directReference.getDEREncoded());
    if (this.indirectReference != null)
      localByteArrayOutputStream.write(this.indirectReference.getDEREncoded());
    if (this.dataValueDescriptor != null)
      localByteArrayOutputStream.write(this.dataValueDescriptor.getDEREncoded());
    this = new DERTaggedObject(this.encoding, this.externalContent);
    localByteArrayOutputStream.write(getDEREncoded());
    paramDEROutputStream.writeEncoded(32, 8, localByteArrayOutputStream.toByteArray());
  }

  final boolean asn1Equals(DERObject paramDERObject)
  {
    if (!(paramDERObject instanceof DERExternal))
      return false;
    if (this == paramDERObject)
      return true;
    paramDERObject = (DERExternal)paramDERObject;
    if ((this.directReference != null) && ((paramDERObject.directReference == null) || (!paramDERObject.directReference.equals(this.directReference))))
      return false;
    if ((this.indirectReference != null) && ((paramDERObject.indirectReference == null) || (!paramDERObject.indirectReference.equals(this.indirectReference))))
      return false;
    if ((this.dataValueDescriptor != null) && ((paramDERObject.dataValueDescriptor == null) || (!paramDERObject.dataValueDescriptor.equals(this.dataValueDescriptor))))
      return false;
    return this.externalContent.equals(paramDERObject.externalContent);
  }

  public final ASN1Object getDataValueDescriptor()
  {
    return this.dataValueDescriptor;
  }

  public final DERObjectIdentifier getDirectReference()
  {
    return this.directReference;
  }

  public final int getEncoding()
  {
    return this.encoding;
  }

  public final DERObject getExternalContent()
  {
    return this.externalContent;
  }

  public final DERInteger getIndirectReference()
  {
    return this.indirectReference;
  }
}

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.bouncycastle.asn1.DERExternal
 * JD-Core Version:    0.6.0
 */