package org.bouncycastle.asn1;

import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.SimpleTimeZone;
import java.util.TimeZone;

public class DERGeneralizedTime extends ASN1Object
{
  private String time;

  public DERGeneralizedTime(String paramString)
  {
    this.time = paramString;
    try
    {
      getDate();
      return;
    }
    catch (ParseException this)
    {
    }
    throw new IllegalArgumentException("invalid date string: " + getMessage());
  }

  DERGeneralizedTime(byte[] paramArrayOfByte)
  {
    char[] arrayOfChar = new char[paramArrayOfByte.length];
    for (int i = 0; i != arrayOfChar.length; i++)
      arrayOfChar[i] = (char)(paramArrayOfByte[i] & 0xFF);
    this.time = new String(arrayOfChar);
  }

  public final String getTime()
  {
    if (this.time.charAt(this.time.length() - 1) == 'Z')
      return this.time.substring(0, this.time.length() - 1) + "GMT+00:00";
    int i = this.time.length() - 5;
    int j;
    if (((j = this.time.charAt(i)) == '-') || (j == 43))
      return this.time.substring(0, i) + "GMT" + this.time.substring(i, i + 3) + ":" + this.time.substring(i + 3);
    i = this.time.length() - 3;
    if (((j = this.time.charAt(i)) == '-') || (j == 43))
      return this.time.substring(0, i) + "GMT" + this.time.substring(i) + ":00";
    return this.time + calculateGMTOffset();
  }

  private String calculateGMTOffset()
  {
    String str = "+";
    TimeZone localTimeZone;
    if ((i = (localTimeZone = TimeZone.getDefault()).getRawOffset()) < 0)
    {
      str = "-";
      i = -i;
    }
    int j = i / 3600000;
    int i = (i - j * 60 * 60 * 1000) / 60000;
    try
    {
      if ((localTimeZone.useDaylightTime()) && (localTimeZone.inDaylightTime(getDate())))
        j += (str.equals("+") ? 1 : -1);
    }
    catch (ParseException localParseException)
    {
    }
    return "GMT" + str + convert(j) + ":" + convert(i);
  }

  private static String convert(int paramInt)
  {
    if (paramInt < 10)
      return "0" + paramInt;
    return Integer.toString(paramInt);
  }

  private Date getDate()
    throws ParseException
  {
    String str = this.time;
    SimpleDateFormat localSimpleDateFormat;
    if (this.time.endsWith("Z"))
    {
      if (hasFractionalSeconds())
        localSimpleDateFormat = new SimpleDateFormat("yyyyMMddHHmmss.SSS'Z'");
      else
        localSimpleDateFormat = new SimpleDateFormat("yyyyMMddHHmmss'Z'");
      localSimpleDateFormat.setTimeZone(new SimpleTimeZone(0, "Z"));
    }
    else if ((this.time.indexOf('-') > 0) || (this.time.indexOf('+') > 0))
    {
      str = getTime();
      if (hasFractionalSeconds())
        localSimpleDateFormat = new SimpleDateFormat("yyyyMMddHHmmss.SSSz");
      else
        localSimpleDateFormat = new SimpleDateFormat("yyyyMMddHHmmssz");
      localSimpleDateFormat.setTimeZone(new SimpleTimeZone(0, "Z"));
    }
    else
    {
      if (hasFractionalSeconds())
        localSimpleDateFormat = new SimpleDateFormat("yyyyMMddHHmmss.SSS");
      else
        localSimpleDateFormat = new SimpleDateFormat("yyyyMMddHHmmss");
      localSimpleDateFormat.setTimeZone(new SimpleTimeZone(0, TimeZone.getDefault().getID()));
    }
    if (hasFractionalSeconds())
    {
      this = str.substring(14);
      for (int i = 1; i < length(); i++)
      {
        int j = charAt(i);
        if ((48 > j) || (j > 57))
          break;
      }
      if (i - 1 > 3)
      {
        this = substring(0, 4) + substring(i);
        str = str.substring(0, 14) + this;
      }
      else if (i - 1 == 1)
      {
        this = substring(0, i) + "00" + substring(i);
        str = str.substring(0, 14) + this;
      }
      else if (i - 1 == 2)
      {
        this = substring(0, i) + "0" + substring(i);
        str = str.substring(0, 14) + this;
      }
    }
    return localSimpleDateFormat.parse(str);
  }

  private boolean hasFractionalSeconds()
  {
    return this.time.indexOf('.') == 14;
  }

  final void encode(DEROutputStream paramDEROutputStream)
    throws IOException
  {
    this = this;
    paramDEROutputStream = new byte[(this = this.time.toCharArray()).length];
    int i = 0;
    if (i != this.length)
    {
      paramDEROutputStream[i] = (byte)this[i];
      i++;
      tmpTernaryOp = 24;
      while (true);
    }
  }

  final boolean asn1Equals(DERObject paramDERObject)
  {
    if (!(paramDERObject instanceof DERGeneralizedTime))
      return false;
    return this.time.equals(((DERGeneralizedTime)paramDERObject).time);
  }

  public int hashCode()
  {
    return this.time.hashCode();
  }
}

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.bouncycastle.asn1.DERGeneralizedTime
 * JD-Core Version:    0.6.0
 */