package org.bouncycastle.asn1;

import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import org.bouncycastle.util.io.Streams;

final class DefiniteLengthInputStream extends LimitedInputStream
{
  private static final byte[] EMPTY_BYTES = new byte[0];
  private final int _originalLength;
  private int _remaining;

  DefiniteLengthInputStream(InputStream paramInputStream, int paramInt)
  {
    super(paramInputStream, paramInt);
    if (paramInt < 0)
      throw new IllegalArgumentException("negative lengths not allowed");
    this._originalLength = paramInt;
    this._remaining = paramInt;
    if (paramInt == 0)
      setParentEofDetect(true);
  }

  final int getRemaining()
  {
    return this._remaining;
  }

  public final int read()
    throws IOException
  {
    if (this._remaining == 0)
      return -1;
    int i;
    if ((i = this._in.read()) < 0)
      throw new EOFException("DEF length " + this._originalLength + " object truncated by " + this._remaining);
    if (--this._remaining == 0)
      setParentEofDetect(true);
    return i;
  }

  public final int read(byte[] paramArrayOfByte, int paramInt1, int paramInt2)
    throws IOException
  {
    if (this._remaining == 0)
      return -1;
    paramInt2 = Math.min(paramInt2, this._remaining);
    if ((paramArrayOfByte = this._in.read(paramArrayOfByte, paramInt1, paramInt2)) < 0)
      throw new EOFException("DEF length " + this._originalLength + " object truncated by " + this._remaining);
    if (this._remaining -= paramArrayOfByte == 0)
      setParentEofDetect(true);
    return paramArrayOfByte;
  }

  final byte[] toByteArray()
    throws IOException
  {
    if (this._remaining == 0)
      return EMPTY_BYTES;
    byte[] arrayOfByte = new byte[this._remaining];
    if (this._remaining -= Streams.readFully(this._in, arrayOfByte) != 0)
      throw new EOFException("DEF length " + this._originalLength + " object truncated by " + this._remaining);
    setParentEofDetect(true);
    return arrayOfByte;
  }
}

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.bouncycastle.asn1.DefiniteLengthInputStream
 * JD-Core Version:    0.6.0
 */