package org.bouncycastle.asn1.util;

import java.io.IOException;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.MissingResourceException;
import java.util.ResourceBundle;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.bouncycastle.asn1.ASN1OctetString;
import org.bouncycastle.asn1.ASN1Sequence;
import org.bouncycastle.asn1.ASN1Set;
import org.bouncycastle.asn1.BERApplicationSpecific;
import org.bouncycastle.asn1.BERConstructedOctetString;
import org.bouncycastle.asn1.BERSequence;
import org.bouncycastle.asn1.BERSet;
import org.bouncycastle.asn1.BERTaggedObject;
import org.bouncycastle.asn1.DERApplicationSpecific;
import org.bouncycastle.asn1.DERBMPString;
import org.bouncycastle.asn1.DERBitString;
import org.bouncycastle.asn1.DERBoolean;
import org.bouncycastle.asn1.DEREncodable;
import org.bouncycastle.asn1.DEREnumerated;
import org.bouncycastle.asn1.DERExternal;
import org.bouncycastle.asn1.DERGeneralizedTime;
import org.bouncycastle.asn1.DERIA5String;
import org.bouncycastle.asn1.DERInteger;
import org.bouncycastle.asn1.DERNull;
import org.bouncycastle.asn1.DERObject;
import org.bouncycastle.asn1.DERObjectIdentifier;
import org.bouncycastle.asn1.DEROctetString;
import org.bouncycastle.asn1.DERPrintableString;
import org.bouncycastle.asn1.DERSequence;
import org.bouncycastle.asn1.DERSet;
import org.bouncycastle.asn1.DERT61String;
import org.bouncycastle.asn1.DERTaggedObject;
import org.bouncycastle.asn1.DERUTCTime;
import org.bouncycastle.asn1.DERUTF8String;
import org.bouncycastle.asn1.DERUnknownTag;
import org.bouncycastle.asn1.DERVisibleString;
import org.bouncycastle.util.encoders.Hex;

public class ASN1Dump
{
  private final Log _logger;
  private String[] _basenames;
  private final Map<String, Map<Locale, ResourceBundle>> _cachedResourceBundles;

  public ASN1Dump()
  {
  }

  private static void _dumpAsString(String paramString, boolean paramBoolean, DERObject paramDERObject, StringBuffer paramStringBuffer)
  {
    String str = System.getProperty("line.separator");
    Object localObject1;
    Object localObject2;
    if ((paramDERObject instanceof ASN1Sequence))
    {
      localObject1 = ((ASN1Sequence)paramDERObject).getObjects();
      localObject2 = paramString + "    ";
      paramStringBuffer.append(paramString);
      if ((paramDERObject instanceof BERSequence))
        paramStringBuffer.append("BER Sequence");
      else if ((paramDERObject instanceof DERSequence))
        paramStringBuffer.append("DER Sequence");
      else
        paramStringBuffer.append("Sequence");
      paramStringBuffer.append(str);
      while (((Enumeration)localObject1).hasMoreElements())
      {
        if (((paramString = ((Enumeration)localObject1).nextElement()) == null) || (paramString.equals(new DERNull())))
        {
          paramStringBuffer.append((String)localObject2);
          paramStringBuffer.append("NULL");
          paramStringBuffer.append(str);
          continue;
        }
        if ((paramString instanceof DERObject))
        {
          _dumpAsString((String)localObject2, paramBoolean, (DERObject)paramString, paramStringBuffer);
          continue;
        }
        _dumpAsString((String)localObject2, paramBoolean, ((DEREncodable)paramString).getDERObject(), paramStringBuffer);
      }
      return;
    }
    if ((paramDERObject instanceof DERTaggedObject))
    {
      localObject1 = paramString + "    ";
      paramStringBuffer.append(paramString);
      if ((paramDERObject instanceof BERTaggedObject))
        paramStringBuffer.append("BER Tagged [");
      else
        paramStringBuffer.append("Tagged [");
      localObject2 = (DERTaggedObject)paramDERObject;
      paramStringBuffer.append(Integer.toString(((DERTaggedObject)localObject2).getTagNo()));
      paramStringBuffer.append(']');
      if (!((DERTaggedObject)localObject2).isExplicit())
        paramStringBuffer.append(" IMPLICIT ");
      paramStringBuffer.append(str);
      paramString = (String)localObject2;
      _dumpAsString((String)localObject1, paramBoolean, ((DERTaggedObject)localObject2).getObject(), paramStringBuffer);
      return;
    }
    if ((paramDERObject instanceof BERSet))
    {
      localObject1 = ((ASN1Set)paramDERObject).getObjects();
      localObject2 = paramString + "    ";
      paramStringBuffer.append(paramString);
      paramStringBuffer.append("BER Set");
      paramStringBuffer.append(str);
      while (((Enumeration)localObject1).hasMoreElements())
      {
        if ((paramString = ((Enumeration)localObject1).nextElement()) == null)
        {
          paramStringBuffer.append((String)localObject2);
          paramStringBuffer.append("NULL");
          paramStringBuffer.append(str);
          continue;
        }
        if ((paramString instanceof DERObject))
        {
          _dumpAsString((String)localObject2, paramBoolean, (DERObject)paramString, paramStringBuffer);
          continue;
        }
        _dumpAsString((String)localObject2, paramBoolean, ((DEREncodable)paramString).getDERObject(), paramStringBuffer);
      }
      return;
    }
    if ((paramDERObject instanceof DERSet))
    {
      localObject1 = ((ASN1Set)paramDERObject).getObjects();
      localObject2 = paramString + "    ";
      paramStringBuffer.append(paramString);
      paramStringBuffer.append("DER Set");
      paramStringBuffer.append(str);
      while (((Enumeration)localObject1).hasMoreElements())
      {
        if ((paramString = ((Enumeration)localObject1).nextElement()) == null)
        {
          paramStringBuffer.append((String)localObject2);
          paramStringBuffer.append("NULL");
          paramStringBuffer.append(str);
          continue;
        }
        if ((paramString instanceof DERObject))
        {
          _dumpAsString((String)localObject2, paramBoolean, (DERObject)paramString, paramStringBuffer);
          continue;
        }
        _dumpAsString((String)localObject2, paramBoolean, ((DEREncodable)paramString).getDERObject(), paramStringBuffer);
      }
      return;
    }
    if ((paramDERObject instanceof DERObjectIdentifier))
    {
      paramStringBuffer.append(paramString + "ObjectIdentifier(" + ((DERObjectIdentifier)paramDERObject).getId() + ")" + str);
      return;
    }
    if ((paramDERObject instanceof DERBoolean))
    {
      paramStringBuffer.append(paramString + "Boolean(" + ((DERBoolean)paramDERObject).isTrue() + ")" + str);
      return;
    }
    if ((paramDERObject instanceof DERInteger))
    {
      paramStringBuffer.append(paramString + "Integer(" + ((DERInteger)paramDERObject).getValue() + ")" + str);
      return;
    }
    if ((paramDERObject instanceof BERConstructedOctetString))
    {
      localObject1 = (ASN1OctetString)paramDERObject;
      paramStringBuffer.append(paramString + "BER Constructed Octet String" + "[" + ((ASN1OctetString)localObject1).getOctets().length + "] ");
      if (paramBoolean)
      {
        paramStringBuffer.append(dumpBinaryDataAsString(paramString, ((ASN1OctetString)localObject1).getOctets()));
      }
      else
      {
        paramStringBuffer.append(str);
        return;
      }
    }
    else if ((paramDERObject instanceof DEROctetString))
    {
      localObject1 = (ASN1OctetString)paramDERObject;
      paramStringBuffer.append(paramString + "DER Octet String" + "[" + ((ASN1OctetString)localObject1).getOctets().length + "] ");
      if (paramBoolean)
      {
        paramStringBuffer.append(dumpBinaryDataAsString(paramString, ((ASN1OctetString)localObject1).getOctets()));
      }
      else
      {
        paramStringBuffer.append(str);
        return;
      }
    }
    else if ((paramDERObject instanceof DERBitString))
    {
      localObject1 = (DERBitString)paramDERObject;
      paramStringBuffer.append(paramString + "DER Bit String" + "[" + ((DERBitString)localObject1).getBytes().length + ", " + ((DERBitString)localObject1).getPadBits() + "] ");
      if (paramBoolean)
      {
        paramStringBuffer.append(dumpBinaryDataAsString(paramString, ((DERBitString)localObject1).getBytes()));
      }
      else
      {
        paramStringBuffer.append(str);
        return;
      }
    }
    else
    {
      if ((paramDERObject instanceof DERIA5String))
      {
        paramStringBuffer.append(paramString + "IA5String(" + ((DERIA5String)paramDERObject).getString() + ") " + str);
        return;
      }
      if ((paramDERObject instanceof DERUTF8String))
      {
        paramStringBuffer.append(paramString + "UTF8String(" + ((DERUTF8String)paramDERObject).getString() + ") " + str);
        return;
      }
      if ((paramDERObject instanceof DERPrintableString))
      {
        paramStringBuffer.append(paramString + "PrintableString(" + ((DERPrintableString)paramDERObject).getString() + ") " + str);
        return;
      }
      if ((paramDERObject instanceof DERVisibleString))
      {
        paramStringBuffer.append(paramString + "VisibleString(" + ((DERVisibleString)paramDERObject).getString() + ") " + str);
        return;
      }
      if ((paramDERObject instanceof DERBMPString))
      {
        paramStringBuffer.append(paramString + "BMPString(" + ((DERBMPString)paramDERObject).getString() + ") " + str);
        return;
      }
      if ((paramDERObject instanceof DERT61String))
      {
        paramStringBuffer.append(paramString + "T61String(" + ((DERT61String)paramDERObject).getString() + ") " + str);
        return;
      }
      if ((paramDERObject instanceof DERUTCTime))
      {
        paramStringBuffer.append(paramString + "UTCTime(" + ((DERUTCTime)paramDERObject).getTime() + ") " + str);
        return;
      }
      if ((paramDERObject instanceof DERGeneralizedTime))
      {
        paramStringBuffer.append(paramString + "GeneralizedTime(" + ((DERGeneralizedTime)paramDERObject).getTime() + ") " + str);
        return;
      }
      if ((paramDERObject instanceof DERUnknownTag))
      {
        paramStringBuffer.append(paramString + "Unknown " + Integer.toString(((DERUnknownTag)paramDERObject).getTag(), 16) + " " + new String(Hex.encode(((DERUnknownTag)paramDERObject).getData())) + str);
        return;
      }
      if ((paramDERObject instanceof BERApplicationSpecific))
      {
        paramStringBuffer.append(outputApplicationSpecific("BER", paramString, paramBoolean, paramDERObject, str));
        return;
      }
      if ((paramDERObject instanceof DERApplicationSpecific))
      {
        paramStringBuffer.append(outputApplicationSpecific("DER", paramString, paramBoolean, paramDERObject, str));
        return;
      }
      if ((paramDERObject instanceof DEREnumerated))
      {
        localObject1 = (DEREnumerated)paramDERObject;
        paramStringBuffer.append(paramString + "DER Enumerated(" + ((DEREnumerated)localObject1).getValue() + ")" + str);
        return;
      }
      if ((paramDERObject instanceof DERExternal))
      {
        localObject1 = (DERExternal)paramDERObject;
        paramStringBuffer.append(paramString + "External " + str);
        localObject2 = paramString + "    ";
        if (((DERExternal)localObject1).getDirectReference() != null)
          paramStringBuffer.append((String)localObject2 + "Direct Reference: " + ((DERExternal)localObject1).getDirectReference().getId() + str);
        if (((DERExternal)localObject1).getIndirectReference() != null)
          paramStringBuffer.append((String)localObject2 + "Indirect Reference: " + ((DERExternal)localObject1).getIndirectReference().toString() + str);
        if (((DERExternal)localObject1).getDataValueDescriptor() != null)
          _dumpAsString((String)localObject2, paramBoolean, ((DERExternal)localObject1).getDataValueDescriptor(), paramStringBuffer);
        paramStringBuffer.append((String)localObject2 + "Encoding: " + ((DERExternal)localObject1).getEncoding() + str);
        _dumpAsString((String)localObject2, paramBoolean, ((DERExternal)localObject1).getExternalContent(), paramStringBuffer);
        return;
      }
      paramStringBuffer.append(paramString + paramDERObject.toString() + str);
    }
  }

  private static String outputApplicationSpecific(String paramString1, String paramString2, boolean paramBoolean, DERObject paramDERObject, String paramString3)
  {
    paramDERObject = (DERApplicationSpecific)paramDERObject;
    StringBuffer localStringBuffer = new StringBuffer();
    if (paramDERObject.isConstructed())
    {
      try
      {
        ASN1Sequence localASN1Sequence = ASN1Sequence.getInstance(paramDERObject.getObject(16));
        localStringBuffer.append(paramString2 + paramString1 + " ApplicationSpecific[" + paramDERObject.getApplicationTag() + "]" + paramString3);
        paramString1 = localASN1Sequence.getObjects();
        while (paramString1.hasMoreElements())
          _dumpAsString(paramString2 + "    ", paramBoolean, (DERObject)paramString1.nextElement(), localStringBuffer);
      }
      catch (IOException localIOException)
      {
        localStringBuffer.append(localIOException);
      }
      return localStringBuffer.toString();
    }
    return paramString2 + paramString1 + " ApplicationSpecific[" + paramDERObject.getApplicationTag() + "] (" + new String(Hex.encode(paramDERObject.getContents())) + ")" + paramString3;
  }

  public static String dumpAsString(Object paramObject)
  {
    paramObject = 0;
    paramObject = paramObject;
    StringBuffer localStringBuffer = new StringBuffer();
    if ((paramObject instanceof DERObject))
      _dumpAsString("", false, (DERObject)paramObject, localStringBuffer);
    else if ((paramObject instanceof DEREncodable))
      _dumpAsString("", false, ((DEREncodable)paramObject).getDERObject(), localStringBuffer);
    else
      return "unknown object type " + paramObject.toString();
    return localStringBuffer.toString();
  }

  private static String dumpBinaryDataAsString(String paramString, byte[] paramArrayOfByte)
  {
    String str = System.getProperty("line.separator");
    StringBuffer localStringBuffer = new StringBuffer();
    paramString = paramString + "    ";
    localStringBuffer.append(str);
    for (int i = 0; i < paramArrayOfByte.length; i += 32)
      if (paramArrayOfByte.length - i > 32)
      {
        localStringBuffer.append(paramString);
        localStringBuffer.append(new String(Hex.encode(paramArrayOfByte, i, 32)));
        localStringBuffer.append("    ");
        localStringBuffer.append(calculateAscString(paramArrayOfByte, i, 32));
        localStringBuffer.append(str);
      }
      else
      {
        localStringBuffer.append(paramString);
        localStringBuffer.append(new String(Hex.encode(paramArrayOfByte, i, paramArrayOfByte.length - i)));
        for (int j = paramArrayOfByte.length - i; j != 32; j++)
          localStringBuffer.append("  ");
        localStringBuffer.append("    ");
        localStringBuffer.append(calculateAscString(paramArrayOfByte, i, paramArrayOfByte.length - i));
        localStringBuffer.append(str);
      }
    return localStringBuffer.toString();
  }

  private static String calculateAscString(byte[] paramArrayOfByte, int paramInt1, int paramInt2)
  {
    StringBuffer localStringBuffer = new StringBuffer();
    for (int i = paramInt1; i != paramInt1 + paramInt2; i++)
    {
      if ((paramArrayOfByte[i] < 32) || (paramArrayOfByte[i] > 126))
        continue;
      localStringBuffer.append((char)paramArrayOfByte[i]);
    }
    return localStringBuffer.toString();
  }

  public String getLocalizedMessage(String paramString, Locale paramLocale)
  {
    String str = null;
    for (int i = 0; (str == null) && (i < this._basenames.length); i++)
    {
      ResourceBundle localResourceBundle;
      if ((localResourceBundle = getResourceBundle(this._basenames[i], paramLocale)) == null)
        continue;
      str = getStringOrNull(localResourceBundle, paramString);
    }
    return str;
  }

  public ASN1Dump(String[] paramArrayOfString)
  {
    this._logger = LogFactory.getLog(getClass());
    this._basenames = new String[0];
    this._cachedResourceBundles = new HashMap();
    this = paramArrayOfString;
    paramArrayOfString = null;
    if (this != null)
      paramArrayOfString = (String[])clone();
    this._basenames = paramArrayOfString;
  }

  private ResourceBundle getResourceBundle(String paramString, Locale paramLocale)
  {
    synchronized (this._cachedResourceBundles)
    {
      Object localObject1;
      Object localObject2;
      if (((localObject1 = (Map)this._cachedResourceBundles.get(paramString)) != null) && ((localObject2 = (ResourceBundle)((Map)localObject1).get(paramLocale)) != null))
        return localObject2;
      try
      {
        Locale localLocale = paramLocale;
        localObject2 = ResourceBundle.getBundle(localObject2 = paramString, localLocale);
        if (localObject1 == null)
        {
          localObject1 = new HashMap();
          this._cachedResourceBundles.put(paramString, localObject1);
        }
        ((Map)localObject1).put(paramLocale, localObject2);
        return localObject2;
      }
      catch (MissingResourceException localMissingResourceException)
      {
        if (this._logger.isWarnEnabled())
          this._logger.warn("ResourceBundle [" + paramString + "] not found for MessageSource: " + localMissingResourceException.getMessage());
        return null;
      }
    }
  }

  private static String getStringOrNull(ResourceBundle paramResourceBundle, String paramString)
  {
    try
    {
      return paramResourceBundle.getString(paramString);
    }
    catch (MissingResourceException localMissingResourceException)
    {
    }
    return null;
  }
}

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.bouncycastle.asn1.util.ASN1Dump
 * JD-Core Version:    0.6.0
 */