package org.jdesktop.swingworker;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import javax.swing.SwingUtilities;

abstract class AccumulativeRunnable<T>
  implements Runnable
{
  private List<T> arguments = null;

  protected abstract void run(List<T> paramList);

  public final void run()
  {
    run(flush());
  }

  public final synchronized void add(boolean paramBoolean, T[] paramArrayOfT)
  {
    int i = 1;
    if (this.arguments == null)
    {
      i = 0;
      this.arguments = new ArrayList();
    }
    if (paramBoolean)
      this.arguments.addAll(0, Arrays.asList(paramArrayOfT));
    else
      Collections.addAll(this.arguments, paramArrayOfT);
    if (i == 0)
      submit();
  }

  protected void submit()
  {
    SwingUtilities.invokeLater(this);
  }

  private final synchronized List<T> flush()
  {
    List localList = this.arguments;
    this.arguments = null;
    return localList;
  }
}

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.jdesktop.swingworker.AccumulativeRunnable
 * JD-Core Version:    0.6.0
 */