package org.jdesktop.swingworker;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Future;
import java.util.concurrent.FutureTask;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.locks.Condition;
import java.util.concurrent.locks.ReentrantLock;
import javax.swing.SwingUtilities;
import javax.swing.Timer;

public abstract class SwingWorker<T, V>
  implements Future<T>, Runnable
{
  private volatile StateValue state;
  private final FutureTask<T> future;
  private final PropertyChangeSupport propertyChangeSupport;
  private static final AccumulativeRunnable<Runnable> doSubmit = new DoSubmitAccumulativeRunnable();
  private static ExecutorService executorService = null;

  public SwingWorker()
  {
    1 local1 = new Callable()
    {
      public final T call()
        throws Exception
      {
        SwingWorker.access$100(SwingWorker.this, SwingWorker.StateValue.STARTED);
        return SwingWorker.this.doInBackground();
      }
    };
    this.future = new FutureTask(local1)
    {
      protected final void done()
      {
        SwingWorker.access$200(SwingWorker.this);
        SwingWorker.access$100(SwingWorker.this, SwingWorker.StateValue.DONE);
      }
    };
    this.state = StateValue.PENDING;
    this.propertyChangeSupport = new SwingWorkerPropertyChangeSupport(this);
  }

  protected abstract T doInBackground()
    throws Exception;

  public final void run()
  {
    this.future.run();
  }

  public final int getProgress()
  {
    return 0;
  }

  public final void execute()
  {
    getWorkersExecutorService().execute(this);
  }

  public final boolean cancel(boolean paramBoolean)
  {
    return this.future.cancel(paramBoolean);
  }

  public final boolean isCancelled()
  {
    return this.future.isCancelled();
  }

  public final boolean isDone()
  {
    return this.future.isDone();
  }

  public final T get()
    throws InterruptedException, ExecutionException
  {
    return this.future.get();
  }

  public final T get(long paramLong, TimeUnit paramTimeUnit)
    throws InterruptedException, ExecutionException, TimeoutException
  {
    return this.future.get(paramLong, paramTimeUnit);
  }

  public final void addPropertyChangeListener(PropertyChangeListener paramPropertyChangeListener)
  {
    getPropertyChangeSupport().addPropertyChangeListener(paramPropertyChangeListener);
  }

  public final void removePropertyChangeListener(PropertyChangeListener paramPropertyChangeListener)
  {
    getPropertyChangeSupport().removePropertyChangeListener(paramPropertyChangeListener);
  }

  public final void firePropertyChange(String paramString, Object paramObject1, Object paramObject2)
  {
    getPropertyChangeSupport().firePropertyChange(paramString, paramObject1, paramObject2);
  }

  public final PropertyChangeSupport getPropertyChangeSupport()
  {
    return this.propertyChangeSupport;
  }

  public final StateValue getState()
  {
    if (isDone())
      return StateValue.DONE;
    return this.state;
  }

  private static synchronized ExecutorService getWorkersExecutorService()
  {
    if (executorService == null)
    {
      6 local6 = new ThreadFactory()
      {
        private AtomicInteger threadNumber = new AtomicInteger(1);

        public final Thread newThread(Runnable paramRunnable)
        {
          StringBuilder localStringBuilder;
          (localStringBuilder = new StringBuilder("SwingWorker-pool-")).append(System.identityHashCode(this));
          localStringBuilder.append("-thread-");
          localStringBuilder.append(this.threadNumber.getAndIncrement());
          if ((this = new Thread(paramRunnable, localStringBuilder.toString())).isDaemon())
            setDaemon(false);
          if (getPriority() != 5)
            setPriority(5);
          return this;
        }
      };
      executorService = new ThreadPoolExecutor(0, 10, 5L, TimeUnit.SECONDS, new LinkedBlockingQueue(), local6)
      {
        private final ReentrantLock pauseLock = new ReentrantLock();
        private final Condition unpaused = this.pauseLock.newCondition();
        private boolean isPaused = false;
        private final ReentrantLock executeLock = new ReentrantLock();

        public final void execute(Runnable paramRunnable)
        {
          this.executeLock.lock();
          try
          {
            this.pauseLock.lock();
            try
            {
              this.isPaused = true;
              this.pauseLock.unlock();
            }
            finally
            {
              this.pauseLock.unlock();
            }
            super.execute(paramRunnable);
            setCorePoolSize(0);
            this.pauseLock.lock();
            try
            {
              this.isPaused = false;
              this.unpaused.signalAll();
              this.pauseLock.unlock();
            }
            finally
            {
              this.pauseLock.unlock();
            }
            return;
          }
          finally
          {
            this.executeLock.unlock();
          }
          throw paramRunnable;
        }

        // ERROR //
        protected final void afterExecute(Runnable paramRunnable, java.lang.Throwable paramThrowable)
        {
          // Byte code:
          //   0: aload_0
          //   1: aload_1
          //   2: aload_2
          //   3: invokespecial 12	java/util/concurrent/ThreadPoolExecutor:afterExecute	(Ljava/lang/Runnable;Ljava/lang/Throwable;)V
          //   6: aload_0
          //   7: getfield 9	org/jdesktop/swingworker/SwingWorker$7:pauseLock	Ljava/util/concurrent/locks/ReentrantLock;
          //   10: invokevirtual 15	java/util/concurrent/locks/ReentrantLock:lock	()V
          //   13: aload_0
          //   14: getfield 8	org/jdesktop/swingworker/SwingWorker$7:isPaused	Z
          //   17: ifeq +15 -> 32
          //   20: aload_0
          //   21: getfield 10	org/jdesktop/swingworker/SwingWorker$7:unpaused	Ljava/util/concurrent/locks/Condition;
          //   24: invokeinterface 19 1 0
          //   29: goto -16 -> 13
          //   32: aload_0
          //   33: getfield 9	org/jdesktop/swingworker/SwingWorker$7:pauseLock	Ljava/util/concurrent/locks/ReentrantLock;
          //   36: invokevirtual 17	java/util/concurrent/locks/ReentrantLock:unlock	()V
          //   39: return
          //   40: pop
          //   41: aload_0
          //   42: getfield 9	org/jdesktop/swingworker/SwingWorker$7:pauseLock	Ljava/util/concurrent/locks/ReentrantLock;
          //   45: invokevirtual 17	java/util/concurrent/locks/ReentrantLock:unlock	()V
          //   48: return
          //   49: astore_1
          //   50: aload_0
          //   51: getfield 9	org/jdesktop/swingworker/SwingWorker$7:pauseLock	Ljava/util/concurrent/locks/ReentrantLock;
          //   54: invokevirtual 17	java/util/concurrent/locks/ReentrantLock:unlock	()V
          //   57: aload_1
          //   58: athrow
          //
          // Exception table:
          //   from	to	target	type
          //   13	32	40	java/lang/InterruptedException
          //   13	32	49	finally
        }
      };
    }
    return executorService;
  }

  private class SwingWorkerPropertyChangeSupport extends PropertyChangeSupport
  {
    SwingWorkerPropertyChangeSupport(Object arg2)
    {
      super();
    }

    public final void firePropertyChange(PropertyChangeEvent paramPropertyChangeEvent)
    {
      if (SwingUtilities.isEventDispatchThread())
      {
        super.firePropertyChange(paramPropertyChangeEvent);
        return;
      }
      paramPropertyChangeEvent = new Runnable[] { new Runnable(paramPropertyChangeEvent)
      {
        public final void run()
        {
          SwingWorker.SwingWorkerPropertyChangeSupport.this.firePropertyChange(this.val$evt);
        }
      }
       };
      (this = SwingWorker.doSubmit).add(false, paramPropertyChangeEvent);
    }
  }

  private static class DoSubmitAccumulativeRunnable extends AccumulativeRunnable<Runnable>
    implements ActionListener
  {
    private DoSubmitAccumulativeRunnable(byte paramByte)
    {
    }

    protected final void run(List<Runnable> paramList)
    {
      int i = 0;
      try
      {
        Object localObject1 = paramList.iterator();
        while (((Iterator)localObject1).hasNext())
        {
          Runnable localRunnable = (Runnable)((Iterator)localObject1).next();
          i++;
          localRunnable.run();
        }
        if (i < paramList.size())
        {
          localObject1 = new Runnable[paramList.size() - i];
          for (int j = 0; j < localObject1.length; j++)
            localObject1[j] = ((Runnable)paramList.get(i + j));
          add(true, localObject1);
          return;
        }
      }
      finally
      {
        if (i < paramList.size())
        {
          Runnable[] arrayOfRunnable = new Runnable[paramList.size() - i];
          for (int k = 0; k < arrayOfRunnable.length; k++)
            arrayOfRunnable[k] = ((Runnable)paramList.get(i + k));
          add(true, arrayOfRunnable);
        }
      }
    }

    protected final void submit()
    {
      (this = new Timer(33, this)).setRepeats(false);
      start();
    }

    public final void actionPerformed(ActionEvent paramActionEvent)
    {
      run();
    }
  }

  public static enum StateValue
  {
    PENDING, STARTED, DONE;
  }
}

/* Location:           /home/laurent/VOTE/voting-applet.jar
 * Qualified Name:     org.jdesktop.swingworker.SwingWorker
 * JD-Core Version:    0.6.0
 */